@@ -113,9 +113,9 @@ use strict;
         $path = GCUtils::getDisplayedImage($path, '', $file);
         my $dir = undef;
         $dir = dirname($file) if $file;
-        return File::Spec->rel2abs($path,$dir)
+        return GCUtils::pathToUnix(File::Spec->rel2abs($path,$dir))
             if !$self->{options}->useRelativePaths;
-        return File::Spec->abs2rel($path,$dir);
+        return GCUtils::pathToUnix(File::Spec->abs2rel($path,$dir));
     }
     
     sub endProgress
@@ -222,7 +222,6 @@ use strict;
     sub setModel
     {
         my ($self, $model) = @_;
-        
         $self->{model} = $self->{modelFactory}->getModel($model);
         $self->{exporter}->setModel($self->{model})
             if $self->{exporter};
@@ -369,4 +368,4 @@ use strict;
     }
 }
 
-1;
\ No newline at end of file
+1;
