@@ -34,7 +34,6 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
     package GCItems;
     
     use GCModel;
-    use XML::Simple;
     use XML::Parser;
     
     sub new
@@ -86,6 +85,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
     sub updateCurrent
     {
         my $self = shift;
+
         return if $self->{currentItem} == -1;
         my $oldSortValue = $self->{itemArray}[$self->{currentItem}]->{$self->{currentSortField}};
 
@@ -396,22 +396,11 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         
         $type ||= $self->{model}->{fieldsInfo}->{$field}->{type};
         $value = $self->{parent}->transformTitle($value) if $field eq $self->{model}->{commonFields}->{title};
+        $value = GCPreProcess::reverseDate($value) if $type eq 'date';
         $value = GCPreProcess::multipleList($value, $type) if $type =~ /list$/o;
         return $value;
     }
 
-    sub compareItems
-    {
-        my ($self, $a, $b) = @_;
-    
-        use locale;
-        my $field = $self->{currentSortField};
-        my $type = $self->{model}->{fieldsInfo}->{$field}->{type};
-        return ($a->{$field} <=> $b->{$field})
-            if ($type eq 'number');
-        return ($self->transformValue($a->{$field}, $field, $type) cmp $self->transformValue($b->{$field}, $field, $type));
-    }
-    
     sub getValue
     {
         my ($self, $idx, $field) = @_;
@@ -470,6 +459,43 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         return \@results;
     }
     
+    sub sortItems
+    {
+        my $self = shift;
+
+        my $initTime;
+
+        $self->{sortCache} = {};
+        sub compare
+        {
+            use locale;
+            my $field = $self->{currentSortField};
+            my $type = $self->{model}->{fieldsInfo}->{$field}->{type};
+            return ($a->{$field} <=> $b->{$field})
+                if ($type eq 'number');
+#            return (
+#                    ($self->{sortCache}->{$a->{$field}} ||= $self->transformValue($a->{$field}, $field, $type))
+#                    cmp
+#                    ($self->{sortCache}->{$b->{$field}} ||= $self->transformValue($b->{$field}, $field, $type))
+#                   )
+#                if ($type eq 'date');;
+            return (
+                    ($self->{sortCache}->{$a->{$field}} ||= $self->transformValue($a->{$field}, $field, $type))
+                    cmp
+                    ($self->{sortCache}->{$b->{$field}} ||= $self->transformValue($b->{$field}, $field, $type))
+                   );
+        }
+
+        if ($self->{currentSortOrder})
+        {
+            @{$self->{itemArray}} = sort compare @{$self->{itemArray}};
+        }
+        else
+        {
+            @{$self->{itemArray}} = reverse sort compare @{$self->{itemArray}};
+        }
+    }
+
     sub reloadList
     {
         my ($self, $splash, $fullProgress, $filtering) = @_;
@@ -483,19 +509,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         
         $self->{parent}->{itemsList}->reset if $self->{parent}->{itemsList};
         
-        sub compare
-        {
-            return $self->compareItems($a, $b);
-        }
-
-        if ($self->{currentSortOrder})
-        {
-            @{$self->{itemArray}} = sort compare @{$self->{itemArray}};
-        }
-        else
-        {
-            @{$self->{itemArray}} = reverse sort compare @{$self->{itemArray}};
-        }
+        $self->sortItems;
 
         my @displayedArray = ();
         my $lastDisplayed = -1;
@@ -505,11 +519,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         my $j = 0;
         foreach (@{$self->{itemArray}})
         {
-            $hasId = 0;
-            if ($self->{currentId} eq $_->{$self->{model}->{commonFields}->{id}})
-            {
-                $hasId = 1;
-            }
+            $hasId = ($self->{currentId} eq $_->{$self->{model}->{commonFields}->{id}});
 
             if ($self->{toBeDisplayed}->{$_->{$self->{model}->{commonFields}->{id}}})
             {
@@ -632,10 +642,11 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         #$self->{currentItem}-- if $self->{currentItem};
         #$self->{currentItem}-- if $self->{currentItem} == $self->{nbItems};
         
-        my $id = $self->{itemArray}[$self->{currentItem}]->{$self->{model}->{commonFields}->{id}};
-        $self->{currentId} = $id;
+#        my $id = $self->{itemArray}[$self->{currentItem}]->{$self->{model}->{commonFields}->{id}};
+#        $self->{currentId} = $id;
 
         my ($needReload, $newIdx) = $self->{parent}->{itemsList}->removeItem($number, $prevId, $oldInfo);
+        $self->{currentId} = $self->{itemArray}[$newIdx]->{$self->{model}->{commonFields}->{id}};
         if ($needReload)
         {
             $self->reloadList;
@@ -1008,6 +1019,71 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 Char  => \&Text,
             });
             $parser->parsefile($file);
+
+#            use XML::LibXML qw(:all);
+#            my $parser = XML::LibXML->new;
+#            my $doc = $parser->parse_file($file);
+#            my $root = $doc->getDocumentElement();
+#            my $currentCount = 0;
+#            $self->{nbItems} = $root->getAttribute('items');
+#            $self->{splash}->setItemsTotal($self->{nbItems})
+#                if $self->{splash};
+#            if ($root->getAttribute('type') ne 'inline')
+#            {
+#                $self->{parent}->setCurrentModel($root->getAttribute('type'));
+#            }
+#            
+#            for my $node($root->getChildrenByTagName('item'))
+#            {
+#                my $item;
+#                $currentCount++;
+#                for my $data($node->getChildNodes)
+#                {
+#                    next if $data->nodeType eq XML_TEXT_NODE;
+#                    $item->{$data->getName} = $data->textContent;
+#                }
+#                push @{$self->{itemArray}}, $item;
+#                my $id = $item->{$self->{model}->{commonFields}->{id}};
+#                if ($self->{filterSearch}->test($item))
+#                {
+#                    $self->{toBeDisplayed}->{$id} = 1;
+#                }
+#                else
+#                {
+#                    $self->{toBeDisplayed}->{$id} = 0;
+#                }
+#                $self->{splash}->setProgressForItemsLoad($currentCount)
+#                    if $self->{splash};
+#            }
+
+
+
+#            use XML::Twig;
+#
+#            sub item
+#            {
+#                my ($twig, $item) = @_;
+#                #print "Got one\n";
+#            }
+#
+#            my $twig= new XML::Twig( 
+#                                    TwigHandlers => {item => \&item}
+#                                   );            
+#            $twig->parsefile($file);    # build the twig
+#            my $root= $twig->root;           # get the root of the twig (stats)
+#            #my @players= $root->children;    # get the player list
+
+
+
+
+            if ($ENV{GCS_PROFILING} > 0)
+            {
+                my $elapsed;
+                eval '$elapsed = Time::HiRes::tv_interval($initTime)';
+                print "Load time : $elapsed\n";
+            }
+
+
         };
         if ($@)
         {
@@ -1021,12 +1097,12 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         }
 
 		# Now we calculate nbItems to be sure we have the correct value
-		$self->{nbItems} = scalar @{$self->{itemArray}};
+        $self->{nbItems} = scalar @{$self->{itemArray}};
 	
-		if (! $self->{nbItems})
-		{
-		    $self->{panel}->hide;
-		}
+        if (! $self->{nbItems})
+        {
+            $self->{panel}->hide;
+        }
 		
         $self->{parent}->refreshFilters;
 		
@@ -1092,7 +1168,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         }
         my $information = ' <information>
 ';
-        $information .= "  <$_>".$self->{information}->{$_}."</$_>\n"
+        $information .= "  <$_>".GCUtils::encodeEntities($self->{information}->{$_})."</$_>\n"
             foreach (sort keys %{$self->{information}});
         $information .= ' </information>';
 
@@ -1179,6 +1255,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
     my $newItem;
     my $modCap;
     my $prefCap;
+    my $anyCap;
     
     sub StartDocument
     {
@@ -1189,6 +1266,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         $currentCount = 0;
         $modCap = 0;
         $prefCap = 0;
+        $anyCap = 0;
     }
     
     sub EndDocument
@@ -1199,7 +1277,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
     
     sub StartTag
     {
-        my ($expat, $tag, %attrs) = @_;
+        #my ($expat, $tag, %attrs) = @_;
         if ($isItem)
         {
             if ($inLine)
@@ -1207,7 +1285,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 #Only a col could start in a line
                 $inCol = 1;
             }
-            elsif ($tag eq 'line')
+            elsif ($_[1] eq 'line')
             {
                 $inLine = 1;
                 $currentIsList = 1;
@@ -1217,15 +1295,16 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
             else
             {
                 $currentIsList = 0;
-                $currentTag = $tag;
+                $currentTag = $_[1];
             }
         }
         elsif ($isInfo)
         {
-            $currentTag = $tag;
+            $currentTag = $_[1];
         }
         else
         {
+            my ($expat, $tag, %attrs) = @_;
             if ($modCap)
             {
                 $globalInstance->{inlineModel} .= "<$tag".HashToXMLString(%attrs).'>';
@@ -1247,11 +1326,13 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
             elsif ($tag eq $GCData::inlineCollectionTag)
             {
                 $modCap = 1;
+                $anyCap = 1;
                 $globalInstance->{inlineModel} = '<collection'.HashToXMLString(%attrs).">\n";
             }
             elsif ($tag eq $GCData::inlinePreferencesTag)
             {
                 $prefCap = 1;
+                $anyCap = 1;
                 $globalInstance->{inlinePreferences} = '<preferences'.HashToXMLString(%attrs).">\n";
             }
             elsif ($tag eq $GCData::collectionTag)
@@ -1269,14 +1350,13 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
 
     sub EndTag
     {
-        my ($expat, $tag) = @_;
-        if ($modCap || $prefCap)
+        if ($anyCap)
         {
             if ($modCap)
             {
-                if ($tag eq $GCData::inlineCollectionTag)
+                if ($_[1] eq $GCData::inlineCollectionTag)
                 {
-                    $modCap = 0;
+                    $anyCap = $prefCap;
                     $globalInstance->{inlineModel} .= '</'.$GCData::collectionTag.'>';
                     if ($globalInstance->{inlinePreferences})
                     {
@@ -1287,15 +1367,15 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 }
                 else
                 {
-                    $globalInstance->{inlineModel} .= "</$tag>\n";
+                    $globalInstance->{inlineModel} .= '</'.$_[1].">\n";
                 }
                 return;
             }
             else
             {
-                if ($tag eq $GCData::inlinePreferencesTag)
+                if ($_[1] eq $GCData::inlinePreferencesTag)
                 {
-                    $prefCap = 0;
+                    $anyCap = $modCap;
                     $globalInstance->{inlinePreferences} .= '</'.$GCData::preferencesTag.'>';
                     if ($globalInstance->{inlineModel})
                     {
@@ -1305,13 +1385,13 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
                 }
                 else
                 {
-                    $globalInstance->{inlinePreferences} .= "</$tag>\n";
+                    $globalInstance->{inlinePreferences} .= '</'.$_[1].">\n";
                 }
                 return;
             }
         }
 
-        if ($tag eq 'item')
+        if ($_[1] eq 'item')
         {
             push @{$globalInstance->{itemArray}}, $newItem;
             $currentCount++;
@@ -1338,7 +1418,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
             $globalInstance->{splash}->setProgressForItemsLoad($currentCount)
                 if $globalInstance->{splash};
 
-                my ($serie, $rank) = ($newItem->{$globalInstance->{serieField}},
+            my ($serie, $rank) = ($newItem->{$globalInstance->{serieField}},
                                   $newItem->{$globalInstance->{rankField}});
             if ($serie)
             {
@@ -1359,7 +1439,7 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
             }
             $isItem = 0;
         }
-        elsif ($tag eq 'information')
+        elsif ($_[1] eq 'information')
         {
             $isInfo = 0 if !$isItem;
         }
@@ -1375,44 +1455,51 @@ our $inlinePreferencesTag = 'collectionInlinePreferences';
         {
             # The only tag that could prevent us from closing a line is col, but it has
             # already been managed
-            $currentTag = '' if !$inLine;
-            $inLine = 0;
+            if ($inLine)
+            {
+                $inLine = 0;
+            }
+            else
+            {
+                $currentTag = '';
+            }
         }
     }
 
     sub Text
     {
-        my ($expat, $text) = @_;
         if ($isItem)
         {
-            if ($inCol)
+            if ((! $currentTag)
+             || $inLine
+             || $currentIsList
+             || ((!$newItem->{$currentTag}) && ($_[1] =~ /^\s*$/oms)))
             {
-                return if $text =~ /^\s*$/oms;
-                $currentCol .= $text;
+                if ($inCol)
+                {
+                    return if $_[1] =~ /^\s*$/oms;
+                    $currentCol .= $_[1];
+                }
             }
             else
             {
-                return if (! $currentTag)
-                       || $inLine
-                       || $currentIsList
-                       || (($text =~ /^\s*$/oms) && (!$newItem->{$currentTag}));
-                $newItem->{$currentTag} .= $text;
+                $newItem->{$currentTag} .= $_[1];
             }
         }
         elsif ($isInfo)
         {
-            return if $text =~ /^\s*$/oms;
-            $globalInstance->{information}->{$currentTag} .= $text;
+            return if $_[1] =~ /^\s*$/oms;
+            $globalInstance->{information}->{$currentTag} .= $_[1];
         }
         else
         {
             if ($modCap)
             {
-                $globalInstance->{inlineModel} .= $text;
+                $globalInstance->{inlineModel} .= $_[1];
             }
             elsif ($prefCap)
             {
-                $globalInstance->{inlinePreferences} .= $text;
+                $globalInstance->{inlinePreferences} .= $_[1];
             }
         }
     }
