@@ -109,6 +109,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
         {
             $self->{about}->set_position('center-on-parent');
             $self->{about}->run;
+            $self->{about}->hide;
         }
         else
         {
@@ -162,7 +163,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
             $self->{about}->set_name('GCstar');
             $self->{about}->set_comments($parent->{lang}->{AboutDesc});
             $self->{about}->set_version($version);
-            $self->{about}->set_authors(@authors);
+            $self->{about}->set_authors('', @authors);
             $self->{about}->set_documenters(("",'Tian','http://www.gcstar.org/doc'));
             $self->{about}->set_artists("",$parent->{lang}->{AboutDesign}, 'http://le-spektre.org/');
             $self->{about}->set_copyright($parent->{lang}->{AboutLicense});
@@ -278,9 +279,17 @@ my $hasAboutDialog = ($@ ? 0 : 1);
 
         $self->{parent} = $parent;
 
-
-        my $image = Gtk2::Image->new_from_file($file);
-        $self->vbox->pack_start($image,0,0,0);
+        if (-f $file)
+        {
+            my $image = Gtk2::Image->new_from_file($file);
+            $self->vbox->pack_start($image,0,0,0);
+        }
+        else
+        {
+            my $label = new Gtk2::Label;
+            $label->set_markup('<b>'.$parent->{lang}->{PanelImageNoImage}.'</b>');
+            $self->vbox->pack_start($label,1,1,4 * $GCUtils::margin);
+        }
 
         return $self;
     }
@@ -362,7 +371,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
     
         my @files = glob $ENV{GCS_LIB_DIR}.'/*.pm';
         
-        for my $component('GCPlugins', 'GCExport', 'GCImport')
+        for my $component('GCPlugins', 'GCExport', 'GCImport', 'GCExtract')
         {
             foreach (glob $ENV{GCS_LIB_DIR}."/$component/*")
             {
@@ -381,9 +390,14 @@ my $hasAboutDialog = ($@ ? 0 : 1);
             open FILE, $file;
             while (<FILE>)
             {
-                if ((/eval.*?[\"\']use\s*(.*?)[\"\'];/) && ($1 !~ /base|vars|locale|integer|^lib|utf8|\$opt|strict|^$pref/))
+                if (
+                    ((/eval.*?[\"\']use\s*(.*?)[\"\'];/) && ($1 !~ /base|vars|locale|integer|^lib|utf8|\$opt|\$module|strict|^$pref/))
+                    ||
+                    (/checkModule\([\"\'](.*?)[\"\']\)/)
+                   )
                 #"
                 {
+                    next if $1 eq 'Time::HiRes';
                     push (@optionals, $1);
                     push @{$optionalsModules->{$1}}, $file;
                 }
@@ -405,6 +419,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
             my $label1 = new Gtk2::Label($opt);
             my $label2 = new Gtk2::Label;
 
+            $@ = '';
             eval "use $opt";
             if ($@)
             {
@@ -500,7 +515,9 @@ my $hasAboutDialog = ($@ ? 0 : 1);
         {
             $_ = shift;
             return if ! $_;
-            my ($day, $month, $year) = split m/\//;
+            my ($day, $month, $year);
+            ($day, $month, $year) = split m|/|;
+            ($day, $month, $year) = (01, 01, $_) if ! m|/|;
             $self->{calendar}->select_month($month - 1, $year);
             $self->{calendar}->select_day($day);
         }
@@ -553,12 +570,16 @@ my $hasAboutDialog = ($@ ? 0 : 1);
 
     sub setProperties
     {
-        my ($self, $properties) = @_;
+        my ($self, $properties, $file, $count) = @_;
 
         foreach (keys %{$self->{properties}})
         {
             $self->{properties}->{$_}->setValue($properties->{$_});
         }
+        $self->{info}->{file}->setValue($file);
+        $self->{info}->{items}->setValue($count);
+        $self->{info}->{size}->setValue(GCUtils::sizeToHuman((-s $file),
+                                        $self->{parent}->{lang}->{PropertiesFileSizeSymbols}));
     }
 
     sub getProperties
@@ -584,32 +605,59 @@ my $hasAboutDialog = ($@ ? 0 : 1);
 
         $self->{parent} = $parent;
                               
-        my $table = new Gtk2::Table(3,2,0);
+        my $table = new Gtk2::Table(11,4,0);
         $table->set_row_spacings($GCUtils::halfMargin);
         $table->set_col_spacings($GCUtils::halfMargin);
         $table->set_border_width($GCUtils::margin);
 
+
+        my $fileGroupLabel = new GCHeaderLabel($parent->{lang}->{PropertiesFile});
+        $table->attach($fileGroupLabel, 0, 4, 0, 1, 'fill', 'fill', 0, 0);
+
+        my $fileLabel = new GCLabel($parent->{lang}->{PropertiesFilePath});
+        $self->{info}->{file} = new GCShortText;
+        $self->{info}->{file}->lock(1);
+        $table->attach($fileLabel, 2, 3, 1, 2, 'fill', 'fill', 0, 0);
+        $table->attach($self->{info}->{file}, 3, 4, 1, 2, ['expand', 'fill'], 'fill', 0, 0);
+        
+        my $itemsLabel = new GCLabel($parent->{lang}->{PropertiesItemsNumber});
+        $self->{info}->{items} = new GCShortText;
+        $self->{info}->{items}->lock(1);
+        $table->attach($itemsLabel, 2, 3, 2, 3, 'fill', 'fill', 0, 0);
+        $table->attach($self->{info}->{items}, 3, 4, 2, 3, ['expand', 'fill'], 'fill', 0, 0);
+        
+        my $sizeLabel = new GCLabel($parent->{lang}->{PropertiesFileSize});
+        $self->{info}->{size} = new GCShortText;
+        $self->{info}->{size}->lock(1);
+        $table->attach($sizeLabel, 2, 3, 3, 4, 'fill', 'fill', 0, 0);
+        $table->attach($self->{info}->{size}, 3, 4, 3, 4, ['expand', 'fill'], 'fill', 0, 0);
+                
+
+        my $collectionGroupLabel = new GCHeaderLabel($parent->{lang}->{PropertiesCollection});
+        $table->attach($collectionGroupLabel, 0, 4, 6, 7, 'fill', 'fill', 0, 0);
+
         my $nameLabel = new GCLabel($parent->{lang}->{PropertiesName});
         $self->{properties}->{name} = new GCShortText;
-        $table->attach($nameLabel, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{name}, 1, 2, 0, 1, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($nameLabel, 2, 3, 7, 8, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{name}, 3, 4, 7, 8, ['expand', 'fill'], 'fill', 0, 0);
 
         my $ownerLabel = new GCLabel($parent->{lang}->{PropertiesOwner});
         $self->{properties}->{owner} = new GCShortText;
-        $table->attach($ownerLabel, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{owner}, 1, 2, 1, 2, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($ownerLabel, 2, 3, 8, 9, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{owner}, 3, 4, 8, 9, ['expand', 'fill'], 'fill', 0, 0);
 
         my $emailLabel = new GCLabel($parent->{lang}->{PropertiesEmail});
         $self->{properties}->{email} = new GCShortText;
-        $table->attach($emailLabel, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{email}, 1, 2, 2, 3, ['expand', 'fill'], 'fill', 0, 0);
+        $table->attach($emailLabel, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{email}, 3, 4, 9, 10, ['expand', 'fill'], 'fill', 0, 0);
 
         my $descriptionLabel = new GCLabel($parent->{lang}->{PropertiesDescription});
         $self->{properties}->{description} = new GCLongText;
-        $table->attach($descriptionLabel, 0, 1, 3, 4, 'fill', 'fill', 0, 0);
-        $table->attach($self->{properties}->{description}, 1, 2, 3, 4, ['expand', 'fill'], ['expand', 'fill'], 0, 0);
+        $table->attach($descriptionLabel, 2, 3, 10, 11, 'fill', 'fill', 0, 0);
+        $table->attach($self->{properties}->{description}, 3, 4, 10, 11, ['expand', 'fill'], ['expand', 'fill'], 0, 0);
+
+
 
-        
         $self->vbox->pack_start($table, 1, 1, 5);
         $self->vbox->show_all;
 
@@ -1183,6 +1231,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
     {
         my ($self, $file) = @_;
         
+        #$file = GCUtils::pathToUnix($file);
         if ($self->{autoAppend})
         {
             my $tmpFilter = $self->{dialog}->get_filter;
@@ -1204,6 +1253,7 @@ my $hasAboutDialog = ($@ ? 0 : 1);
         my $self = shift;
         my $filename = $self->{dialog}->get_filename;
         $filename .= (($^O =~ /win32/i) ? '\\' : '/') if ($self->{action} eq 'select-folder');
+        #$filename .= '/' if ($self->{action} eq 'select-folder');
         return $self->transformFilename($filename);
     }
 
