@@ -194,8 +194,10 @@ my $firstYear = 1895;
             {
                 my $fieldType = $model->{fieldsInfo}->{$filter}->{type};
                 $preprocess = ($fieldType eq 'date') ? 'reverseDate'
+                            : ($fieldType eq 'number') ? 'noNullNumber'
                             : ($fieldType eq 'single list') ? 'singleList'
                             : ($fieldType eq 'double list') ? 'doubleList'
+                            : ($fieldType eq 'triple list') ? 'otherList'
                             : ($fieldType =~ /list$/o) ? 'singleList'
                             : '';
             }
@@ -407,7 +409,8 @@ use Gtk2;
         bless ($self, $class);
 
         $self->{parent} = $parent;
-        $self->{layoutTable} = new Gtk2::Table(1,4,0);
+        $self->{comparisonConvertor} = new GCComparisonSelector($parent);
+        $self->{layoutTable} = new Gtk2::Table(1,3,0);
         $self->{layoutTable}->set_row_spacings($GCUtils::halfMargin);
         $self->{layoutTable}->set_col_spacings($GCUtils::margin);
         $self->{layoutTable}->set_border_width($GCUtils::margin);
@@ -434,7 +437,7 @@ use Gtk2;
 
         my $row = 0;
         return if ($#filtersTotal + (2 * $#filtersGroup)) <= 0;
-        $self->{layoutTable}->resize($#filtersTotal + (2 * $#filtersGroup),4);
+        $self->{layoutTable}->resize($#filtersTotal + (2 * $#filtersGroup), 3);
 
         $self->{fields} = [];
         foreach my $group(@filtersGroup)
@@ -442,26 +445,27 @@ use Gtk2;
             $row++;
             my @filters = @{$group->{filter}};
             my $label = new GCHeaderLabel($model->getDisplayedText($group->{label}));
-            $self->{layoutTable}->attach($label, 0, 4, $row, $row + 1, 'fill', 'expand', 0, 0);
+            $self->{layoutTable}->attach($label, 0, 3, $row, $row + 1, 'fill', 'expand', 0, 0);
             $row++;
+            my $withComparisonLabel;
             foreach my $filter(@filters)
             {
+                $withComparisonLabel = 1;
                 my $field = $filter->{field};
                 if ($field ne 'separator')
                 {
                     push @{$self->{fields}}, $field;
                     my $labelText = $fieldsInfo->{$field}->{displayed};
                     $labelText = $model->getDisplayedText($filter->{label}) if $filter->{label};            
-                    my $label = new Gtk2::Label($labelText);
-                    $label->set_alignment(0,0.5);
-                    $self->{layoutTable}->attach($label, 2, 3, $row, $row + 1, 'fill', 'fill', 0, 0);
+                    my $label = new GCLabel($labelText);
+                    $self->{layoutTable}->attach($label, 0, 1, $row, $row + 1, 'fill', 'fill', 2 * $GCUtils::margin, 0);
                     if ($fieldsInfo->{$field}->{type} eq 'short text')
                     {
                         if ($filter->{comparison} eq 'range')
                         {
                             $self->{$field} = new GCRange('text', $self->{parent}->{lang});
                             $self->{$field}->setWidth(16);
-                            
+                            $withComparisonLabel = 0;
                         }
                         else
                         {
@@ -487,6 +491,7 @@ use Gtk2;
                                                               $fieldsInfo->{$field}->{max},
                                                               $fieldsInfo->{$field}->{step});
                                 $self->{$field}->setWidth(16);
+                                $withComparisonLabel = 0;
                             }
                             else
                             {
@@ -502,6 +507,7 @@ use Gtk2;
                             {
                                 $self->{$field} = new GCRange('numeric text', $self->{parent}->{lang});
                                 $self->{$field}->setWidth(16);
+                                $withComparisonLabel = 0;
                             }
                             else
                             {
@@ -509,6 +515,10 @@ use Gtk2;
                             }
                         }
                     }
+                    elsif ($fieldsInfo->{$field}->{type} eq 'checked text')
+                    {
+                        $self->{$field} = new GCCheckedText($fieldsInfo->{$field}->{format});
+                    }
                     elsif (($fieldsInfo->{$field}->{type} eq 'history text')
                         || (($fieldsInfo->{$field}->{type} =~ /list/)
                          && ($fieldsInfo->{$field}->{history} ne 'false')))
@@ -523,6 +533,7 @@ use Gtk2;
                     elsif ($fieldsInfo->{$field}->{type} eq 'yesno')
                     {
                         $self->{$field} = new GCCheckBoxWithIgnore($self->{parent});
+                        $withComparisonLabel = 0;
                     }
                     elsif ($fieldsInfo->{$field}->{type} eq 'date')
                     {
@@ -532,11 +543,20 @@ use Gtk2;
                     {
                         $self->{$field} = new GCShortText;
                     }
-                    $self->{layoutTable}->attach($self->{$field}, 3, 4, $row, $row + 1, 'fill', 'expand', 0, 0);
+                    if ($withComparisonLabel
+                    && ($filter->{comparison} ne 'eq'))
+                    {
+                        my $labelComparison = new GCLabel(
+                           $self->{comparisonConvertor}->valueToDisplayed($filter->{comparison}),
+                           1
+                        );
+                        $self->{layoutTable}->attach($labelComparison, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+                    }
+                    $self->{layoutTable}->attach($self->{$field}, 2, 3, $row, $row + 1, ['fill', 'expand'], 'expand', 0, 0);
                 }
                 else
                 {
-                    $self->{layoutTable}->attach(Gtk2::HSeparator->new, 0, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+                    $self->{layoutTable}->attach(Gtk2::HSeparator->new, 0, 3, $row, $row + 1, 'fill', 'fill', 0, 0);
                 }
                 $row++;
             }
