@@ -29,9 +29,6 @@ use GCExport::GCExportBase;
 {
     package GCExport::GCExporterTarGz;
 
-    eval "use Compress::Zlib"; my $hasZlib = $@ ? 0 : 1;
-    eval "use Archive::Tar"; my $hasTar = $@ ? 0 : 1;
-
     use File::Copy;
     use File::Basename;
     use Cwd;
@@ -45,9 +42,9 @@ use GCExport::GCExportBase;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new($parent);
         bless ($self, $class);
-        $self->{errors} = '';
-        $self->{errors} .= "Compress::Zlib\n" if (!$hasZlib);
-        $self->{errors} .= "Archive::Tar\n" if (!$hasTar);
+
+        $self->checkModule('Compress::Zlib');
+        $self->checkModule('Archive::Tar');
 
         return $self;
     }
@@ -145,7 +142,7 @@ use GCExport::GCExportBase;
         (my $tarfile = $self->{fileName}) =~ s/\.gz$//;
         $tar->write($tarfile);
 
-        my $gz = gzopen($self->{fileName}, "wb");
+        my $gz = Compress::Zlib::gzopen($self->{fileName}, "wb");
         open(TAR, $tarfile) or die "Cannot open $tarfile ";
         binmode(TAR);
         my $buff;
