@@ -211,7 +211,8 @@ use strict;
     {
         my ($self, $locked) = @_;
     
-        $self->can_focus(!$locked);
+        #$self->can_focus(!$locked);
+        $self->set_editable(!$locked);
     }
 }
 
@@ -298,6 +299,10 @@ use strict;
         my $self = $class->SUPER::new;
 
         $self->{history} = {'' => 1};
+        
+#        $self->entry->signal_connect('activate', sub {
+#            print "Hello\n";
+#        });
 
         bless ($self, $class);
         return $self;
@@ -393,6 +398,20 @@ use strict;
 #        $self->setValue($previousValue);
         $self->{history}->{$_} = 1 foreach (@$values);
     }
+
+    sub setActivate
+    {
+        my $value
+    }
+
+    sub popup
+    {
+        my $self = shift;
+        ($self->get_children)[1]->grab_focus;
+        ($self->get_children)[1]->signal_emit('activate');
+#        ($self->get_children)[1]->pressed;
+#        ($self->get_children)[1]->released;
+    }
 }
 
 {
@@ -637,6 +656,14 @@ use strict;
         return $self->getValue eq '';
     }
     
+    sub getCurrentDate
+    {
+        my $self = shift;
+        
+        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
+        return $mday.'/'.($mon+1).'/'.(1900+$year);
+    }
+    
     sub getValue
     {
         my $self = shift;
@@ -649,6 +676,7 @@ use strict;
     {
         my ($self, $text) = @_;
         $text = GCPreProcess::restoreDate($text) if $self->{reverseDate};
+        $text = $self->getCurrentDate if $text eq 'current';
         $self->{entry}->set_text($text);
     }
     
@@ -1066,16 +1094,29 @@ use strict;
             if ($useFiles)
             {
                 $self->{entries}->[$i] = GCFile->new($parent);
+                $self->{entries}->[$i]->{entry}->signal_connect('activate' => sub {
+                    $self->addValues;
+                });
             }
             else
             {
                 if ($withHistory)
                 {
                     $self->{entries}->[$i] = GCHistoryText->new;
+                    $self->{entries}->[$i]->entry->signal_connect('activate' => sub {
+                        my $widget = $self->{entries}->[$i];
+                        $self->addValues if $widget->getValue;
+                        #$widget->popup unless $widget->getValue;
+                        $widget->entry->signal_stop_emission_by_name('activate');
+                    });
+                    #$self->{entries}->[$i]->disable_activate;
                 }
                 else
                 {
                     $self->{entries}->[$i] = GCShortText->new;
+                    $self->{entries}->[$i]->signal_connect('activate' => sub {
+                        $self->addValues;
+                    });
                 }
             }
             $self->{entries}->[$i]->setWidth(12);
@@ -1092,6 +1133,7 @@ use strict;
         }
         $self->{list}->unset_rows_drag_source;
         $self->{list}->unset_rows_drag_dest;
+        $self->{list}->set_reorderable(1);
         #($self->{list}->get_column(0)->get_cell_renderers)[0]->set('wrap-mode' => 'word');
 
         for $i (0..($number - 1))
@@ -1192,6 +1234,7 @@ use strict;
         my $formated = shift;
         if ($formated)
         {
+            print "";
             $result = GCPreProcess::multipleList($result, $self->{number});
         }
         
@@ -1627,156 +1670,6 @@ use strict;
     
 }
 
-{
-    package GCOldMenuList;
-
-    @GCOldMenuList::ISA = ('Gtk2::OptionMenu', 'GCGraphicComponent');
-
-    sub isEmpty
-    {
-        my $self = shift;
-        
-        my $idx = $self->get_history;
-        $idx-- if $idx >= $self->{separatorPosition};
-        $idx = 0 if $idx < 0;
-        return $self->{'values'}->[$idx]->{displayed} eq '';
-    }
-    
-    sub valueToDisplayed
-    {
-        my ($self, $value) = @_;
-    
-        foreach (@{$self->{'values'}})
-        {
-            return $_->{displayed} if $_->{value} eq $value
-        }
-        return '';
-    }
-    
-    sub getValue
-    {
-        my $self = shift;
-
-        my $result = 0;
-
-        my $idx = $self->get_history;
-        $idx-- if $idx >= $self->{separatorPosition};
-        $result = $self->{'values'}->[$idx]->{value} if $idx > -1;
-        return $result;
-    }
-
-    sub getDisplayedValue
-    {
-        my $self = shift;
-
-        my $result = 0;
-
-        my $idx = $self->get_history;
-        $idx-- if $idx >= $self->{separatorPosition};
-        $result = $self->{'values'}->[$idx]->{displayed} if $idx > -1;
-        return $result;
-    }
-
-    sub setValue
-    {
-        my ($self, $value) = @_;
-
-        $value = 0 if !$value;
-
-        my $i = 0;
-        if ($value)
-        {
-    		foreach (@{$self->{'values'}})
-            {
-                last if $_->{value} eq $value;
-                $i++ if $i == $self->{separatorPosition};
-                $i++;
-            }
-        }
-        $i-- if ($self->{default} == -1) && ($i >= $self->{count});
-        $self->set_history($i);
-    }
-
-    sub clear
-    {
-        my $self = shift;
-        $self->set_history(0);
-    }
-
-    sub lock
-    {
-        my ($self, $locked) = @_;
-        
-        $self->set_sensitive(!$locked);
-    }
-    
-    sub getValues
-    {
-        my $self = shift;
-        
-        my @values;
-        return $self->{values};
-    }
-    
-    sub setValues
-    {
-        my ($self, $values, $separatorPosition, $preserveValue) = @_;
-        
-        my $previous = $self->getValue if $preserveValue;
-        
-        $self->{values} = $values;
-        #$self->{textValues} = [];
-        $self->{separatorPosition} = $separatorPosition || 9999;
- 
-        if ($self->{menu})
-        {
-            $self->remove_menu;
-            $self->{menu}->destroy;
-        }
-        
-		$self->{menu} = new Gtk2::Menu();
-        my $i = 0;
-		foreach (@$values)
-		{
-            if ($i == $self->{separatorPosition})
-            {
-                $self->{menu}->append(Gtk2::SeparatorMenuItem->new);
-                $i++;
-            }
-            #push @{$self->{textValues}}, $_->{displayed};
-		    my $item = Gtk2::MenuItem->new_with_label($_->{displayed});
-		    $self->{menu}->append($item);
-		    $i++;
-		}
-
-        $self->{count} = $i;
-        $self->set_menu($self->{menu});
-        $self->{menu}->show_all;
-        
-        $self->setValue($previous) if $preserveValue;
-    }
-    
-    sub setLastForDefault
-    {
-        my $self = shift;
-        $self->{default} = -1;
-    }
-    
-    sub new
-    {
-        my ($proto, $values, $separatorPosition) = @_;
-        my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new;
-
-        bless ($self, $class);
-
-        $self->setValues($values, $separatorPosition) if $values;
-        $self->{default} = 0;
-        
-        return $self;
-    }
-}
-
 {
     package GCMenuList;
 
@@ -1827,17 +1720,16 @@ use strict;
         my ($self, $value) = @_;
 
         $value = 0 if !$value;
-
         my $i = 0;
         if ($value)
         {
     		foreach (@{$self->{values}})
             {
                 last if $_->{value} eq $value;
-                $i++ if $i == $self->{separatorPosition};
                 $i++;
             }
         }
+        $i++ if $i >= $self->{separatorPosition};
         $i-- if ($self->{default} == -1) && ($i >= $self->{count});
         $self->set_active($i);
     }
@@ -1916,7 +1808,7 @@ use strict;
 
         $self->setValues($values, $separatorPosition) if $values;
         $self->{default} = 0;
-        
+        $self->set_focus_on_click(1);
         return $self;
     }
 }
@@ -1952,11 +1844,12 @@ use strict;
 
     sub new
     {
-        my ($proto, $label) = @_;
+        my ($proto, $label, $disableMarkup) = @_;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new;
         bless ($self, $class);
-        $self->set_markup($label);
+        $self->set_markup($label) unless $disableMarkup;
+        $self->set_label($label) if $disableMarkup;
         $self->set_alignment(0,0.5);
         return $self;
     }
@@ -2428,9 +2321,9 @@ use strict;
                           {value => 'range', displayed => $parent->{lang}->{ModelFilterRange}},
                           {value => 'eq', displayed => '='},
                           {value => 'lt', displayed => '<'},
-                          {value => 'le', displayed => '<='},
+                          {value => 'le', displayed => '≤'},
                           {value => 'gt', displayed => '>'},
-                          {value => 'ge', displayed => '>='},
+                          {value => 'ge', displayed => '≥'},
                         ]);
         return $self;
      }
