@@ -92,6 +92,10 @@ use strict;
         return $self;
     }
 
+    sub savePreferences
+    {
+    }
+
     sub couldExpandAll
     {
         my $self = shift;
@@ -237,7 +241,7 @@ use strict;
         
         $self->{parent} = $parent;
         
-        $self->{sortButton} = Gtk2::Button->new_from_stock('gtk-sort-ascending');
+        $self->{sortButton} = Gtk2::Button->new_from_stock('gtk-sort-descending');
         
         #$self->{list} = new Gtk2::Table(0,$columns,1);
         $self->{list} = new Gtk2::VBox(0,0);
@@ -322,6 +326,10 @@ use strict;
         return $self;
     }
 
+    sub savePreferences
+    {
+    }
+
     sub couldExpandAll
     {
         my $self = shift;
@@ -344,7 +352,7 @@ use strict;
         
         $self->remove($self->{sortButton});
         $self->{sortButton}->destroy;
-        $self->{sortButton} = Gtk2::Button->new_from_stock($order ? 'gtk-sort-ascending' : 'gtk-sort-descending');
+        $self->{sortButton} = Gtk2::Button->new_from_stock($order ? 'gtk-sort-descending' : 'gtk-sort-ascending');
         $self->pack_start($self->{sortButton},0,0,0);
         $self->reorder_child($self->{sortButton},0);
         $self->{sortButton}->show_all;
@@ -429,8 +437,13 @@ use strict;
     sub createPixbuf
     {
         my ($self, $displayedImage, $borrower) = @_;
-    
-        my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($displayedImage);
+
+        my $pixbuf;
+        eval {
+            $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($displayedImage);
+        };
+        $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{defaultImage})
+            if $@;
         my $width = $self->{imgWidth};
         my $height = $self->{imgHeight};
         $pixbuf = GCUtils::scaleMaxPixbuf($pixbuf,
@@ -534,7 +547,6 @@ use strict;
     sub getFromCache
     {
         my ($self, $info) = @_;
-        
         if (($info->{$self->{idField}} == '') || 
             (! $self->{cache}->{$info->{$self->{idField}}}))
         {
@@ -632,13 +644,12 @@ use strict;
         #$self->select($number);
 
         #Reload needed
-        return (1, $number - 1);
+        return (1, ($number < (scalar(@{$self->{boxes}}) - 1) ? $number : ($number - 1)));
     }
         
     sub select
     {
         my ($self, $idx, $id, $init) = @_;
-
         $idx = 0 if $idx == -1;
         my @boxes = @{$self->{boxes}};
 
@@ -698,8 +709,8 @@ use strict;
         #To ease comparison, do some modifications.
         #empty borrower is equivalent to 'none'.
 
-        $previous->{$self->{borrowerField}} = '' if $previous->{$self->{borrowerField}} eq 'none';
-        $new->{$self->{borrowerField}} = '' if $new->{$self->{borrowerField}} eq 'none';
+        $previous->{$self->{borrowerField}} = 'none' if $previous->{$self->{borrowerField}} eq '';
+        $new->{$self->{borrowerField}} = 'none' if $new->{$self->{borrowerField}} eq '';
         $self->{tooltips}->set_tip($self->{boxes}->[$self->{current}], $self->{parent}->transformTitle($new->{$self->{titleField}}), '')
             if ($new->{$self->{titleField}} ne $previous->{$self->{titleField}});
         return 0 if ($previous->{$self->{coverField}} eq $new->{$self->{coverField}}) && ($previous->{$self->{borrowerField}} eq $new->{$self->{borrowerField}});
@@ -883,6 +894,20 @@ use strict;
         $self->{list}->set_rules_hint(1);
         $self->{list}->set_reorderable(1);
 
+        # Restore size of columns
+        if ($self->{preferences}->exists('columnsWidths'))
+        {
+            my $i = 0;
+            my @widths = split /\|/, $self->{preferences}->columnsWidths;
+            foreach (@{$self->{columnsArray}})
+            {
+                $_->set_sizing('fixed');
+                $_->set_resizable(1);
+                $_->set_fixed_width($widths[$i] || 70);
+                $i++;
+            }
+        }
+
 #        $self->{list}->get_model->set_sort_column_id(0, 'ascending');
 
         if ($self->{generateMaster})
@@ -956,6 +981,16 @@ use strict;
         return $self;
     }
 
+    sub savePreferences
+    {
+        my ($self, $preferences) = @_;
+        # We store it as a pipe separated list of pixel sizes
+       
+        my $value = '';
+        $value .= $_->get_width.'|' foreach (@{$self->{columnsArray}});
+        $preferences->columnsWidths($value);
+    }
+
     sub couldExpandAll
     {
         my $self = shift;
@@ -1118,6 +1153,7 @@ use strict;
                 }
             }
             $self->select($origIdx);
+            $self->{parent}->markAsUpdated;
             #$context->abort($time);
             #return 1;
         }
@@ -1225,7 +1261,13 @@ use strict;
         
         if (! $self->{cache}->{$realPath})
         {
-            my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($realPath);
+            my $pixbuf;
+            eval {
+                $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($realPath);
+            };
+            $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{defaultImage})
+                if $@;
+
             $pixbuf = GCUtils::scaleMaxPixbuf($pixbuf,
                                               $self->{imgWidth},
                                               $self->{imgHeight},
@@ -1428,6 +1470,24 @@ use strict;
         return $master;
     }
 
+    sub removeInCollection
+    {
+        my ($self, $collec, $idx) = @_;
+        my $master = $self->findMaster($collec);
+        my $iter = $self->{model}->iter_nth_child($master, 0);
+        while ($iter)
+        {
+            last if $idx == $self->convertIterToIdx($iter);
+            $iter = $self->{model}->iter_next($iter);
+        }
+        if ($iter)
+        {
+            my $removedCurrent = ($self->{selectedIterString} eq $self->{currentIterString});
+            $self->removeFromModel($iter);
+            $self->{currentRemoved} = $removedCurrent;
+        }
+    }
+
     sub isRankAfter
     {
         my ($self, $rank1, $rank2) = @_;
@@ -1457,25 +1517,6 @@ use strict;
         return 0;
     }
 
-    sub compareItems
-    {
-        my ($self, $a, $b) = @_;
-
-        my $result;
-        use locale;
-
-        return 1 if ($self->{generateMaster});
-        if ($self->{isRankNumeric})
-        {
-            $result = $a <=> $b;
-        }
-        else
-        {
-            $result = $a cmp $b;
-        }
-        return $result;
-    }
-
     sub addToWaiting
     {
         my ($self, $data, $collection, $rank) = @_;
@@ -1502,7 +1543,9 @@ use strict;
             my @waitings;
             sub compare
             {
-                return $self->compareItems($a, $b);
+                use locale;
+                return 1 if ($self->{generateMaster});
+                return ($self->{isRankNumeric} ? ($a <=> $b) : ($a cmp $b));
             }
             foreach my $childRank(sort compare keys %{$self->{waiting}->{$collection}})
             {
@@ -1796,7 +1839,8 @@ use strict;
             push @data, $col, $newValue;
             $col++;
         }
-        push @data, $col, $self->getCurrentId;
+        my $idx = $self->getCurrentId;
+        push @data, $col, $idx;
         $col++;
         my $previousRank = $self->transformValue($previous->{$self->{rankField}}, $self->{rankField});
         my $newRank = $self->transformValue($new->{$self->{rankField}}, $self->{rankField});
@@ -1848,50 +1892,105 @@ use strict;
             elsif (($previousCollection ne $newCollection)
                 || ($previousRank != $newRank))
             {
+                my $previousCollectionArray;
+                my $newCollectionArray;
                 #An item is integrated or moved into a collection
                 #First we find its master
-                my $parent;
+                my @parents;
                 if ($previousCollection eq $newCollection)
                 {
                     #Just moving
-                    $parent = $self->{model}->iter_parent($currentIter);
+                    $parents[0] = $self->{model}->iter_parent($currentIter);
                 }
                 else
-                {   
+                {
                     #Changing collection
-                    $parent = $self->findMaster($newCollection);
-                    if ($self->{generateMaster} && !$parent)
+                    $previousCollectionArray = $self->transformValue($previous->{$self->{serieField}}, $self->{serieField}, 0, $self->{groupItems});
+                    $newCollectionArray = $self->transformValue($new->{$self->{serieField}}, $self->{serieField}, 0, $self->{groupItems});
+                    if (ref($previousCollectionArray) ne 'ARRAY')
                     {
-                        #We have to create a new parent
-                        #Create the master
-                        $parent = $self->insertAtPosition(undef, $newCollection);
-                        $self->{alreadyInserted}->{$newCollection} = 1;
-                        my %info = (
-                               $self->{titleField} => $newCollection,
-                               $self->{serieField} => $newCollection,
-                               isGeneratedMaster => 1
-                        );
-                        my @masterData = $self->createRowsData(\%info, $newCollection, '', $self->convertIterToIdx($currentIter));
-                        $self->{model}->set($parent, @masterData);
-                        #Insert the child
+                        my @array = ($previousCollectionArray);
+                        $previousCollectionArray = \@array;
                     }
+                    if (ref($newCollectionArray) ne 'ARRAY')
+                    {
+                        my @array = ($newCollectionArray);
+                        $newCollectionArray = \@array;
+                    }
+                    
+                    foreach my $collec(@$newCollectionArray)
+                    {
+                        push @parents, $self->findMaster($collec);
+                        if ($self->{generateMaster})
+                        {
+                            if (!$parents[-1])
+                            {
+                                #We have to create a new parent
+                                #Create the master
+                                $parents[-1] = $self->insertAtPosition(undef, $newCollection);
+                                $self->{alreadyInserted}->{$newCollection} = 1;
+                                my %info = (
+                                       $self->{titleField} => $collec,
+                                       $self->{serieField} => $newCollection,
+                                       isGeneratedMaster => 1
+                                );
+                                my @masterData = $self->createRowsData(\%info, $newCollection, '', $self->convertIterToIdx($currentIter));
+                                $self->{model}->set($parents[-1], @masterData);
+                            }
+                            else
+                            {
+                                # The parent already exists
+                                # Check if the child were already there
+
+                                # If it was, we remove it from parents
+                                pop @parents if GCUtils::inArrayTest($collec, @$previousCollectionArray);
+                            }
+                        }
+                    }
+                    
+                    if ($self->{generateMaster})
+                    {
+                    }
+                    
                 }
-                if ($parent)
+
+                my $childIter = 0;
+                foreach my $parent(@parents)
                 {
                     #First we insert it at correct position
-                    my $childIter = $self->insertAtPosition($parent, $newRank, 1);
-                    $self->{model}->set($childIter, @data);
+                    my $cIter = $self->insertAtPosition($parent, $newRank, 1);
+                    $self->{model}->set($cIter, @data);
+                    # We point to the 1st one
+                    $childIter = $cIter if !$childIter;
+                }
+                
+                my $removedCurrent = 0;
+                # When master is generated, we already managed this
+                if ($self->{generateMaster})
+                {
+                    # Now we remove the previous ones for generated master
+                    foreach my $collec(@$previousCollectionArray)
+                    {
+                        $self->removeInCollection($collec, $idx)
+                            if !GCUtils::inArrayTest($collec, @$newCollectionArray);
+                    }
+                }
+                else
+                {
                     #First we store if we are removing the one that has been selected
-                    my $removedCurrent = ($self->{selectedIterString} eq $self->{currentIterString});
+                    $removedCurrent = ($self->{selectedIterString} eq $self->{currentIterString});
                     $self->removeFromModel($currentIter);
                     $self->{currentRemoved} = $removedCurrent;
+                }
+                if ($childIter)
+                {
                     my $childPath = $self->{model}->get_path($childIter);
                     my $rowReference = new Gtk2::TreeRowReference($self->{model}, $childPath);
                     $self->{currentIterString} = $rowReference->get_path->to_string;
                     $self->{list}->expand_to_path($childPath);
                     $self->{list}->get_selection->select_iter($childIter) if $removedCurrent;
-                    return 0;
                 }
+                return 0;
             }
         }
         $self->{model}->set($currentIter, @data) if ! $reloadNeeded;
