@@ -72,6 +72,9 @@
         'InstallOK' => 'OK',
         'InstallMissing' => 'Липсващ',
         'InstallMissingFor' => 'Липсващ за',
+        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
+        'InstallCopyDirectory' => 'Copying files in directory: ',
+        'InstallCopyDesktop' => 'Copying desktop file in: ',
 
 #Update
         'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
@@ -120,6 +123,7 @@
 
         'MenuHelp' => '_Помощ',
             'MenuHelpContent' => '_Помощ',
+            'MenuAllPlugins' => 'View _plugins',
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => '_Относно GCstar',
 
@@ -327,10 +331,6 @@ http://le-spektre.org',
 
         'ExtractButton' => 'Информация',
         'ExtractTitle' => 'Информация за видео файл',
-        'ExtractSize' => 'Размер',
-        'ExtractLength' => 'Продължителност (минути)',
-        'ExtractType' => 'Видео формат',
-        'ExtractAudioEncoding' => 'Аудио формат',
         'ExtractImport' => 'Използване на стойности',
 
         'FieldsListOpen' => 'Load a fields list from a file',
@@ -371,6 +371,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Десен бутон за повече възможности.',
         'PanelImageTitle' => 'Избор на изображение',
+        'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Избор на файл',
 
         'PanelFrom' =>'From',
@@ -407,6 +408,7 @@ http://le-spektre.org',
         'PluginsFrame' => 'Сайт за търсене',
         'PluginsLogo' => 'Лого',
         'PluginsName' => 'Име',
+        'PluginsSearchFields' => 'Search fields',
         'PluginsAuthor' => 'Автор',
         'PluginsLang' => 'Език',
         'PluginsUseSite' => 'Използване на избрания сайт за бъдещи търсения',
@@ -473,6 +475,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
+        'PropertiesFile' => 'File Information',
+        'PropertiesFilePath' => 'Full path',
+        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesFileSize' => 'Size',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Collection properties',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
