@@ -61,9 +61,10 @@
         Serie => 'Sbírka',
         Rank => 'Pořadí',
         Subtitles => 'Titulky',
+        Added => 'Přidáno',
 
-        PanelSeenYes => 'Viděl',
-        PanelSeenNo => 'Neviděl',
+        SeenYes => 'Shlédnuto',
+        SeenNo => 'Neshlédnuto',
 
         AgeUnrated => 'Nestanoven',
         AgeAll => 'Pro všechny',
@@ -81,6 +82,8 @@
         FilterSeenNo => '_Neshlédnuté filmy',
         FilterSeenYes => '_Shlédnuté filmy',
         FilterRatingSelect => '_Hodnocení minimálně...',
+
+        ExtractSize => 'Velikost',
      );
 }
 
