@@ -71,6 +71,9 @@ K rozlišení, který server vlastní dané informace, můžete použít
         'InstallOK' => 'OK',
         'InstallMissing' => 'Chybí',
         'InstallMissingFor' => 'Chybí',
+        'InstallCleanDirectory' => 'Odstraňování souborů programu GCstar v adresáři: ',
+        'InstallCopyDirectory' => 'Kopírování souborů do adresáře: ',
+        'InstallCopyDesktop' => 'Kopírování souboru pracovní plochy do: ',		#Copying desktop file in
 
 #Update
         'UpdateUseProxy' => 'Použít Proxy (pokud není potřeba, stiskni enter): ',
@@ -119,7 +122,8 @@ K rozlišení, který server vlastní dané informace, můžete použít
 
         'MenuHelp' => '_Nápověda',
             'MenuHelpContent' => '_Nápověda',
-            'MenuBugReport' => 'Report a _bug',
+            'MenuAllPlugins' => 'Zobrazit _pluginy',
+            'MenuBugReport' => 'Nahlásit _chybu',
             'MenuAbout' => '_O aplikaci GCstar',
     
         'MenuNewWindow' => 'Zobrazit položky v _novém okně',
@@ -206,7 +210,7 @@ http://le-spektre.org',
         'ModelFieldTypeFile' => 'Soubor',
         'ModelFieldParameters' => 'Parametry',
         'ModelFieldHasHistory' => 'Používat historii',
-        'ModelFieldFlat' => 'Display on one line',
+        'ModelFieldFlat' => 'Zobrazit v jedné řadě',
         'ModelFieldStep' => 'Krok přírůstku:',
         'ModelFieldFileFormat' => 'Typ souboru:',
         'ModelFieldFileFile' => 'Prostý soubor',
@@ -295,7 +299,7 @@ http://le-spektre.org',
         'OptionsInternetSettingsGroup' => 'Nastavení',
         'OptionsDisplayInformationGroup' => 'Informační panel',
         'OptionsDisplayArticlesGroup' => 'Členy',
-        'OptionsImagesDisplayGroup' => 'Display',
+        'OptionsImagesDisplayGroup' => 'Zobrazení',
         'OptionsImagesStyleGroup' => 'Styl',
         'OptionsDetailedPreferencesGroup' => 'Předvolby',
         'OptionsFeaturesConveniencesGroup' => 'Nastavení',
@@ -326,10 +330,6 @@ http://le-spektre.org',
 
         'ExtractButton' => 'Informace',
         'ExtractTitle' => 'Informace o video souboru',
-        'ExtractSize' => 'Velikost',
-        'ExtractLength' => 'Délka (v minutách)',
-        'ExtractType' => 'Video formát',
-        'ExtractAudioEncoding' => 'Audio formát',
         'ExtractImport' => 'Použít hodnoty',
 
         'FieldsListOpen' => 'Nahrát seznam polí ze souboru',
@@ -370,6 +370,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Pro zobrazení skutečné velikosti obrázku na něj klikněte.',
         'PanelImageTipMenu' => 'Pod pravým tlačítkem je více voleb.',
         'PanelImageTitle' => 'Vyberte obrázek',
+        'PanelImageNoImage' => 'Bez obrázku',
         'PanelSelectFileTitle' => 'Vyberte soubor',
 
         'PanelFrom' =>'Od',
@@ -402,10 +403,11 @@ http://le-spektre.org',
         'ToolbarGroupByTooltip' => 'Vyberte pole, podle kterého se mají řadit položky seznamu',
         
         'PluginsTitle' => 'Hledat',
-        'PluginsQuery' => 'Query',
+        'PluginsQuery' => 'Dotaz',
         'PluginsFrame' => 'Hledat na serveru',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Jméno',
+        'PluginsSearchFields' => 'Hledat v poli',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Jazyk',
         'PluginsUseSite' => 'Použít vybraný server pro další hledání',
@@ -472,6 +474,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Vlastník',
         'PropertiesEmail' => 'E-mail',
         'PropertiesDescription' => 'Popis',
+        'PropertiesFile' => 'Informace o souboru',
+        'PropertiesFilePath' => 'Úplná cesta',
+        'PropertiesItemsNumber' => 'Počet položek',
+        'PropertiesFileSize' => 'Velikost',
+        'PropertiesFileSizeSymbols' => ['Bytů', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Vlastnosti sbírky',
 
         'MailProgramsTitle' => 'Programy pro odesílání mailů',
         'MailProgramsName' => 'Název',
@@ -490,10 +498,10 @@ http://le-spektre.org',
         'BookmarksPath' => 'Cesta',
         'BookmarksNewFolder' => 'Nový adresář',
 
-        'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
-        'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchType' => 'Typ hledání',
+        'AdvancedSearchTypeAnd' => 'Položky odpovídají všem podmínkám',
+        'AdvancedSearchTypeOr' => 'Položky odpovídají alespoň jedné podmínce',
+        'AdvancedSearchCriteria' => 'Podmínky',
     );
 }
 1;
