@@ -30,7 +30,7 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'CopyPictures' => 'Copy pictures',
+        'CopyPictures' => 'Kopiere Bilder',
      );
 }
 
