@@ -38,13 +38,13 @@
         'Warning' => '<b>Warnung</b>:
         
 Informationen, die Sie (durch Plugins) von Webseiten herunterladen, 
-sind <b>ausschließlich für den persönlichen Gebrauch </b>.
+sind <b>ausschließlich für den persönlichen Gebrauch bestimmt.</b>.
 
-Jede <b>Weiterverbreitung</b> ist ohne die explizite Erlaubnis 
-der Seite <b>verboten</b>.
+Jede <b>Weitergabe</b> ist ohne die explizite Erlaubnis der
+Seitenbetreiber <b>verboten</b>.
 
-Der Button unter den Elementen verweist Sie auf die 
-jeweilige Webseite, von der die Informationen stammen.',
+Der Button unter den Elementen verweist Sie auf die jeweilige
+Webseite, von der die Informationen stammen.',
 
     'AllItemsFiltered' => 'Kein Element erfüllt Ihre Filtereinstellungen.',
         
@@ -53,10 +53,10 @@ jeweilige Webseite, von der die Informationen stammen.',
 	'InstallOptional' => 'Optionale Komponenten',
 	'InstallErrorMissing' => 'Fehler : Die folgenden Komponenten müssen installiert sein: ',
 	'InstallPrompt' => 'Basisverzeichnis für die Installation [/usr/local]: ',
-	'InstallEnd' => 'Ende der Installation',
+	'InstallEnd' => 'Installation beendet',
 	'InstallNoError' => 'Keine Fehler',
 	'InstallLaunch' => 'Um die Anwendung zu verwenden starten Sie ',
-	'InstallDirectory' => 'Basisverzeichnis',
+	'InstallDirectory' => 'Installationsverzeichnis',
 	'InstallTitle' => 'Installation von GCstar',
 	'InstallDependencies' => 'Abhängigkeiten',
     'InstallPath' => 'Pfad',
@@ -64,13 +64,16 @@ jeweilige Webseite, von der die Informationen stammen.',
 	'InstallSelectDirectory' => 'Wählen Sie ein Basisverzeichnis für die Installation',
 	'InstallWithClean' => 'Daten im Installationsverzeichnis löschen',
 	'InstallWithMenu' => 'GCstar zum Anwendungsmenü hinzufügen',
-    'InstallNoPermission' => 'Fehler: Sie haben keine Rechte um im gewählten Verzeichnis zu schreiben',
-	'InstallMissingMandatory' => 'Notwendige Abhängigkeiten fehlen auf ihrem System. Sie müssen diese auf ihrem System ergänzen, um GCstar installieren zu können.',
-	'InstallMissingOptional' => 'Einige unten aufgelistete optionale Abhängigkeiten fehlen. GCstar kann installiert werden, aber einige Features werden nicht verfügbar sein.',
-	'InstallMissingNone' => 'Es gibt keine fehlenden Abhängigkeiten. Sie können mit der Installation fortfahren.',
+    'InstallNoPermission' => 'Fehler: Sie haben keine Schreibrechte im gewählten Verzeichnis',
+	'InstallMissingMandatory' => 'Abhängigkeiten können auf Ihrem System nicht gelöst werden. Sie müssen diese ergänzen, um GCstar installieren zu können.',
+	'InstallMissingOptional' => 'Einige unten aufgelistete optionale Abhängigkeiten können nicht gelöst werden. GCstar kann installiert werden, aber einige Eigenschaften werden nicht verfügbar sein.',
+	'InstallMissingNone' => 'Es gibt keine ungelösten Abhängigkeiten. Sie können mit der Installation fortfahren.',
 	'InstallOK' => 'OK',
 	'InstallMissing' => 'Fehlt',
 	'InstallMissingFor' => 'Fehlt für',
+    'InstallCleanDirectory' => 'Entferne GCstar\'s Dateien im Verzeichnis: ',
+    'InstallCopyDirectory' => 'Kopiere Dateien in Verzeichnis: ',
+    'InstallCopyDesktop' => 'Kopiere Desktop Datei nach: ',
 
 #Update
     'UpdateUseProxy' => 'Proxy (drücken Sie Enter für keinen): ',
@@ -85,7 +88,7 @@ jeweilige Webseite, von der die Informationen stammen.',
 	'SplashDone' => 'Fertig',
 
 #Import from GCfilms
-    'GCfilmsImportQuestion' => 'Es scheint, als ob Sie bereits GCfilms benutzt haben. Was möchten Sie von GCfilms nach GCstar importieren (es wird keine Daten von GCfilms ändern - für den Fall dass Sie es weiterhin nutzen wollen)?',
+    'GCfilmsImportQuestion' => 'Sie scheinen bereits GCfilms benutzt zu haben. Was möchten Sie von GCfilms nach GCstar importieren (die Daten von GCfilms bleiben erhalten)?',
     'GCfilmsImportOptions' => 'Einstellungen',
     'GCfilmsImportData' => 'Filmliste',
 
@@ -104,7 +107,7 @@ jeweilige Webseite, von der die Informationen stammen.',
 		'MenuEditLockItems' => 'Liste _sperren',
 
 	'MenuDisplay' => '_Filter',
-        'MenuAdvancedSearch' => 'A_dvanced Search',
+        'MenuAdvancedSearch' => 'Erweiterte Suche',
 		'MenuViewAllItems' => '_Alle Elemente anzeigen',
 		'MenuNoFilter' => '_Alle',
 
@@ -119,7 +122,8 @@ jeweilige Webseite, von der die Informationen stammen.',
 
 	'MenuHelp' => '_Hilfe',
     	'MenuHelpContent' => '_Hilfe',
-        'MenuBugReport' => 'Report a _bug',
+        'MenuAllPlugins' => 'Zeige _Plugins',
+        'MenuBugReport' => '_Programmfehler melden',
 		'MenuAbout' => '_Über GCstar',
 
 	'MenuNewWindow' => 'Elemente in neuem _Fenster zeigen',
@@ -173,7 +177,7 @@ Adolfo González : Programmierer',
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Deutsche Übersetzung von Gabriel Meier und FrenkX',
-        'AboutDesign' => 'Logo und webdesign von le Spektre',
+        'AboutDesign' => 'Logo und Webdesign von le Spektre',
         
         'ToolbarRandom' => 'Heute Abend',
         
@@ -195,7 +199,7 @@ http://le-spektre.org',
         'ModelFieldMax' => 'Maximum:',
         'ModelFieldList' => 'Wertliste:',
         'ModelFieldListLegend' => '<i>Kommasepariert</i>',
-        'ModelFieldTypeShortText' => 'Kurztext',
+        'ModelFieldTypeShortText' => 'Kurzer Text',
         'ModelFieldTypeLongText' => 'Langer Text',
         'ModelFieldTypeYesNo' => 'Ja/Nein',
         'ModelFieldTypeNumber' => 'Zahl',
@@ -241,12 +245,12 @@ http://le-spektre.org',
 
         'ResultsTitle' => 'Wählen Sie einen Eintrag',
         'ResultsNextTip' => 'Auf der nächsten Seite suchen',
-        'ResultsPreview' => 'Preview',
+        'ResultsPreview' => 'Vorschau',
         
         'OptionsTitle' => 'Einstellungen',
         'OptionsBrowser' => 'Web-Browser',
         'OptionsPlayer' => 'Video-Player',
-        'OptionsAudio' => 'Audio-player',
+        'OptionsAudio' => 'Audio-Player',
         'OptionsImages' => 'Verzeichnis für Bilder',
         'OptionsUseRelativePaths' => 'Relative Pfade für Bilder verwenden',
         'OptionsLayout' => 'Layout',
@@ -269,9 +273,9 @@ http://le-spektre.org',
         'OptionsMain' => 'Allgemein',
         'OptionsPaths' => 'Pfade',
         'OptionsInternet' => 'Internet',
-        'OptionsConveniences' => 'Features',
+        'OptionsConveniences' => 'Eigenschaften',
         'OptionsDisplay' => 'Anzeige',
-        'OptionsToolbar' => 'Toolbar',
+        'OptionsToolbar' => 'Werkzeugleiste',
         'OptionsToolbars' => {0 => 'Keine', 1 => 'Klein', 2 => 'Gross'},
         'OptionsToolbarPosition' => 'Position',
         'OptionsToolbarPositions' => {0 => 'Oben', 1 => 'Unten', 2 => 'Links', 3 => 'Rechts'},
@@ -326,10 +330,6 @@ http://le-spektre.org',
 
         'ExtractButton' => 'Information',
         'ExtractTitle' => 'Dateiinformationen',
-        'ExtractSize' => 'Größe',
-        'ExtractLength' => 'Laufzeit (minuten)',
-        'ExtractType' => 'Videoformat',
-        'ExtractAudioEncoding' => 'Audioformat',
         'ExtractImport' => 'Werte verwenden',
 
         'FieldsListOpen' => 'Lade Liste von Feldern aus Datei',
@@ -370,6 +370,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Klicken, um das Bild in Orginalgröße anzuzeigen.',
         'PanelImageTipMenu' => ' Rechtsklick für weitere Optionen.',
         'PanelImageTitle' => 'Wählen Sie ein Bild',
+        'PanelImageNoImage' => 'kein Bild',
         'PanelSelectFileTitle' => 'Datei auswählen',
 
         'PanelFrom' =>'From',
@@ -406,6 +407,7 @@ http://le-spektre.org',
         'PluginsFrame' => 'Eine Website durchsuchen',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Name',
+        'PluginsSearchFields' => 'Suchfelder',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Sprache',
         'PluginsUseSite' => 'Gewählte Seite für zukünftige Suchen verwenden',
@@ -453,7 +455,7 @@ http://le-spektre.org',
         'MultiSiteTitle' => 'Seite für Internetrecherche',
         'MultiSiteUnused' => 'Nicht verwendete Plugins',
         'MultiSiteUsed' => 'Zu verwendende Plugins',
-        'MultiSiteLang' => 'Deutsche Plugins verwenden',
+        'MultiSiteLang' => 'sprachige eutschsprachige Plugins verwenden',
         'MultiSiteEmptyError' => 'Die Liste der zu verwendenden Plugins ist leer!',
         'MultiSiteClear' => 'Liste löschen',
 
@@ -472,6 +474,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Besitzer',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Beschreibung',
+        'PropertiesFile' => 'Dateieigenschaften',
+        'PropertiesFilePath' => 'Vollständiger Pfad',
+        'PropertiesItemsNumber' => 'Anzahl enthaltener Elemente',
+        'PropertiesFileSize' => 'Dateigröße',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Eigenschaften der Sammlung',
 
         'MailProgramsTitle' => 'Programm zum senden von Emails',
         'MailProgramsName' => 'Name',
@@ -490,10 +498,10 @@ http://le-spektre.org',
         'BookmarksPath' => 'Pfad',
         'BookmarksNewFolder' => 'Neues Verzeichnis',
 
-        'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
-        'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchType' => 'Art der Suche',
+        'AdvancedSearchTypeAnd' => 'Elemente, die alle Kriterien erfüllen',
+        'AdvancedSearchTypeOr' => 'Elemente, die mindestens ein Kriterium erfüllen',
+        'AdvancedSearchCriteria' => 'Suchkriterium',
     );
 }
 1;
