@@ -61,6 +61,7 @@
         Serie => 'Serie',
         Rank => 'Rank',
         Subtitles => 'Subtitles',
+        Added => 'Add date',
 
         SeenYes => 'Viewed',
         SeenNo => 'Not viewed',
@@ -81,6 +82,8 @@
         FilterSeenNo => '_Not Yet Viewed',
         FilterSeenYes => '_Already Viewed',
         FilterRatingSelect => 'Rating At _Least...',
+
+        ExtractSize => 'Size',
      );
 }
 
