@@ -52,8 +52,8 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'InstallDirInfo' => 'Instalar en ',
         'InstallMandatory' => 'Componentes obligatorios',
         'InstallOptional' => 'Componentes opcionales',
-        'InstallErrorMissing' => 'Error : los componentes siguientes deben instalarse : ',
-        'InstallPrompt' => 'Directorio predeterminado para la instalación [/usr/local] : ',
+        'InstallErrorMissing' => 'Error: los componentes siguientes deben instalarse: ',
+        'InstallPrompt' => 'Directorio predeterminado para la instalación [/usr/local]: ',
         'InstallEnd' => 'Fin de la instalación',	
         'InstallNoError' => 'Ningún error',
         'InstallLaunch' => 'Para utilizar la aplicación, ejecute ',
@@ -72,6 +72,9 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'No disponible',
         'InstallMissingFor' => 'No disponible por',
+        'InstallCleanDirectory' => 'Eliminado ficheros de GCstar en el diretorio: ',
+        'InstallCopyDirectory' => 'Copiando ficheros en el directorio: ',
+        'InstallCopyDesktop' => 'Copiando el fichero .desktop en: ',
         
 #Update
         'UpdateUseProxy' => 'Proxy a usar (si no usa ninguno presione Enter): ',
@@ -82,70 +85,71 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
 #Splash
         'SplashInit' => 'Inicialización',
         'SplashLoad' => 'Cargando películas',
-        'SplashDisplay' => 'Displaying Collection',
+        'SplashDisplay' => 'Mostrando Colección',
         'SplashDone' => 'Listo',
 
 #Import from GCfilms
-        'GCfilmsImportQuestion' => 'It seems you were using GCfilms before. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
-        'GCfilmsImportOptions' => 'Settings',
-        'GCfilmsImportData' => 'Movies list',
+        'GCfilmsImportQuestion' => 'Parece que antes usaba GCfilms. ¿Qué quiere importar desde GCfilms a GCstar? (No afectará a GCfilms, si todavía quiere seguir usándolo)',
+        'GCfilmsImportOptions' => 'Preferencias',
+        'GCfilmsImportData' => 'Listado de películas',
 
 #Menus
-        'MenuFile' => '_Películas',	
+        'MenuFile' => '_Archivo',	
             'MenuNewList' => '_Nueva lista de películas',	
             'MenuHistory' => '_Ficheros abiertos recientemente',
-            'MenuLend' => '_Ver las películas prestadas',	
+            'MenuLend' => '_Ver películas prestadas',	
             'MenuImport' => '_Importar',
             'MenuExport' => '_Exportar',	
 
         'MenuEdit'  => '_Editar',
        	    'MenuDuplicate' => '_Duplicar película',
             'MenuEditDeleteCurrent' => '_Eliminar película actual',
-            'MenuEditFields' => '_Change collection fields',
+            'MenuEditFields' => '_Cambiar campos de la colección',
             'MenuEditLockItems' => '_Bloquear la información',
         
         'MenuDisplay' => '_Visualización',        
-            'MenuAdvancedSearch' => 'A_dvanced Search',
+            'MenuAdvancedSearch' => 'Búsqueda _avanzada',
             'MenuViewAllItems' => '_Ver todas las películas',	
-            'MenuNoFilter' => 'Todas las películas',	
+            'MenuNoFilter' => '_Todas las películas',	
 
         'MenuConfiguration' => '_Configuración',	
             'MenuDisplayOptions' => '_Información a mostrar',
             'MenuBorrowers' => 'Pres_tatarios',	
             'MenuGenresConversion' => 'Conversión de _géneros',
 
-        'MenuBookmarks' => 'My _Collections',
-            'MenuBookmarksAdd' => '_Add current collection',
-            'MenuBookmarksEdit' => '_Edit bookmarked collections',
+        'MenuBookmarks' => 'Mis _Colecciones',
+            'MenuBookmarksAdd' => '_Añadir colección actual',
+            'MenuBookmarksEdit' => '_Editar colecciones favoritas',
 
         'MenuHelp' => '_?',
             'MenuHelpContent' => '_?',
-            'MenuBugReport' => 'Report a _bug',
+            'MenuAllPlugins' => 'Ver _complementos',
+            'MenuBugReport' => 'Comunicar un _fallo',
             'MenuAbout' => 'A propósito de _GCstar',	
 
         'MenuNewWindow' => 'Mostrar películas en una nueva ventana',
         
-        'ContextExpandAll' => 'Expand all',
-        'ContextCollapseAll' => 'Collapse all',
+        'ContextExpandAll' => 'Expandir todo',
+        'ContextCollapseAll' => 'Contraer todo',
 
-        'DialogEnterNumber' => 'Please enter value',
+        'DialogEnterNumber' => 'Introduzca un valor por favor',
 
         'RemoveConfirm' => '¿Realmente quiere eliminar esta película?',  
-        'DefaultNewItem' => 'New item',
+        'DefaultNewItem' => 'Elemento nuevo',
         'NewItemTooltip' => 'Añadir una nueva película',
         'NoItemFound' => 'Ninguna película encontrada. ¿Quiere intentar una nueva búsqueda en otro sitio?',
         'OpenList' => '¿Qué lista de películas abrir?',	
         'SaveList' => '¿En qué fichero quiere guardar el listado?',	
         'SaveListTooltip' => 'Guardar el listado actual', 
         'SaveCurrentList' => 'Primero debe eligir en que fichero quiere guardar el listado actual',
-        'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
-        'SaveDontSave' => 'Don\'t save',
+        'SaveUnsavedChanges' => 'Hay cambios sin guardar en su colección. ¿Quiere guardarlos?',
+        'SaveDontSave' => 'No guardar',
         'PreferencesTooltip' => 'Cambiar sus preferencias',
         'ViewTooltip' => 'Cambiar el tipo de lista',
         'PlayTooltip' => 'Reproducir archivo de video asociado a la película',
         
-        'StatusSave' => 'Saving...',
-        'StatusLoad' => 'Loading...',
+        'StatusSave' => 'Guardando...',
+        'StatusLoad' => 'Cargando...',
         'StatusSearch' => 'Búsqueda en curso...',
         'StatusGetInfo' => 'Descargando la información...',
         'StatusGetImage' => 'Descarga a distancia de la imagen...',	
@@ -165,7 +169,7 @@ puede usar <b>el botón situado debajo de los detalles de la película</b>.',
         'RandomOkTip'=> 'Aceptar esta película',
                         
         'AboutTitle' => 'A propósito de GCstar',
-        'AboutDesc' => 'Gtk2 Catálogo de Películas',
+        'AboutDesc' => 'Gestión de Colecciones',
         'AboutVersion' => 'Versión',
         'AboutTeam' => 'Equipo',
         'AboutWho' => 'Tian : Gestión del proyecto, Programación
@@ -178,96 +182,96 @@ http://le-spektre.org',
         
         'ToolbarRandom' => 'Esta noche',
 
-        'ModelsSelect' => 'Select a collection type',
-        'ModelsPersonal' => 'Personal models',
-        'ModelsDefault' => 'Default models',
-        'ModelsList' => 'Collection definition',
-        'ModelSettings' => 'Collection settings',
-        'ModelNewType' => 'New collection type',
-        'ModelName' => 'Name of the collection type:',
-        'ModelNewField' => 'New field',
-        'ModelFieldInformation' => 'Information',
-        'ModelFieldName' => 'Label:',
-        'ModelFieldType' => 'Type:',
-        'ModelFieldGroup' => 'Group:',
-        'ModelFieldValues' => 'Values',
-        'ModelFieldInit' => 'Default:',
-        'ModelFieldMin' => 'Minimum:',
-        'ModelFieldMax' => 'Maximum:',
-        'ModelFieldList' => 'Values list:',
-        'ModelFieldListLegend' => '<i>Comma separated</i>',
-        'ModelFieldTypeShortText' => 'Short text',
-        'ModelFieldTypeLongText' => 'Long text',
-        'ModelFieldTypeYesNo' => 'Yes/No',
-        'ModelFieldTypeNumber' => 'Number',
-        'ModelFieldTypeDate' => 'Date',
-        'ModelFieldTypeOptions' => 'Pre-defined values list',
-        'ModelFieldTypeImage' => 'Image',
-        'ModelFieldTypeSingleList' => 'Simple list',
-        'ModelFieldTypeFile' => 'File',
-        'ModelFieldParameters' => 'Parameters',
-        'ModelFieldHasHistory' => 'Use an history',
-        'ModelFieldFlat' => 'Display on one line',
-        'ModelFieldStep' => 'Increment step:',
-        'ModelFieldFileFormat' => 'File format:',
-        'ModelFieldFileFile' => 'Simple file',
-        'ModelFieldFileImage' => 'Image',
+        'ModelsSelect' => 'Seleccionar un tipo de colección',
+        'ModelsPersonal' => 'Modelos personales',
+        'ModelsDefault' => 'Modelos predefinidos',
+        'ModelsList' => 'Definición de la colección',
+        'ModelSettings' => 'Preferencias de la colección',
+        'ModelNewType' => 'Nuevo tipo de colección',
+        'ModelName' => 'Nombre del tipo de colección:',
+        'ModelNewField' => 'Nuevo campo',
+        'ModelFieldInformation' => 'Información',
+        'ModelFieldName' => 'Etiqueta:',
+        'ModelFieldType' => 'Tipo:',
+        'ModelFieldGroup' => 'Grupo:',
+        'ModelFieldValues' => 'Valores',
+        'ModelFieldInit' => 'Predeterminado:',
+        'ModelFieldMin' => 'Mínimo:',
+        'ModelFieldMax' => 'Máximo:',
+        'ModelFieldList' => 'Lista de valores:',
+        'ModelFieldListLegend' => '<i>Separados por comas</i>',
+        'ModelFieldTypeShortText' => 'Texto corto',
+        'ModelFieldTypeLongText' => 'Texto largo',
+        'ModelFieldTypeYesNo' => 'Si/No',
+        'ModelFieldTypeNumber' => 'Número',
+        'ModelFieldTypeDate' => 'Fecha',
+        'ModelFieldTypeOptions' => 'Lista de valores prefedinidos',
+        'ModelFieldTypeImage' => 'Imagen',
+        'ModelFieldTypeSingleList' => 'Lista simple',
+        'ModelFieldTypeFile' => 'Fichero',
+        'ModelFieldParameters' => 'Parámetros',
+        'ModelFieldHasHistory' => 'Usar historial',
+        'ModelFieldFlat' => 'Mostrar en una línea',
+        'ModelFieldStep' => 'Paso de incremento:',
+        'ModelFieldFileFormat' => 'Formato de fichero:',
+        'ModelFieldFileFile' => 'Fichero simple',
+        'ModelFieldFileImage' => 'Imagen',
         'ModelFieldFileVideo' => 'Video',
         'ModelFieldFileAudio' => 'Audio',
-        'ModelFieldFileProgram' => 'Program',
+        'ModelFieldFileProgram' => 'Programa',
         'ModelFieldFileUrl' => 'URL',
-        'ModelOptionsFields' => 'Fields to use',
-        'ModelOptionsFieldsAuto' => 'Automatic',
-        'ModelOptionsFieldsNone' => 'None',
-        'ModelOptionsFieldsTitle' => 'As title',
-        'ModelOptionsFieldsId' => 'As identifier',
-        'ModelOptionsFieldsCover' => 'As cover',
-        'ModelOptionsFieldsPlay' => 'For Play button',
-        'ModelCollectionSettings' => 'Collection settings',
-        'ModelCollectionSettingsLending' => 'Items could be borrowed',
-        'ModelFilterActivated' => 'Should be in search box',
-        'ModelFilterComparison' => 'Comparison',
-        'ModelFilterContain' => 'Contains',
-        'ModelFilterRange' => 'Range',
-        'ModelFilterNumeric' => 'Comparison is numeric',
-        'ModelFilterQuick' => 'Create a quick filter',
-        'ModelTooltipName' => 'Use a name to re-use this model for many collections. If empty, the settings will be directly stored in the collection itself',
-        'ModelTooltipLabel' => 'The field name as it will be displayed',
-        'ModelTooltipGroup' => 'Used to group fields. Items with no value here will be in a default group',
-        'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
-        'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
-        'ModelTooltipLending' => 'This will add some fields to manage lendings',
-        'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
-        'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
+        'ModelOptionsFields' => 'Campos a usar',
+        'ModelOptionsFieldsAuto' => 'Automático',
+        'ModelOptionsFieldsNone' => 'Ninguno',
+        'ModelOptionsFieldsTitle' => 'Como título',
+        'ModelOptionsFieldsId' => 'Como identificador',
+        'ModelOptionsFieldsCover' => 'Como portada',
+        'ModelOptionsFieldsPlay' => 'Como botón de Reproducir',
+        'ModelCollectionSettings' => 'Preferencias de la colección',
+        'ModelCollectionSettingsLending' => 'Los elementos se pueden prestar',
+        'ModelFilterActivated' => 'Debe aparecer en la caja de búsqueda',
+        'ModelFilterComparison' => 'Comparación',
+        'ModelFilterContain' => 'Contiene',
+        'ModelFilterRange' => 'Rango',
+        'ModelFilterNumeric' => 'Comparación numérica',
+        'ModelFilterQuick' => 'Crear un filtro rápido',
+        'ModelTooltipName' => 'Usar un nombre para reutilizar este modelo para otras colecciones. Si lo deja vacío, las preferencias se guardatán en la propia colección',
+        'ModelTooltipLabel' => 'El nombre del campo como será mostrado',
+        'ModelTooltipGroup' => 'Usado para agrupar los campos. Los elementos sin calor aparecerán en el grupo por defecto',
+        'ModelTooltipHistory' => '¿Deberían almacenarse los valores introducidos anteriormente en una lista asociada al campo?',
+        'ModelTooltipFormat' => 'El formato se usa para determinar la acción para abrir  el fichero al pulsar el botón de Reproducir',
+        'ModelTooltipLending' => 'Se añadirán algunos campos para administrar los préstamos',
+        'ModelTooltipNumeric' => '¿Se deberían considerar los valores como números para las comparaciones?',
+        'ModelTooltipQuick' => 'Esto añadirá un submenu dentro del menu de Filtros',
 
         'ResultsTitle' => 'Elija una película',
         'ResultsNextTip' => 'Buscar en el siguiente sitio',
-        'ResultsPreview' => 'Preview',
+        'ResultsPreview' => 'Previsualizar',
 
         'OptionsTitle' => 'Preferencias',
         'OptionsBrowser' => 'Navegador de Internet',
         'OptionsPlayer' => 'Reproductor de video',
-        'OptionsAudio' => 'Audio player',
+        'OptionsAudio' => 'Reproductor de audio',
         'OptionsImages' => 'Directorio de imágenes', 	
         'OptionsUseRelativePaths' => 'Usar rutas relativas para las imágenes',
-        'OptionsLayout' => 'Disposición',		
+        'OptionsLayout' => 'Disposición',	
         'OptionsStatus' => 'Barra de estado',	
         'OptionsWarning' => 'Cuidado : Los cambios efectuados en este pestaña no se tendrán en cuenta hasta reiniciar la aplicación', 
         'OptionsRemoveConfirm' => 'Pedir confirmación antes de eliminar',
         'OptionsAutoSave' => 'Protección automática de la lista de películas',
-        'OptionsAutoLoad' => 'Load previous collection on startup',
-        'OptionsSplash' => 'Mostrar la pantalla de arranque', 
-        'OptionsImagesTitle' => 'Elija un directorio',	
+        'OptionsAutoLoad' => 'Cargar la colección anterior en el inicio',
+        'OptionsSplash' => 'Mostrar la pantalla de arranque',
+        'OptionsImagesTitle' => 'Elija un directorio',
         'OptionsProgramTitle' => 'Elija el programa que debe utilizarse',
         'OptionsPlugins' => 'Sitio para descargar las fichas',
-        'OptionsAskPlugins' => 'Preguntar',		
+        'OptionsAskPlugins' => 'Preguntar',
         'OptionsPluginsMulti' => 'Varios sitios',
         'OptionsPluginsMultiAsk' => 'Preguntar (Algunos sitios)',
-        'OptionsPluginsList' => 'Definir la lista',		
-        'OptionsAskImport' => 'Elegir los campos que deben importarse',	
-        'OptionsProxy' => 'Utilizar un proxy',	
-        'OptionsMain' => 'Principal',	
-        'OptionsLang' => 'Idioma',	
+        'OptionsPluginsList' => 'Definir la lista',
+        'OptionsAskImport' => 'Elegir los campos que deben importarse',
+        'OptionsProxy' => 'Utilizar un proxy',
+        'OptionsMain' => 'Principal',
+        'OptionsLang' => 'Idioma',
         'OptionsPaths' => 'Directorios',
         'OptionsInternet' => 'Internet',
         'OptionsConveniences' => 'Opciones',	
@@ -290,22 +294,22 @@ http://le-spektre.org',
         'OptionsClearHistory' => 'Limpiar el historial',
         'OptionsStyle' => 'Piel',
         'OptionsDontAsk' => 'No preguntar nunca más',
-        'OptionsPathProgramsGroup' => 'Applications',
-        'OptionsPathImagesGroup' => 'Images',
-        'OptionsInternetDataGroup' => 'Data import',
-        'OptionsInternetSettingsGroup' => 'Settings',
-        'OptionsDisplayInformationGroup' => 'Information display',
-        'OptionsDisplayArticlesGroup' => 'Articles',
-        'OptionsImagesDisplayGroup' => 'Display',
-        'OptionsImagesStyleGroup' => 'Style',
-        'OptionsDetailedPreferencesGroup' => 'Preferences',
-        'OptionsFeaturesConveniencesGroup' => 'Conveniences',
-        'OptionsPicturesFormat' => 'Prefix to use for pictures:',
+        'OptionsPathProgramsGroup' => 'Aplicaciones',
+        'OptionsPathImagesGroup' => 'Imágenes',
+        'OptionsInternetDataGroup' => 'Importar datos',
+        'OptionsInternetSettingsGroup' => 'Preferencias',
+        'OptionsDisplayInformationGroup' => 'Mostrar información',
+        'OptionsDisplayArticlesGroup' => 'Artículos',
+        'OptionsImagesDisplayGroup' => 'Mostrar',
+        'OptionsImagesStyleGroup' => 'Estilo',
+        'OptionsDetailedPreferencesGroup' => 'Preferencias',
+        'OptionsFeaturesConveniencesGroup' => 'conveniencias',
+        'OptionsPicturesFormat' => 'Prefijo para uasr en las imágenes:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
-        'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
-        'OptionsConfigureMailers' => 'Configure mailing programs',
+        'OptionsPicturesFormatTitle' => 'Título o nombre del elemento asociado',
+        'OptionsConfigureMailers' => 'Configurar programas de envío correo',
 		       
-		'ImagesOptionsButton' => 'Preferencias',
+	'ImagesOptionsButton' => 'Preferencias',
         'ImagesOptionsTitle' => 'Preferencias para el listado de imágenes',
         'ImagesOptionsSelectColor' => 'Elija un color',
         'ImagesOptionsBg' => 'Fondo',
@@ -319,23 +323,19 @@ http://le-spektre.org',
 
         'DetailedOptionsTitle' => 'Preferencias del listado detallado',
         'DetailedOptionsImageSize' => 'Tamaño de la imagen',
-        'DetailedOptionsGroupItems' => 'Group items by',
+        'DetailedOptionsGroupItems' => 'Agrupar elementos por',
         'DetailedOptionsFields' => 'Seleccione los campos a mostrar',
-		'DetailedOptionsMasterOption' => 'Group master is',
-		'DetailedOptionsMasterGenerated' => 'Auto generated',
-		'DetailedOptionsMasterOrdered' => 'Determined by',
+	'DetailedOptionsMasterOption' => 'Elemento principal del grupo',
+	'DetailedOptionsMasterGenerated' => 'Autogenerado',
+	'DetailedOptionsMasterOrdered' => 'Determinado por',
 
         'ExtractButton' => 'Información',
         'ExtractTitle' => 'Información del Fichero de Video',
-        'ExtractSize' => 'Tamaño',
-        'ExtractLength' => 'Duración (minutos)',
-        'ExtractType' => 'Formato de Video',
-        'ExtractAudioEncoding' => 'Formato de Audio',
         'ExtractImport' => 'Usar valores',
 
-        'FieldsListOpen' => 'Load a fields list from a file',
-        'FieldsListSave' => 'Save fields list to a file',
-        'FieldsListError' => 'This fields list cannot be used with this kind of collection',
+        'FieldsListOpen' => 'Leer los campos de la lista desde un fichero',
+        'FieldsListSave' => 'Guardar los campos de la lista a un fichero',
+        'FieldsListError' => 'Estos campor no se pueden usar con este tipo de colección',
 
         'ExportTitle' => 'Exportar el listado de películas',	
         'ExportFilter' => 'Exportar sólo las películas mostradas',
@@ -344,7 +344,7 @@ http://le-spektre.org',
         'ExportWithPictures' => 'Copiar las imágenes a un subdirectorio',
 
         'ImportListTitle' => 'Importar otro listado de películas',
-        'ImportExportData' => 'Data',
+        'ImportExportData' => 'Datos',
         'ImportExportFile' => 'Fichero',	 
         'ImportExportSave' => '¿En qué fichero guardar?', 	
         'ImportExportFieldsUnused' => 'Campos sin utilizar',
@@ -368,13 +368,14 @@ http://le-spektre.org',
         'PanelSearchButton' => 'Descargar',
         'PanelSearchTip' => 'Buscar información relativa a la película',
         'PanelImageTipOpen' => 'Pulse en la imagen para elegir otra.',
-        'PanelImageTipView' => 'Click on the picture to view it in real size.',
-        'PanelImageTipMenu' => ' Click con el botón derecho para mas opciones.',
+        'PanelImageTipView' => 'Pulse en la imagen para verla en su tamaño real...',
+        'PanelImageTipMenu' => 'Click con el botón derecho para mas opciones.',
         'PanelImageTitle' => 'Seleccionar una imagen',	
+        'PanelImageNoImage' => 'Sin imagen',
         'PanelSelectFileTitle' => 'Seleccione un fichero',
 
-        'PanelFrom' =>'From',
-        'PanelTo' =>'To',
+        'PanelFrom' =>'De',
+        'PanelTo' =>'Para',
 
         'PanelWeb' => 'Ver la ficha en Internet',
         'PanelWebTip' => 'Ver la ficha de la película en Internet',	
@@ -393,16 +394,21 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Prestada',
         'PanelLendedNo' => 'Disponible',
 
+        'CheckUndef' => 'Cualquiera',
+        'CheckYes' => 'Si',
+        'CheckNo' => 'No',
+
         'ToolbarAll' => 'Ver todas',	
         'ToolbarAllTooltip' => 'Ver todas las películas',	
-        'ToolbarGroupBy' => 'Group by',
-        'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarGroupBy' => 'Agrupar por',
+        'ToolbarGroupByTooltip' => 'Seleccionar el campo a usar para agrupos los elementos en la lista',
 
         'PluginsTitle' => 'Buscar una película',	
-        'PluginsQuery' => 'Query',
+        'PluginsQuery' => 'Búsqueda',
         'PluginsFrame' => 'Sitio donde buscar ',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Nombre',
+        'PluginsSearchFields' => 'Campos de búsqueda',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Idioma',
         'PluginsUseSite' => 'Usar sitio seleccionado para futuras búsquedas',
@@ -420,27 +426,27 @@ http://le-spektre.org',
         'BorrowersNotice2' => '%2 se sustituirá por el título de la película',	
         'BorrowersNotice3' => '%3 se sustituirá por la fecha del préstamo',	
       
-        'BorrowersImportTitle' => 'Import borrowers information',
-        'BorrowersImportType' => 'File format:',
-        'BorrowersImportFile' => 'File:',
+        'BorrowersImportTitle' => 'Importar información de prestatarios',
+        'BorrowersImportType' => 'Formato del fichero:',
+        'BorrowersImportFile' => 'Fichero:',
 
         'BorrowedTitle' => 'Películas prestadas',	
         'BorrowedDate' => 'Desde el',	
         
         'MailTitle' => 'Enviar un correo electrónico',	
-        'MailFrom' => 'De : ',	
-        'MailTo' => 'A : ',	
-        'MailSubject' => 'Tema : ',
+        'MailFrom' => 'De: ',	
+        'MailTo' => 'Para: ',	
+        'MailSubject' => 'Tema: ',
         'MailSmtpError' => 'Problema de conexión con el servidor',	
         'MailSendmailError' => 'Problema ejecutando sendmail',	
 
         'SearchTooltip' => 'Buscar en todas las películas',	
         'SearchTitle' => 'Búsqueda de películas',	
                 
-        'QueryReplaceField' => 'Field to replace',
+        'QueryReplaceField' => 'Campo a sustituir',
         'QueryReplaceOld' => 'Nombre actual',	
         'QueryReplaceNew' => 'Nuevo nombre',	
-        'QueryReplaceLaunch' => 'Replace',
+        'QueryReplaceLaunch' => 'Sustituir',
         
         'ImportWindowTitle' => 'Elegir los campos que deben importarse',	
         'ImportViewPicture' => 'Ver la imagen',		
@@ -465,32 +471,38 @@ http://le-spektre.org',
         'GenresExport' => 'Exportar listado a un fichero',
         'GenresModify' => 'Editar conversión',
 
-        'PropertiesName' => 'Collection name',
-        'PropertiesOwner' => 'Owner',
+        'PropertiesName' => 'Nombre de la colección',
+        'PropertiesOwner' => 'Dueño',
         'PropertiesEmail' => 'Email',
-        'PropertiesDescription' => 'Description',
+        'PropertiesDescription' => 'Descripción',
+        'PropertiesFile' => 'Información del fichero',
+        'PropertiesFilePath' => 'Ruta completa',
+        'PropertiesItemsNumber' => 'Número de elementos',
+        'PropertiesFileSize' => 'Tamaño',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Propiedades de la colección',
 
-        'MailProgramsTitle' => 'Programs for mail sending',
-        'MailProgramsName' => 'Name',
-        'MailProgramsCommand' => 'Command line',
-        'MailProgramsRestore' => 'Restore defaults',
-        'MailProgramsAdd' => 'Add a program',
-        'MailProgramsInstructions' => 'In command line, some substitutions are made:
- %f is replaced with user\'s e-mail address.
- %t is replaced with the recipient address.
- %s is replaced with the subject of the message.
- %b is replaced with the body of the message.',
+        'MailProgramsTitle' => 'Programas para enviar correos',
+        'MailProgramsName' => 'Nombre',
+        'MailProgramsCommand' => 'Linea de comandos',
+        'MailProgramsRestore' => 'Usar predeterminados',
+        'MailProgramsAdd' => 'Añadir un programa',
+        'MailProgramsInstructions' => 'En la linea de comandos se hacen algunas sustituciones:
+ %f se sustituirá por la dirección de e-mail del usuario.
+ %t se sustituirá por la dirección del destinatario.
+ %s se sustituirá por el asunto del mensaje.
+ %b se sustituirá por el cuerpo del mensaje.',
 
-        'BookmarksBookmarks' => 'Bookmarks',
-        'BookmarksFolder' => 'Directory',
-        'BookmarksLabel' => 'Label',
-        'BookmarksPath' => 'Path',
-        'BookmarksNewFolder' => 'New folder',
+        'BookmarksBookmarks' => 'Marcadores',
+        'BookmarksFolder' => 'Directorio',
+        'BookmarksLabel' => 'Etiqueta',
+        'BookmarksPath' => 'Ruta',
+        'BookmarksNewFolder' => 'Nueva carpeta',
 
-        'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
-        'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchType' => 'Tipo de búsqueda',
+        'AdvancedSearchTypeAnd' => 'Elementos que cumplan todos los criterios',
+        'AdvancedSearchTypeOr' => 'Elementos que cunplan al menos un criterio',
+        'AdvancedSearchCriteria' => 'Critero',
     );
 }
 1;
