@@ -73,6 +73,9 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Manquant',
         'InstallMissingFor' => 'Manquant pour',
+        'InstallCleanDirectory' => 'Suppression des fichiers GCstar dans le répertoire : ',
+        'InstallCopyDirectory' => 'Copie des fichiers dans le répertoire : ',
+        'InstallCopyDesktop' => 'Copie du fichier de lancement (.desktop) dans le répertoire : ',
 
 #Update
         'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
@@ -121,6 +124,7 @@ le <b>bouton situé en dessous de sa fiche</b>.',
 
         'MenuHelp' => '_Aide',
             'MenuHelpContent' => '_Contenu',
+            'MenuAllPlugins' => 'Voir les _modules',
             'MenuBugReport' => 'Signaler un _dysfonctionnement',
             'MenuAbout' => 'A _propos de GCstar',
     
@@ -329,10 +333,6 @@ http://le-spektre.org',
 
         'ExtractButton' => 'Informations',
         'ExtractTitle' => 'Informations du fichier vidéo',
-        'ExtractSize' => 'Dimensions',
-        'ExtractLength' => 'Durée (minutes)',
-        'ExtractType' => 'Format vidéo',
-        'ExtractAudioEncoding' => 'Format audio',
         'ExtractImport' => 'Utiliser les valeurs',
 
         'FieldsListOpen' => 'Charger une liste de champs depuis un fichier',
@@ -373,6 +373,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Cliquez sur l\'image pour la voir en taille réelle.',
         'PanelImageTipMenu' => ' Clic droit pour plus d\'options.',
         'PanelImageTitle' => 'Sélectionnez une image',
+        'PanelImageNoImage' => 'Pas d\'image',
         'PanelSelectFileTitle' => 'Sélectionnez un fichier',
 
         'PanelFrom' =>'Entre',
@@ -409,6 +410,7 @@ http://le-spektre.org',
         'PluginsFrame' => 'Site où rechercher',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Nom',
+        'PluginsSearchFields' => 'Champs de recherche',
         'PluginsAuthor' => 'Auteur',
         'PluginsLang' => 'Langue',
         'PluginsUseSite' => 'Utiliser le site sélectionné pour les futures recherches',
@@ -475,6 +477,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Propriétaire',
         'PropertiesEmail' => 'Adresse e-mail',
         'PropertiesDescription' => 'Description',
+        'PropertiesFile' => 'Informations sur le fichier',
+        'PropertiesFilePath' => 'Chemin complet',
+        'PropertiesItemsNumber' => 'Nombre d\'éléments',
+        'PropertiesFileSize' => 'Taille',
+        'PropertiesFileSizeSymbols' => ['octets', 'Ko', 'Mo', 'Go', 'To', 'Po', 'Eo', 'Zo', 'Yo'],
+        'PropertiesCollection' => 'Propriétés de la collection',
 
         'MailProgramsTitle' => 'Programmes pour envoyer des emails',
         'MailProgramsName' => 'Nom',
