@@ -36,8 +36,8 @@
         NewItem => 'Nuovo film',
     
     
-        Id => 'Id',Titolo
-        Title => 'Title',
+        Id => 'Id',
+        Title => 'Titolo',
         Date => 'Data',
         Time => 'Dureta',
         Director => 'Regista',
@@ -61,6 +61,7 @@
         Serie => 'Serie',
         Rank => 'Rank',
         Subtitles => 'Sottotitoli',
+        Added => 'Add date',
 
         SeenYes => 'Item already viewed',
         SeenNo => 'Item not viewed',
@@ -81,6 +82,8 @@
         FilterSeenNo => '_Non visto',
         FilterSeenYes => '_Already Viewed',
         FilterRatingSelect => 'Valutazione maggiore di...',
+
+        ExtractSize => 'Size',
      );
 }
 
