@@ -72,6 +72,9 @@ can use <b>button below film details</b>.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Missing',
         'InstallMissingFor' => 'Missing for',
+        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
+        'InstallCopyDirectory' => 'Copying files in directory: ',
+        'InstallCopyDesktop' => 'Copying desktop file in: ',
         
 #Update
         'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
@@ -120,6 +123,7 @@ can use <b>button below film details</b>.',
 
         'MenuHelp' => '?',
             'MenuHelpContent' => '?',
+            'MenuAllPlugins' => 'View _plugins',
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => 'Circa GCstar',
 
@@ -326,11 +330,7 @@ http://le-spektre.org',
 		'DetailedOptionsMasterOrdered' => 'Determined by',
 
         'ExtractButton' => 'Information',
-        'ExtractTitle' => 'Video file information',
-        'ExtractSize' => 'Size',
-        'ExtractLength' => 'Runtime (minutes)',
-        'ExtractType' => 'Video format',
-        'ExtractAudioEncoding' => 'Audio format',
+        'ExtractTitle' => 'File information',
         'ExtractImport' => 'Use values',
 
         'FieldsListOpen' => 'Load a fields list from a file',
@@ -371,6 +371,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Right click for more options.',
         'PanelImageTitle' => 'Sceglie un\'immagine',
+        'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Select a file',
 
         'PanelFrom' =>'From',
@@ -407,6 +408,7 @@ http://le-spektre.org',
         'PluginsFrame' => 'Cerca un sito',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Name',
+        'PluginsSearchFields' => 'Search fields',
         'PluginsAuthor' => 'Author',
         'PluginsLang' => 'Language',
         'PluginsUseSite' => 'Use selected site for future searches',
@@ -473,6 +475,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
+        'PropertiesFile' => 'File Information',
+        'PropertiesFilePath' => 'Full path',
+        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesFileSize' => 'Size',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Collection properties',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
