@@ -61,6 +61,7 @@
         Serie => 'Kolekcja',
         Rank => 'Ranga',
         Subtitles => 'Napisy',
+        Added => 'Add date',
 
         SeenYes => 'Przeglądane',
         SeenNo => 'Nie przeglądane',
@@ -79,7 +80,10 @@
 
         FilterAudienceAge => 'Widownia',
         FilterSeenNo => 'Nie oglądane',
+        FilterSeenYes => 'Oglądane',
         FilterRatingSelect => 'Notowanie Większe od...',
+
+        ExtractSize => 'Rozmiar',
      );
 }
 
