@@ -72,6 +72,9 @@ można użyć <b>przycisku pod szczegółami</b>.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Brak',
         'InstallMissingFor' => 'Brak',
+        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
+        'InstallCopyDirectory' => 'Copying files in directory: ',
+        'InstallCopyDesktop' => 'Copying desktop file in: ',
 
 #Update
         'UpdateUseProxy' => 'Wybierz serwer proxy (naciśnij Enter aby pominąć): ', 
@@ -120,6 +123,7 @@ można użyć <b>przycisku pod szczegółami</b>.',
 
         'MenuHelp' => 'Pomoc',
             'MenuHelpContent' => 'Pomoc',
+            'MenuAllPlugins' => 'View _plugins',
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => 'O programie',
     
@@ -327,10 +331,6 @@ http://le-spektre.org',
 
         'ExtractButton' => 'Informacje',
         'ExtractTitle' => 'Informacja o pliku wideo',
-        'ExtractSize' => 'Rozmiar',
-        'ExtractLength' => 'Czas trwania (minuty)',
-        'ExtractType' => 'Format obrazu',
-        'ExtractAudioEncoding' => 'Format dźwięku',
         'ExtractImport' => 'Używaj wartości',
 
         'FieldsListOpen' => 'Load a fields list from a file',
@@ -371,6 +371,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Right click for more options.',
         'PanelImageTitle' => 'Wybierz zdjęcie',
+        'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Wybierz plik',
 
         'PanelFrom' =>'From',
@@ -407,6 +408,7 @@ http://le-spektre.org',
         'PluginsFrame' => 'Szukaj strony',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Nazwa',
+        'PluginsSearchFields' => 'Search fields',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Język',
         'PluginsUseSite' => 'Używaj wybranej strony w kolejnych wyszukiwaniach',
@@ -473,6 +475,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
+        'PropertiesFile' => 'File Information',
+        'PropertiesFilePath' => 'Full path',
+        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesFileSize' => 'Size',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Collection properties',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
