@@ -61,6 +61,7 @@
         Serie => 'Colecţie',
         Rank => 'Poziţie',
         Subtitles => 'Subtitrări',
+        Added => 'Add date',
 
         SeenYes => 'Vizionat',
         SeenNo => 'Nevizionat',
@@ -81,6 +82,8 @@
         FilterSeenNo => '_Nevizionat',
         FilterSeenYes => '_Already Viewed',
         FilterRatingSelect => 'Evaluat la cel _puţin...',
+
+        ExtractSize => 'Mărime',
      );
 }
 
