@@ -72,6 +72,9 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Lipsă',
         'InstallMissingFor' => 'Lipsă pentru',
+        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
+        'InstallCopyDirectory' => 'Copying files in directory: ',
+        'InstallCopyDesktop' => 'Copying desktop file in: ',
 
 #Update
         'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
@@ -120,6 +123,7 @@ puteţi folosi <b>butonul aflat sub detaliile filmului</b>.',
 
         'MenuHelp' => '_Ajutor',
             'MenuHelpContent' => '_Ajutor',
+            'MenuAllPlugins' => 'View _plugins',
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => '_Despre GCstar',
     
@@ -327,10 +331,6 @@ http://le-spektre.org',
 
         'ExtractButton' => 'Informaţii',
         'ExtractTitle' => 'Informaţii fişier video',
-        'ExtractSize' => 'Mărime',
-        'ExtractLength' => 'Durată (minute)',
-        'ExtractType' => 'Format video',
-        'ExtractAudioEncoding' => 'Format audio',
         'ExtractImport' => 'Foloseşte valorile',
 
         'FieldsListOpen' => 'Load a fields list from a file',
@@ -371,6 +371,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Clic dreapta pentru mai multe opţiuni.',
         'PanelImageTitle' => 'Selectaţi o imagine',
+        'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Selectaţi un fişier',
 
         'PanelFrom' =>'From',
@@ -407,6 +408,7 @@ http://le-spektre.org',
         'PluginsFrame' => 'Sit pentru căutare',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Nume',
+        'PluginsSearchFields' => 'Search fields',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Limbă',
         'PluginsUseSite' => 'Foloseşte situl selectat pentru viitoarele căutări',
@@ -473,6 +475,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
+        'PropertiesFile' => 'File Information',
+        'PropertiesFilePath' => 'Full path',
+        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesFileSize' => 'Size',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Collection properties',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
