@@ -1,4 +1,4 @@
-{
+﻿{
     package GCLang::RU::GCImport::GCImportAlexandria;
 
     use utf8;
@@ -30,9 +30,9 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'Where' => 'Where should it search',
-        'Default' => 'Default Alexandria\'s directory',
-        'Specified' => 'Directory specified below',
+        'Where' => 'Где следует искать',
+        'Default' => 'Директория Alexandria по-умолчанию',
+        'Specified' => 'Директория указанная ниже',
      );
 }
 
