@@ -1,4 +1,4 @@
-{
+﻿{
     package GCLang::RU::GCImport::GCImportGCstar;
 
     use utf8;
@@ -30,7 +30,7 @@
     our @EXPORT = qw(%lang);
 
     our %lang = (
-        'CopyPictures' => 'Copy pictures',
+        'CopyPictures' => 'Копировать изображения',
      );
 }
 
