@@ -1,4 +1,4 @@
-{
+﻿{
     package GCLang::RU::GCModels::GCgames;
 
     use utf8;
@@ -31,40 +31,40 @@
 
     our %lang = (
     
-        CollectionDescription => 'Video games collection',
-        Items => 'Games',
-        NewItem => 'New game',
+        CollectionDescription => 'Коллекция видео-игр',
+        Items => 'Игры',
+        NewItem => 'Новая игра',
     
-        Id => 'Id',
-        Name => 'Name',
-        Platform => 'Platform',
-        Players => 'Number of players',
-        Released => 'Release Date',
-        Editor => 'Editor',
-        Genre => 'Genre',
-        Box => 'Box picture',
-        Rating => 'Rating',
-        Completion => 'Completion (%)',
-        Description => 'Description',
-        Codes => 'Codes',
-        Code => 'Code',
-        Effect => 'Effect',
-        Secrets => 'Secrets',
-        Location => 'Location',
-        Screenshots => 'Screenshots',
-        Screenshot1 => 'First screenshot',
-        Screenshot2 => 'Second screenshot',
-        Url => 'Web page',
-        Unlockables => 'Unlockables',
-        Unlockable => 'Unlockable',
-        Howto => 'How to unlock',
+        Id => 'Идентификатор',
+        Name => 'Имя',
+        Platform => 'Платформа',
+        Players => 'Количество игроков',
+        Released => 'Дата выпуска',
+        Editor => 'Редактор',
+        Genre => 'Жанр',
+        Box => 'Изображения коробки',
+        Rating => 'Рейтинг',
+        Completion => 'Пройдено (%)',
+        Description => 'Описание',
+        Codes => 'Коды',
+        Code => 'Код',
+        Effect => 'Эффект',
+        Secrets => 'Секреты',
+        Location => 'Расположение',
+        Screenshots => 'Снимки экраны',
+        Screenshot1 => 'Первый снимок',
+        Screenshot2 => 'Второй снимок',
+        Url => 'ВЭБ страница',
+        Unlockables => 'Бонусы',
+        Unlockable => 'Бонусы',
+        Howto => 'Как разблокировать',
 
-        General => 'General',
-        Details => 'Details',
-        Tips => 'Tips',
-        Information => 'Information',
+        General => 'Общее',
+        Details => 'Детали',
+        Tips => 'Подсказки',
+        Information => 'Информация',
 
-        FilterRatingSelect => 'Rating At _Least...',
+        FilterRatingSelect => 'По Крайней мере...',
      );
 }
 
