@@ -64,7 +64,7 @@
         'InstallOptions' => 'Опции',
         'InstallSelectDirectory' => 'Выберите базовую директорию для инсталляции',
         'InstallWithClean' => 'Удалить файлы найденные в директории для инсталляции',
-        'InstallWithMenu' => 'Добавить GCstar tв меню Приложений',
+        'InstallWithMenu' => 'Добавить GCstar в меню Приложений',
         'InstallNoPermission' => 'Ошибка : У вас нет прав на запись в указанную директорию',
         'InstallMissingMandatory' => 'Необходимые зависмости не удовлетворены. Вы не можете проинсталлировать GCfilms пока не будут установлены зависимые компоненты.',
         'InstallMissingOptional' => 'Некоторые из дополнительных компонентов отсутствуют. Они перечислены ниже. GCfilms может быть проинсталлированн, но некоторые возможности не будут доступны.',
@@ -72,6 +72,9 @@
         'InstallOK' => 'OK',
         'InstallMissing' => 'Отсутствует',
         'InstallMissingFor' => 'Отсутствует',
+        'InstallCleanDirectory' => 'Удаление файлов GCstar в директории: ',
+        'InstallCopyDirectory' => 'Копируются файлы в директорию: ',
+        'InstallCopyDesktop' => 'Копируются файлы рабочего стола в диреткорию: ',
 
 #Update
         'UpdateUseProxy' => 'Использовать прокси-сервер (или просто нажмите Enter если не нужно): ',
@@ -82,13 +85,13 @@
 #Splash
         'SplashInit' => 'Инициализация',
         'SplashLoad' => 'Загружается',
-        'SplashDisplay' => 'Displaying Collection',
+        'SplashDisplay' => 'Отображать коллекцию',
         'SplashDone' => 'Всё готово',
 
 #Import from GCfilms
-        'GCfilmsImportQuestion' => 'It seems you were using GCfilms before. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
-        'GCfilmsImportOptions' => 'Settings',
-        'GCfilmsImportData' => 'Movies list',
+        'GCfilmsImportQuestion' => 'Кажется вы ранее уже использовали GCFilms. Что вы хотите импортировать из GCfilms в GCstar (это не затронет приложение GCFilms если Вы все ещё захотите потом его использовать)?',
+        'GCfilmsImportOptions' => 'Установки',
+        'GCfilmsImportData' => 'Список фильмов',
 
 #Menus
         'MenuFile' => '_Файл',
@@ -101,11 +104,11 @@
         'MenuEdit'  => '_Редактирование',
             'MenuDuplicate' => '_Дублировать фильм',
             'MenuEditDeleteCurrent' => '_Удалить фильм',
-            'MenuEditFields' => '_Change collection fields',
+            'MenuEditFields' => '_Изменить поля коллекции',
             'MenuEditLockItems' => '_Зафиксировать коллекцию',
     
         'MenuDisplay' => '_Фильтр',
-            'MenuAdvancedSearch' => 'A_dvanced Search',
+            'MenuAdvancedSearch' => 'Расширенный _Поиск',
             'MenuViewAllItems' => 'Показать _ВСЕ фильмы',
             'MenuNoFilter' => '_Любой',
     
@@ -114,38 +117,39 @@
             'MenuBorrowers' => '_Должники',
             'MenuGenresConversion' => '_Преобразование жанров',
         
-        'MenuBookmarks' => 'My _Collections',
-            'MenuBookmarksAdd' => '_Add current collection',
-            'MenuBookmarksEdit' => '_Edit bookmarked collections',
+        'MenuBookmarks' => 'Моя _Коллекция',
+            'MenuBookmarksAdd' => 'Добавить _текущую коллекцию',
+            'MenuBookmarksEdit' => '_Редактировать закладки коллекций',
 
         'MenuHelp' => '_Помощь',
             'MenuHelpContent' => '_Помощь',
-            'MenuBugReport' => 'Report a _bug',
+            'MenuAllPlugins' => 'Все подключаемые _модули',
+            'MenuBugReport' => 'Отправить отчёт об _ошибке',
             'MenuAbout' => '_О GCstar',
     
         'MenuNewWindow' => 'Показать фильм в _Новом Окне',
         
-        'ContextExpandAll' => 'Expand all',
-        'ContextCollapseAll' => 'Collapse all',
+        'ContextExpandAll' => 'Развернуть всё',
+        'ContextCollapseAll' => 'Свернуть всё',
     
-        'DialogEnterNumber' => 'Please enter value',
+        'DialogEnterNumber' => 'Пожалуйста введите занчение',
 
         'RemoveConfirm' => 'Вы действительно хотите удалить этот фильм?',
-        'DefaultNewItem' => 'New item',
+        'DefaultNewItem' => 'Новый элемент',
         'NewItemTooltip' => 'Добавить новый фильм',
         'NoItemFound' => 'Фильм не был найде. Хотите поискать на другом сайте?',
         'OpenList' => 'Пожалуйста выберите коллекцию',
         'SaveList' => 'Пожалуйста выберите куда сохранить коллекцию',
         'SaveListTooltip' => 'Сохранить текущую коллекцию',
         'SaveCurrentList' => 'Сначала укажите куда сохранить текущую коллекцию',
-        'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
-        'SaveDontSave' => 'Don\'t save',
+        'SaveUnsavedChanges' => 'В вашей коллекций есть несохранённые изменения, хотите их сохранить?',
+        'SaveDontSave' => 'Не сохранять',
         'PreferencesTooltip' => 'Установите свои предпочтения',
         'ViewTooltip' => 'Изменить отоюражение коллекции',
         'PlayTooltip' => 'Воспроизвести видео ассоциируемое с фильмом',
 
-        'StatusSave' => 'Saving...',
-        'StatusLoad' => 'Loading...',
+        'StatusSave' => 'Сохраняется...',
+        'StatusLoad' => 'Загружается...',
         'StatusSearch' => 'Идёт поиск...',
         'StatusGetInfo' => 'Получается информация...',
         'StatusGetImage' => 'Получается изображение...',
@@ -153,7 +157,7 @@
         'SaveError' => 'Не могу сохранить список фильмов. Пожалуйста проверьте права доступа и свободное мето на диске.',
         'OpenError' => 'Не могу открыть список фильмо. Пожалуйста проверьте права доступа.',
         'OpenFormatError' => 'Не могу открыть список фильмо.',
-        'ImageError' => 'Выбранная для сохранения изображение директория не верна. Пожалуйста выюерите другую.',
+        'ImageError' => 'Выбранная для сохранения изображение директория не верна. Пожалуйста выберите другую.',
         'OptionsCreationError'=> 'Не могу создать файл опций: ',
         'OptionsOpenError'=> 'Не могу открыть файл опций: ',
         'OptionsSaveError'=> 'Не могу сохранить файл опций: ',
@@ -171,83 +175,83 @@
         'AboutWho' => 'Tian: Руководитель проекта, Программист
 Adolfo González : Программист',
         'AboutLicense' => 'Распространяется под лицензией GNU GPL
-Logos Copyright le Spektre
+Логотипы Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Русский перевод Андрей Гуселетов',
         'AboutDesign' => 'Логотипы и вэб-дизайн : le Spektre',
 
         'ToolbarRandom' => 'Сегодня вечером',
         
-        'ModelsSelect' => 'Select a collection type',
-        'ModelsPersonal' => 'Personal models',
-        'ModelsDefault' => 'Default models',
-        'ModelsList' => 'Collection definition',
-        'ModelSettings' => 'Collection settings',
-        'ModelNewType' => 'New collection type',
-        'ModelName' => 'Name of the collection type:',
-        'ModelNewField' => 'New field',
-        'ModelFieldInformation' => 'Information',
-        'ModelFieldName' => 'Label:',
-        'ModelFieldType' => 'Type:',
-        'ModelFieldGroup' => 'Group:',
-        'ModelFieldValues' => 'Values',
-        'ModelFieldInit' => 'Default:',
-        'ModelFieldMin' => 'Minimum:',
-        'ModelFieldMax' => 'Maximum:',
-        'ModelFieldList' => 'Values list:',
-        'ModelFieldListLegend' => '<i>Comma separated</i>',
-        'ModelFieldTypeShortText' => 'Short text',
-        'ModelFieldTypeLongText' => 'Long text',
-        'ModelFieldTypeYesNo' => 'Yes/No',
-        'ModelFieldTypeNumber' => 'Number',
-        'ModelFieldTypeDate' => 'Date',
-        'ModelFieldTypeOptions' => 'Pre-defined values list',
-        'ModelFieldTypeImage' => 'Image',
-        'ModelFieldTypeSingleList' => 'Simple list',
-        'ModelFieldTypeFile' => 'File',
-        'ModelFieldParameters' => 'Parameters',
-        'ModelFieldHasHistory' => 'Use an history',
-        'ModelFieldFlat' => 'Display on one line',
-        'ModelFieldStep' => 'Increment step:',
-        'ModelFieldFileFormat' => 'File format:',
-        'ModelFieldFileFile' => 'Simple file',
-        'ModelFieldFileImage' => 'Image',
-        'ModelFieldFileVideo' => 'Video',
-        'ModelFieldFileAudio' => 'Audio',
-        'ModelFieldFileProgram' => 'Program',
+        'ModelsSelect' => 'Выберите тип коллекции',
+        'ModelsPersonal' => 'Персональные модели',
+        'ModelsDefault' => 'По-умолчанию',
+        'ModelsList' => 'Определение коллекции',
+        'ModelSettings' => 'настройки коллекции',
+        'ModelNewType' => 'новый тип коллекции',
+        'ModelName' => 'Имя нового типа коллекции:',
+        'ModelNewField' => 'Новое поле',
+        'ModelFieldInformation' => 'Информация',
+        'ModelFieldName' => 'Метка:',
+        'ModelFieldType' => 'Тип:',
+        'ModelFieldGroup' => 'Группа:',
+        'ModelFieldValues' => 'Значения',
+        'ModelFieldInit' => 'По-умолчанию:',
+        'ModelFieldMin' => 'Минимум:',
+        'ModelFieldMax' => 'Максимум:',
+        'ModelFieldList' => 'Список значений:',
+        'ModelFieldListLegend' => '<i>Разделённые запятой</i>',
+        'ModelFieldTypeShortText' => 'Короткое описание текст',
+        'ModelFieldTypeLongText' => 'Длинное описание',
+        'ModelFieldTypeYesNo' => 'Да/Нет',
+        'ModelFieldTypeNumber' => 'Число',
+        'ModelFieldTypeDate' => 'Дата',
+        'ModelFieldTypeOptions' => 'Предопределённый список значений',
+        'ModelFieldTypeImage' => 'Изображение',
+        'ModelFieldTypeSingleList' => 'Простой список',
+        'ModelFieldTypeFile' => 'Файл',
+        'ModelFieldParameters' => 'Параметры',
+        'ModelFieldHasHistory' => 'Использовать историю',
+        'ModelFieldFlat' => 'Отображать на одной строке',
+        'ModelFieldStep' => 'Шаг увеличения:',
+        'ModelFieldFileFormat' => 'Формат файла:',
+        'ModelFieldFileFile' => 'Простой файл',
+        'ModelFieldFileImage' => 'Изображение',
+        'ModelFieldFileVideo' => 'Видео',
+        'ModelFieldFileAudio' => 'Аудио',
+        'ModelFieldFileProgram' => 'Программа',
         'ModelFieldFileUrl' => 'URL',
-        'ModelOptionsFields' => 'Fields to use',
-        'ModelOptionsFieldsAuto' => 'Automatic',
-        'ModelOptionsFieldsNone' => 'None',
-        'ModelOptionsFieldsTitle' => 'As title',
-        'ModelOptionsFieldsId' => 'As identifier',
-        'ModelOptionsFieldsCover' => 'As cover',
-        'ModelOptionsFieldsPlay' => 'For Play button',
-        'ModelCollectionSettings' => 'Collection settings',
-        'ModelCollectionSettingsLending' => 'Items could be borrowed',
-        'ModelFilterActivated' => 'Should be in search box',
-        'ModelFilterComparison' => 'Comparison',
-        'ModelFilterContain' => 'Contains',
-        'ModelFilterRange' => 'Range',
-        'ModelFilterNumeric' => 'Comparison is numeric',
-        'ModelFilterQuick' => 'Create a quick filter',
-        'ModelTooltipName' => 'Use a name to re-use this model for many collections. If empty, the settings will be directly stored in the collection itself',
-        'ModelTooltipLabel' => 'The field name as it will be displayed',
-        'ModelTooltipGroup' => 'Used to group fields. Items with no value here will be in a default group',
-        'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
-        'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
-        'ModelTooltipLending' => 'This will add some fields to manage lendings',
-        'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
-        'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
+        'ModelOptionsFields' => 'Использовать поля',
+        'ModelOptionsFieldsAuto' => 'Автоматически',
+        'ModelOptionsFieldsNone' => 'Нет',
+        'ModelOptionsFieldsTitle' => 'Как заголовок',
+        'ModelOptionsFieldsId' => 'Как идентифекатор',
+        'ModelOptionsFieldsCover' => 'Как обложку',
+        'ModelOptionsFieldsPlay' => 'Для кнопки Воспроизведение',
+        'ModelCollectionSettings' => 'Настройки коллекции',
+        'ModelCollectionSettingsLending' => 'Предмет может быть дан взаймы',
+        'ModelFilterActivated' => 'Должно быть в строке поиска',
+        'ModelFilterComparison' => 'Сравнение',
+        'ModelFilterContain' => 'Содержит',
+        'ModelFilterRange' => 'Диапазон',
+        'ModelFilterNumeric' => 'ИСпользовать цифровое сравнение',
+        'ModelFilterQuick' => 'Создать бытрый фильтр',
+        'ModelTooltipName' => 'Используйте имя для того чтобы потом можно было использовать эту модель в других коллекция. Оставьте значение по-умолчанию, для того чтобы сохранить модель только в самой коллекции.',
+        'ModelTooltipLabel' => 'Поле имени так как оно будет отображено',
+        'ModelTooltipGroup' => 'Используется для группировки полей. Элементы без значений здесь будут в группе по-умолчанию.',
+        'ModelTooltipHistory' => 'Должно ли введенное значение сохраняться в списке ассоциированном с полем',
+        'ModelTooltipFormat' => 'Формат используется для определения действия которое происходит при нажатии кнопки Воспроизведение',
+        'ModelTooltipLending' => 'Тут будут добавлены некоторые поля для управления займами',
+        'ModelTooltipNumeric' => 'Должны ли значения считаться цифрами при сравнении',
+        'ModelTooltipQuick' => 'Это добавит подменю в фильтры',
 
         'ResultsTitle' => 'Выберите фильм',
         'ResultsNextTip' => 'искать на следующем сайте',
-        'ResultsPreview' => 'Preview',
+        'ResultsPreview' => 'Предпросмотр',
         
         'OptionsTitle' => 'Предпочтения',
         'OptionsBrowser' => 'Вэб браузер',
         'OptionsPlayer' => 'Видео проигрыватель',
-        'OptionsAudio' => 'Audio player',
+        'OptionsAudio' => 'Аудио проигрыватель',
         'OptionsImages' => 'Директория с изображения',
         'OptionsUseRelativePaths' => 'Использовать относительные пути для изображений',
         'OptionsLayout' => 'Расположение',
@@ -255,7 +259,7 @@ http://le-spektre.org',
         'OptionsWarning' => 'Внимание : изменения на этой вкладке не будут применыны до перезагрузки приложения.',
         'OptionsRemoveConfirm' => 'Спрашивать подтверждение перед удалением фильма',
         'OptionsAutoSave' => 'Автоматически сохранять коллекцию',
-        'OptionsAutoLoad' => 'Load previous collection on startup',
+        'OptionsAutoLoad' => 'Загружать предыдущую коллекцию при старте',
         'OptionsSplash' => 'Показывать стартовый экран',
         'OptionsImagesTitle' => 'Выберите директорию',
         'OptionsProgramTitle' => 'Выберите программу',
@@ -290,20 +294,20 @@ http://le-spektre.org',
         'OptionsClearHistory' => 'Очистить историю',
 		'OptionsStyle' => 'Шкура',
         'OptionsDontAsk' => 'Больше не спрашивать',
-        'OptionsPathProgramsGroup' => 'Applications',
-        'OptionsPathImagesGroup' => 'Images',
-        'OptionsInternetDataGroup' => 'Data import',
-        'OptionsInternetSettingsGroup' => 'Settings',
-        'OptionsDisplayInformationGroup' => 'Information display',
-        'OptionsDisplayArticlesGroup' => 'Articles',
-        'OptionsImagesDisplayGroup' => 'Display',
-        'OptionsImagesStyleGroup' => 'Style',
-        'OptionsDetailedPreferencesGroup' => 'Preferences',
-        'OptionsFeaturesConveniencesGroup' => 'Conveniences',
-        'OptionsPicturesFormat' => 'Prefix to use for pictures:',
+        'OptionsPathProgramsGroup' => 'Приложения',
+        'OptionsPathImagesGroup' => 'Изображения',
+        'OptionsInternetDataGroup' => 'Импорт данных',
+        'OptionsInternetSettingsGroup' => 'Настройки',
+        'OptionsDisplayInformationGroup' => 'Информация',
+        'OptionsDisplayArticlesGroup' => 'Статьи',
+        'OptionsImagesDisplayGroup' => 'Отобразить',
+        'OptionsImagesStyleGroup' => 'Стиль',
+        'OptionsDetailedPreferencesGroup' => 'Предпочтения',
+        'OptionsFeaturesConveniencesGroup' => 'Соглашения',
+        'OptionsPicturesFormat' => 'Префикс для использования в изображениях:',
         'OptionsPicturesFormatInternal' => 'gcstar__',
-        'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
-        'OptionsConfigureMailers' => 'Configure mailing programs',
+        'OptionsPicturesFormatTitle' => 'Заголовок или имя ассоциированного элемента ',
+        'OptionsConfigureMailers' => 'Настройка почтовой программы',
 
         'ImagesOptionsButton' => 'Настройки',
         'ImagesOptionsTitle' => 'Настройки для списка изображений',
@@ -319,23 +323,19 @@ http://le-spektre.org',
 		        
         'DetailedOptionsTitle' => 'Настройки для детализированного списка',
         'DetailedOptionsImageSize' => 'Размер изображения',
-        'DetailedOptionsGroupItems' => 'Group items by',
+        'DetailedOptionsGroupItems' => 'Группировать элементы по',
 		'DetailedOptionsFields' => 'Выберите поля для отображения',
-		'DetailedOptionsMasterOption' => 'Group master is',
-		'DetailedOptionsMasterGenerated' => 'Auto generated',
-		'DetailedOptionsMasterOrdered' => 'Determined by',
+		'DetailedOptionsMasterOption' => 'Основная группировка ',
+		'DetailedOptionsMasterGenerated' => 'Автоматически созданный',
+		'DetailedOptionsMasterOrdered' => 'Определяется ',
 
         'ExtractButton' => 'Информация',
         'ExtractTitle' => 'Информация из видеофайла',
-        'ExtractSize' => 'Размер',
-        'ExtractLength' => 'Длительность (минут)',
-        'ExtractType' => 'Видео формат',
-        'ExtractAudioEncoding' => 'Аудиоформат',
         'ExtractImport' => 'Использовать значения',
 
-        'FieldsListOpen' => 'Load a fields list from a file',
-        'FieldsListSave' => 'Save fields list to a file',
-        'FieldsListError' => 'This fields list cannot be used with this kind of collection',
+        'FieldsListOpen' => 'Загрузить список полей из файла',
+        'FieldsListSave' => 'Сохранить список полей в файл',
+        'FieldsListError' => 'Этот список полей не может быть использован с данным типом коллекции',
 
         'ExportTitle' => 'Экспортировать список фильмов',
         'ExportFilter' => 'Экспортировать только показанные фильмы',
@@ -344,7 +344,7 @@ http://le-spektre.org',
         'ExportWithPictures' => 'Скопировать изображения в под-директорию',
 
         'ImportListTitle' => 'Импортировать другой список фильмоа',
-        'ImportExportData' => 'Data',
+        'ImportExportData' => 'Данные',
         'ImportExportFile' => 'Файл',
         'ImportExportSave' => 'Пожалуйста, выберите файл',
         'ImportExportFieldsUnused' => 'Неиспользуемые поля',
@@ -359,7 +359,7 @@ http://le-spektre.org',
         'ImportCurrentList' => 'Добавить к текущей коллекции',
         'ImportDropError' => 'Произошла ошибка в процессе открытия, по крайней мере в одном файле. Будет загружен предыдущий список.',
 
-        'FileOverwrite' => 'Такой файл уже сущевутует. Вы хотите перезаписать его?',
+        'FileOverwrite' => 'Такой файл уже существует. Вы хотите перезаписать его?',
 
         'PanelCompact' => 'Компактно',
         'PanelReadOnly' => 'Только для чтения',
@@ -368,13 +368,14 @@ http://le-spektre.org',
         'PanelSearchButton' => 'Получить информацию',
         'PanelSearchTip' => 'Искать в Инетрнет информацию по этому заголовку',
         'PanelImageTipOpen' => 'Щёлкните на картинке для выбора другой.',
-        'PanelImageTipView' => 'Click on the picture to view it in real size.',
+        'PanelImageTipView' => 'Нажмите на картинке для просмотра её в оригинальном размере.',
         'PanelImageTipMenu' => ' Правый щелчок - еще опции',
         'PanelImageTitle' => 'Выберите картинку',
+        'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Выберите файл',
 
-        'PanelFrom' =>'From',
-        'PanelTo' =>'To',
+        'PanelFrom' =>'От',
+        'PanelTo' =>'Куда',
 
         'PanelWeb' => 'Смотреть информацию',
         'PanelWebTip' => 'Посмотреть информацию в Интернет об этом фильме',
@@ -399,14 +400,15 @@ http://le-spektre.org',
 
         'ToolbarAll' => 'Показать все',
         'ToolbarAllTooltip' => 'Показать все фильмы',
-        'ToolbarGroupBy' => 'Group by',
-        'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
+        'ToolbarGroupBy' => 'Группировать по',
+        'ToolbarGroupByTooltip' => 'Выберите поля для группировки элементов в списке',
         
         'PluginsTitle' => 'Искать фильм',
-        'PluginsQuery' => 'Query',
+        'PluginsQuery' => 'Запрос',
         'PluginsFrame' => 'Искать сайт',
         'PluginsLogo' => 'Лого',
         'PluginsName' => 'Имя',
+        'PluginsSearchFields' => 'Поля для поиска',
         'PluginsAuthor' => 'Автор',
         'PluginsLang' => 'Язык',
         'PluginsUseSite' => 'Использовать выбранный сайт для последующего поиска',
@@ -424,9 +426,9 @@ http://le-spektre.org',
         'BorrowersNotice2' => '%2 будет заменено названием фильма',
         'BorrowersNotice3' => '%3 будет заменено датой',
 
-        'BorrowersImportTitle' => 'Import borrowers information',
-        'BorrowersImportType' => 'File format:',
-        'BorrowersImportFile' => 'File:',
+        'BorrowersImportTitle' => 'Импорт информации о должниках',
+        'BorrowersImportType' => 'Формат файла:',
+        'BorrowersImportFile' => 'Файл:',
 
         'BorrowedTitle' => 'На руках',
         'BorrowedDate' => 'С ',
@@ -441,13 +443,13 @@ http://le-spektre.org',
         'SearchTooltip' => 'Искать все фильмы',
         'SearchTitle' => 'Поиск фильмов',
 
-        'QueryReplaceField' => 'Field to replace',
+        'QueryReplaceField' => 'Поле для замены',
         'QueryReplaceOld' => 'Текущее имя',
         'QueryReplaceNew' => 'Новое имя',
-        'QueryReplaceLaunch' => 'Replace',
+        'QueryReplaceLaunch' => 'Заменить',
         
         'ImportWindowTitle' => 'Выберите поля для импортирования',
-        'ImportViewPicture' => 'Посмотреть каринку',
+        'ImportViewPicture' => 'Посмотреть картинку',
         'ImportSelectAll' => 'Выбрать все',
         'ImportSelectNone' => 'Сбросить выбор',
 
@@ -469,32 +471,38 @@ http://le-spektre.org',
         'GenresExport' => 'Сохранить список жанров в файл',
         'GenresModify' => 'Редактировать конвертацию',
 
-        'PropertiesName' => 'Collection name',
-        'PropertiesOwner' => 'Owner',
-        'PropertiesEmail' => 'Email',
-        'PropertiesDescription' => 'Description',
+        'PropertiesName' => 'Имя коллекции',
+        'PropertiesOwner' => 'Владелец',
+        'PropertiesEmail' => 'E-mail',
+        'PropertiesDescription' => 'Описание',
+        'PropertiesFile' => 'Информация о файле',
+        'PropertiesFilePath' => 'Полный путь',
+        'PropertiesItemsNumber' => 'Количество элементов',
+        'PropertiesFileSize' => 'Размер',
+        'PropertiesFileSizeSymbols' => ['Байт', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Свойства коллекции',
 
-        'MailProgramsTitle' => 'Programs for mail sending',
-        'MailProgramsName' => 'Name',
-        'MailProgramsCommand' => 'Command line',
-        'MailProgramsRestore' => 'Restore defaults',
-        'MailProgramsAdd' => 'Add a program',
-        'MailProgramsInstructions' => 'In command line, some substitutions are made:
- %f is replaced with user\'s e-mail address.
- %t is replaced with the recipient address.
- %s is replaced with the subject of the message.
- %b is replaced with the body of the message.',
+        'MailProgramsTitle' => 'Программы для отправки почты',
+        'MailProgramsName' => 'Имя',
+        'MailProgramsCommand' => 'Коммандная строка',
+        'MailProgramsRestore' => 'Восстановить значения по-умолчанию',
+        'MailProgramsAdd' => 'Добавить программу',
+        'MailProgramsInstructions' => 'В коммандной строке делаются такие подстановки:
+ %f заменяется e-mail адресом пользователя.
+ %t заменяется адресом получателя.
+ %s заменяется темой сообщения.
+ %b заменяется телом сообщения.',
 
-        'BookmarksBookmarks' => 'Bookmarks',
-        'BookmarksFolder' => 'Directory',
-        'BookmarksLabel' => 'Label',
-        'BookmarksPath' => 'Path',
-        'BookmarksNewFolder' => 'New folder',
+        'BookmarksBookmarks' => 'Закладки',
+        'BookmarksFolder' => 'Директория',
+        'BookmarksLabel' => 'Метка',
+        'BookmarksPath' => 'Путь',
+        'BookmarksNewFolder' => 'Новая папка',
 
-        'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
-        'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchType' => 'Тип поиска',
+        'AdvancedSearchTypeAnd' => 'Элементы удовлетворяющие всем критериям',
+        'AdvancedSearchTypeOr' => 'Элементы удовлетворяющие по крайней мере одному критерию',
+        'AdvancedSearchCriteria' => 'Критерий',
     );
 }
 1;
