@@ -61,6 +61,7 @@
         Serie => 'Kolekcija',
         Rank => 'Ocena',
         Subtitles => 'Prevod',
+        Added => 'Add date',
 
         SeenYes => 'Gledao',
         SeenNo => 'Neodgledan',
@@ -81,6 +82,8 @@
         FilterSeenNo => '_Negledani',
         FilterSeenYes => '_Already Viewed',
         FilterRatingSelect => 'Ocena _Najmanje...',
+
+        ExtractSize => 'Veličina',
      );
 }
 
