@@ -69,6 +69,9 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
     	'InstallOK' => 'OK',
     	'InstallMissing' => 'Nedostaju',
     	'InstallMissingFor' => 'Nedostaju',
+        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
+        'InstallCopyDirectory' => 'Copying files in directory: ',
+        'InstallCopyDesktop' => 'Copying desktop file in: ',
 
 #Update
         'UpdateUseProxy' => 'Koristi proxy (pritisnite enter ako ih nema): ',
@@ -82,6 +85,11 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
         'SplashDisplay' => 'Displaying Collection',
     	'SplashDone' => 'Spremno',
 
+#Import from GCfilms
+        'GCfilmsImportQuestion' => 'It seems you were using GCfilms before. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
+        'GCfilmsImportOptions' => 'Settings',
+        'GCfilmsImportData' => 'Movies list',
+
 #Menus
     	'MenuFile' => '_Fajl',
     		'MenuNewList' => '_Nova Kolekcija',
@@ -112,6 +120,7 @@ Da biste odredili koji sajt je vlasnik informacija, možete da koristite <b>dugm
 
     	'MenuHelp' => '_Pomoć',
         	'MenuHelpContent' => '_Pomoć',
+            'MenuAllPlugins' => 'View _plugins',
             'MenuBugReport' => 'Report a _bug',
     		'MenuAbout' => '_O GCstar',
     
@@ -319,10 +328,6 @@ http://le-spektre.org',
 
         'ExtractButton' => 'Informacije',
         'ExtractTitle' => 'Informacije o video fajlu',
-        'ExtractSize' => 'Veličina',
-        'ExtractLength' => 'Trajanje (minuta)',
-        'ExtractType' => 'Video format',
-        'ExtractAudioEncoding' => 'Audio format',
         'ExtractImport' => 'Koristi vrednosti',
 
         'FieldsListOpen' => 'Load a fields list from a file',
@@ -363,6 +368,7 @@ http://le-spektre.org',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Desni klik za više opcija.',
         'PanelImageTitle' => 'Odaberi sliku',
+        'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Odaberi fajl',
 
         'PanelFrom' =>'From',
@@ -399,6 +405,7 @@ http://le-spektre.org',
         'PluginsFrame' => 'Traži po internet sajtu',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Ime',
+        'PluginsSearchFields' => 'Search fields',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Jezik',
         'PluginsUseSite' => 'Koristi odabrani sajt za sledeće pretrage',
@@ -465,6 +472,12 @@ http://le-spektre.org',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
+        'PropertiesFile' => 'File Information',
+        'PropertiesFilePath' => 'Full path',
+        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesFileSize' => 'Size',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Collection properties',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
