@@ -1,5 +1,5 @@
 {
-    package GCLang::EN::GCImport::GCImportTellico;
+    package GCLang::TR::GCImport::GCImportTellico;
 
     use utf8;
 ###################################################
