@@ -76,6 +76,9 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'InstallOK' => 'Tamam',
         'InstallMissing' => 'Eksik',
         'InstallMissingFor' => 'Eksikler',
+        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
+        'InstallCopyDirectory' => 'Copying files in directory: ',
+        'InstallCopyDesktop' => 'Copying desktop file in: ',
 
 #Update
         'UpdateUseProxy' => 'Kullanılacak Proxy (emin değilseniz sadece entere basınız): ',
@@ -124,6 +127,7 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
 
         'MenuHelp' => '_Yardım',
             'MenuHelpContent' => '_Yardım',
+            'MenuAllPlugins' => 'View _plugins',
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => 'GCstar _Hakkında',
     
@@ -331,10 +335,6 @@ http://le-spektre.org\'a aittir.',
 
         'ExtractButton' => 'Bilgi',
         'ExtractTitle' => 'Video Bilgisi',
-        'ExtractSize' => 'Boyut',
-        'ExtractLength' => 'Süre (dakika)',
-        'ExtractType' => 'Video formatı',
-        'ExtractAudioEncoding' => 'Ses formatı',
         'ExtractImport' => 'Bu değerleri kullan',
 
         'FieldsListOpen' => 'Load a fields list from a file',
@@ -376,6 +376,7 @@ http://le-spektre.org\'a aittir.',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Daha fazla seçenek için sağ tıklayınız.',
         'PanelImageTitle' => 'Kapak seç',
+        'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Dosya Seçiniz',
 
         'PanelFrom' =>'From',
@@ -412,6 +413,7 @@ http://le-spektre.org\'a aittir.',
         'PluginsFrame' => 'Arama sitesi',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Adı',
+        'PluginsSearchFields' => 'Search fields',
         'PluginsAuthor' => 'Yazarı',
         'PluginsLang' => 'Dil',
         'PluginsUseSite' => 'Her zaman bu siteyi kullan',
@@ -478,6 +480,12 @@ http://le-spektre.org\'a aittir.',
         'PropertiesOwner' => 'Owner',
         'PropertiesEmail' => 'Email',
         'PropertiesDescription' => 'Description',
+        'PropertiesFile' => 'File Information',
+        'PropertiesFilePath' => 'Full path',
+        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesFileSize' => 'Size',
+        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
+        'PropertiesCollection' => 'Collection properties',
 
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
