@@ -82,6 +82,7 @@ use Gtk2;
         $self->{options}->split($self->{pane}->get_position) if ($self->{pane});
         
         $self->{options}->save;
+        $self->{itemsList}->savePreferences($self->{model}->{preferences});
         $self->{model}->save;
 
         $self->{items}->clean;
@@ -605,7 +606,7 @@ use Gtk2;
             }
                         
             $self->{items}->updateCurrent;
-            $self->{itemsList}->changeCurrent($previous, $info) if ($self->{panel}->{autoUpdate});
+            #$self->{itemsList}->changeCurrent($previous, $info) if ($self->{panel}->{autoUpdate});
             $self->{itemsList}->showCurrent;
         }
         $self->{panel}->dataChanged;
@@ -646,9 +647,9 @@ use Gtk2;
         $path = GCUtils::getDisplayedImage($path, '', $file);
         my $dir = undef;
         $dir = dirname($file) if $file;
-        return File::Spec->rel2abs($path,$dir)
+        return GCUtils::pathToUnix(File::Spec->rel2abs($path,$dir))
             if !$self->{options}->useRelativePaths;
-        return File::Spec->abs2rel($path,$dir);
+        return GCUtils::pathToUnix(File::Spec->abs2rel($path,$dir));
     }
 
     sub addBookmark
@@ -699,7 +700,7 @@ use Gtk2;
         if ($self->{items}->load($filename, $self, 1))
         {
             $self->addFileHistory($filename);
-            $self->{options}->file($filename);
+            $self->setFile($filename);
             $self->{options}->save;
             $self->selectFirst;
             $self->setTitle(basename($filename), $self->{items}->{information}->{name});
@@ -741,9 +742,9 @@ use Gtk2;
 
     sub newList
     {
-        my ($self, $modelName, $modelAlreadySet) = @_;
+        my ($self, $modelName, $modelAlreadySet, $saveAlreadyDone) = @_;
 
-        return if !$self->checkAndSave;
+        return if !$saveAlreadyDone && !$self->checkAndSave;
 
         if (!$modelAlreadySet)
         {
@@ -770,7 +771,8 @@ use Gtk2;
         }
 
         $self->{items}->clearList;
-        $self->{options}->file('');
+        $self->setFile('');
+        $self->{menubar}->setAddBookmarkActive(0);
         $self->setTitle('');
     }
 
@@ -789,7 +791,7 @@ use Gtk2;
                 my $filename = $fileDialog->get_filename;
                 $self->addFileHistory($filename);
                 my $previousFile = $self->{options}->file;
-                $self->{options}->file($filename);
+                $self->setFile($filename);
                 if ($self->saveList())
                 {
                     $self->{options}->save;
@@ -798,7 +800,7 @@ use Gtk2;
                 }
                 else
                 {
-                    $self->{options}->file($previousFile);
+                    $self->setFile($previousFile);
                 }            
     		}
     		last if ($response ne 'ok')
@@ -839,9 +841,11 @@ use Gtk2;
         $dialog->set_position('center-on-parent');
         my $response = $dialog->run();
         $dialog->destroy;
-        ($response eq 'yes') ? $self->saveList :
-        ($response eq 'cancel') ? return 0 :
-        $self->removeUpdatedMark;
+
+        $self->saveList if $response eq 'yes';
+        return 0 if $response eq 'cancel';
+#        $self->removeUpdatedMark;
+
         return 1;
     }
 
@@ -850,7 +854,6 @@ use Gtk2;
         my ($self, $self2) = @_;
         $self = $self2 if $self2;
         my $response = 'yes';
-
         if ($self->{options}->file)
         {
             return $self->{items}->save($self);
@@ -1036,6 +1039,14 @@ use Gtk2;
         return $error;
     }
 
+    sub setFile
+    {
+        my ($self, $filename) = @_;
+        
+        $self->{options}->file($filename);
+        $self->{menubar}->setAddBookmarkActive($filename ne '');
+    }
+    
     sub setFileName
     {
         my ($self, $file) = @_;
@@ -1055,7 +1066,9 @@ use Gtk2;
         my $self = shift;
         
         my $dialog = $self->getDialog('Properties');
-        $dialog->setProperties($self->{items}->{information});
+        $dialog->setProperties($self->{items}->{information},
+                               $self->{options}->file,
+                               $self->{items}->{nbItems});
         if ($dialog->show)
         {
             $self->{items}->{information} = $dialog->getProperties;
@@ -1216,6 +1229,8 @@ use Gtk2;
         my ($self, $model) = @_;
 
         $model = 'GCfilms' if ! $model;
+        $self->{itemsList}->savePreferences($self->{model}->{preferences})
+            if $self->{itemsList};
         $self->{model}->save if $self->{model};
         if ((ref $model) =~ /GCModelLoader/)
         {
@@ -1275,12 +1290,16 @@ use Gtk2;
 
         $self->getDialog('Search')->setModel($self->{model})
             if $self->{SearchDialog};
+        $self->getDialog('AdvancedSearch')->setModel($self->{model})
+            if $self->{AdvancedSearchDialog};
         $self->getDialog('Options')->setModel($self->{model})
             if $self->{OptionsDialog};
         $self->getDialog('QueryReplace')->setModel($self->{model})
             if $self->{QueryReplaceDialog};
         $self->getDialog('Plugins')->setModel
             if $self->{PluginsDialog};
+        $self->getDialog('ImportFields')->setModel($self->{model})
+            if $self->{ImportFieldsDialog};
         $self->getDialog('Export')->setModel
             if $self->{ExportDialog};
         $self->getDialog('Import')->setModel
@@ -1374,10 +1393,15 @@ use Gtk2;
     sub showDependencies
     {
         my $self = shift;
-        
         $self->getDialog('Dependencies')->show;
     }
 
+    sub showAllPlugins
+    {
+        my $self = shift;
+        $self->getDialog('AllPlugins')->show;
+    }
+
     sub help
     {
         my ($self, $self2) = @_;
@@ -1391,7 +1415,14 @@ use Gtk2;
         my ($self, $self2) = @_;
         $self = $self2 if $self2;
 
-        $self->launch('https://gna.org/bugs/?func=additem&group=gcstar', 'url');
+        my %topicIds = (
+            EN => '4',
+            FR => '9'
+        );
+        
+        my $id = $topicIds{$self->{options}->lang} || $topicIds{EN};
+        #$self->launch('https://gna.org/bugs/?func=additem&group=gcstar', 'url');
+        $self->launch('http://forums.gcstar.org/post.php?fid='.$id, 'url');
     }
 
     sub playItem
@@ -1410,6 +1441,7 @@ use Gtk2;
         # For image, we have an internal viewer
         if ($format eq 'image')
         {
+            $file = GCUtils::getDisplayedImage($file, '', $self->{options}->file);
             my $dialog = new GCImageDialog($self, $file);
             $dialog->show;
             $dialog->destroy;
@@ -1424,7 +1456,6 @@ use Gtk2;
         $command = $self->{options}->audio if $format eq 'audio';
         if ($^O =~ /win32/i)
         {
-            #"
             if ($format eq 'program')
             {
                 if ($withParams)
@@ -1436,14 +1467,14 @@ use Gtk2;
                     $file =~ s/([^\\])"/$1\\"/g;
                     $command = '"'.$file.'"';
                 }
-                $command = '"" '.$command ;
             }
             else
             {
+                $command = '"'.$command.'"';
                 $file =~ s/([^\\])"/$1\\"/g;
                 $command .= ' "'.$file.'"';
             }
-            system "start $command";
+            system "start \"\" $command";
         }
         else
         {
@@ -1473,9 +1504,12 @@ use Gtk2;
     {
         my ($self, $file, $panel) = @_;
         
-        my $infoExtractor = new GCVideoInfo($file);
-        $self->getDialog('Extract')->setInfo($infoExtractor->getInfo, $panel);
-        $self->getDialog('Extract')->show;
+        my $infoExtractor = $self->{model}->getExtracter($self, $file, $panel, $self->{model});
+        #$self->getDialog('Extract')->setInfo($infoExtractor->getInfo, $panel);
+        #$self->getDialog('Extract')->show;
+        my $dialog = new GCExtractDialog($self, $self->{model}, $infoExtractor);
+        $dialog->setInfo($infoExtractor, $panel);
+        $dialog->show;
     }
 
     sub setStatus
@@ -1994,7 +2028,6 @@ use Gtk2;
             my @pics = glob($self->{pluginsPicturesDir}.'/*.png');
             $self->{hasPluginsPictures} = 1 if $#pics > 0;
         }
-
         $self->{lang} = $GCLang::langs{$self->{options}->lang};
 
         GCPlugins::loadPlugins;
@@ -2265,6 +2298,9 @@ use Gtk2;
         
         $self->show_all;
 
+        # Workaround for a Gtk2 bug. Field selector is not shown again when hidden.
+        $self->{toolbar}->setShowFieldsSelection($self->{options}->toolbarPosition <= 1);
+
         #$splash->setProgress(0.08) if $splash;
 
         $self->checkDisplayed;
@@ -2381,6 +2417,7 @@ use Gtk2;
             $self->{toolbar}->set_style('icons');
             $self->{mainHbox}->pack_start($self->{handleToolbar},0,0,0);
             $self->{handleToolbar}->set_handle_position('top');
+            #$self->{toolbar}->setShowFieldsSelection(0);
             if ($position == 2) # left
             {
                 $self->{handleToolbar}->set_snap_edge('left');
@@ -2396,9 +2433,10 @@ use Gtk2;
         {
             $self->{boxToolbar} = new Gtk2::HBox(0,0);
             $self->{toolbar}->set_orientation('horizontal');
-            $self->{toolbar}->unset_style;
+            #$self->{toolbar}->unset_style;
             $self->{mainVbox}->pack_start($self->{handleToolbar},0,0,0 );
             $self->{handleToolbar}->set_handle_position('left');
+            #$self->{toolbar}->setShowFieldsSelection(1);
             if ($position == 1) # bottom
             {
                 $self->{handleToolbar}->set_snap_edge('bottom');
@@ -2414,6 +2452,7 @@ use Gtk2;
         $self->{boxToolbar}->pack_start($self->{logoButton},0,0,0);
         $self->{handleToolbar}->add($self->{boxToolbar});
         $self->{handleToolbar}->show_all;
+        $self->{toolbar}->setShowFieldsSelection($position <= 1);
     }
 
     sub checkDisplayed
@@ -2533,10 +2572,9 @@ use Gtk2;
 
         $self->{itemsList}->setSortOrder;
 
-        my $splashValue = 0.91;
 #        my $splashStep = 0.08 / (scalar @{$self->{model}->{fieldsHistory}});
         $splash->setProgress(0.99) if $splash;
-        
+
         # Windows program starts iconify to hide console window.
         # Here we make only main window become visible.
         $self->deiconify if ($^O =~ /win32/i);
