@@ -109,6 +109,7 @@ use strict;
         {
             $self->addBookmarksDir($sub, $parent);
         }
+        return if !$dir->{file};
         foreach my $file(@{$dir->{file}})
         {
             $self->addBookmark($file, $parent);
@@ -451,6 +452,12 @@ use strict;
         $self->{savedb}->set_sensitive($value);
     }
     
+    sub setAddBookmarkActive
+    {
+        my ($self, $value) = @_;
+        $self->{addBookmark}->set_sensitive($value);
+    }
+    
     sub setCollectionLock
     {
         my ($self, $value) = @_;
@@ -720,11 +727,11 @@ use strict;
         $self->{menuBookmarks} = Gtk2::Menu->new();
         my $bto = Gtk2::TearoffMenuItem->new();
         $self->{menuBookmarks}->append($bto);
-        my $addBookmark = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuBookmarksAdd});
-        $addBookmark->signal_connect('activate' , sub {
+        $self->{addBookmark} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuBookmarksAdd});
+        $self->{addBookmark}->signal_connect('activate' , sub {
             $self->{parent}->addBookmark;
         });
-        $self->{menuBookmarks}->append($addBookmark);
+        $self->{menuBookmarks}->append($self->{addBookmark});
 
         my $editBookmark = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuBookmarksEdit});
         $editBookmark->signal_connect('activate' , sub {
@@ -750,6 +757,11 @@ use strict;
             $window->help;
         }, $self->{parent});
         $self->{menuHelp}->append($help);
+        my $plugins = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuAllPlugins});
+        $plugins->signal_connect ('activate' => sub {
+            $self->{parent}->showAllPlugins;
+        });
+        $self->{menuHelp}->append($plugins);
         my $depend = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{InstallDependencies});
         $depend->signal_connect ('activate' => sub {
             $self->{parent}->showDependencies;
@@ -851,6 +863,7 @@ use strict;
         $self->{groupLabel} = new Gtk2::Label($self->{lang}->{ToolbarGroupBy});
         $self->append_widget($self->{groupLabel}, undef, undef);
         $self->{groupOption} = new GCFieldSelector;
+        $self->{groupOption}->set_focus_on_click(0);
         $self->{groupOption}->signal_connect('changed' => sub {
             return if $self->{blocked};
             my $field = $self->{groupOption}->getValue;
@@ -865,10 +878,52 @@ use strict;
         $self->append_widget($self->{groupBox}, undef, undef);
         $self->{blocked} = 1;
         $self->setSaveActive(0);
+        $self->{showFieldsSelection} = 1;
 
         return $self;
     }
     
+#    sub setShowFieldsSelection
+#    {
+#        my ($self, $value) = @_;
+#        if ($value != $self->{showFieldsSelection})
+#        {
+#            if ($value)
+#            {
+#                print "HEre\n";
+#                $self->append_widget($self->{groupLabel}, undef, undef);
+#                $self->append_widget($self->{groupBox}, undef, undef);
+#                $self->{groupOption}->setValues($self->{groupOption}->getValues);
+#                $self->{groupOption}->hide_all;
+#                $self->{groupOption}->show_all;
+#                $self->{groupBox}->show_all;
+#                $self->{groupOption}->popup;
+#                $self->hide_all;
+#            }
+#            else
+#            {
+#                $self->remove($self->{groupLabel});
+#                $self->remove($self->{groupBox});
+#            }
+#        }
+#        $self->{showFieldsSelection} = $value;
+#    }
+    
+    sub setShowFieldsSelection
+    {
+        my ($self, $value) = @_;
+        if ($value)
+        {
+            $self->{groupLabel}->show;
+            $self->{groupBox}->show;
+        }
+        else
+        {
+            $self->{groupLabel}->hide;
+            $self->{groupBox}->hide;
+        }
+    }
+
     sub setSaveActive
     {
         my ($self, $value) = @_;
