@@ -37,11 +37,13 @@ our $initDefault = 'DefaultNewItem';
     package GCModelLoader;
 
     use XML::Simple;
+    $XML::Simple::PREFERRED_PARSER='XML::Parser';
 
     sub load
     {
         my ($self, $file) = @_;
         open XML, $file;
+        binmode(XML, ':utf8');
         $self->{xmlString} = do {local $/; <XML>};
         $self->loadFromString;
         close XML;
@@ -143,6 +145,8 @@ our $initDefault = 'DefaultNewItem';
             return 0;
         }
         binmode(DATA, ':utf8');
+        print DATA '<?xml version="1.0" encoding="UTF-8"?>
+';
         print DATA $self->toString('collection', 1);
         close DATA;
         $self->{isInline} = 0;
@@ -817,6 +821,17 @@ our $initDefault = 'DefaultNewItem';
         return $id;
     }
 
+    sub getDisplayedLabel
+    {
+        my ($self, $field) = @_;
+
+        return $self->getDisplayedText($self->{fieldsInfo}->{$field}->{label})
+            if exists $self->{fieldsInfo}->{$field};
+        return $self->getGroups->{$field}->{displayed}
+            if exists $self->getGroups->{$field};
+        return $self->getDisplayedText($field);
+    }
+
     sub getDisplayedValue
     {
         my ($self, $values, $value) = @_;
@@ -958,6 +973,21 @@ our $initDefault = 'DefaultNewItem';
         return $GCPlugins::pluginsMap{$self->getName}->{$pluginName};
     }
 
+    sub getExtracter
+    {
+        my $self = shift;
+        #return $self->{extracter} if exists $self->{extracter};
+        return 0 if $self->isPersonal;
+        my $extracter;
+        (my $module = 'GCExtract::GCExtract'.$self->getName) =~ s/(GCExtract)GC(.)/$1\U$2\E/;
+        eval "use $module";
+        my $extracterName = 'GCExtract::'.$self->getName.'Extracter';
+        $extracter = new $extracterName(@_);
+        #$self->{extracter} = ($extracter->{errors} ? 0 : $extracter);
+        #return $self->{extracter};
+        return ($extracter->{errors} ? 0 : $extracter);
+    }
+
     sub new
     {
         my ($proto, $parent, $file) = @_;
@@ -1122,6 +1152,7 @@ our $initDefault = 'DefaultNewItem';
             push @results, {name => $model->getName,
                             description => $model->getDescription};
         }
+        @results = sort {$a->{description} cmp $b->{description}} @results;
         return \@results;
     }
 }
