@@ -68,7 +68,7 @@ use Gtk2;
         my $result = "<".$GCData::inlinePreferencesTag.">\n";
         while (my ($key,$value) = each(%{$self->{options}}))
         {
-            $result .= "  <$key>$value</$key>\n";
+            $result .= "  <$key>".GCUtils::encodeEntities($value)."</$key>\n";
         }
         $result .= "</$GCData::inlinePreferencesTag>";
         return $result;
@@ -109,7 +109,7 @@ use Gtk2;
                 $self->{created} = 1;
             
                 my $tmpLang = $ENV{LANG};
-                $tmpLang =~ s/(..)_.*/\U$1\E/ if $tmpLang;
+                $tmpLang =~ s/(..)_?.*/\U$1\E/ if $tmpLang;
                 $tmpLang = $DEFAULT_LANG if ! $tmpLang;
             
                 print OPTIONS 'images='.$ENV{GCS_DATA_HOME}.'/images/
@@ -167,6 +167,7 @@ useTitleForPics=0
         }
                 
         close OPTIONS;
+        #GCLang::loadLangs($self->lang);
         $self->lang($DEFAULT_LANG) if $main && (! exists $GCLang::langs{$self->lang});
     }
 
@@ -195,6 +196,7 @@ useTitleForPics=0
 		my $value;
         while (($key,$value) = each(%options))
         {
+            next if !$key;
             $line = $key.'='.$value;
             print OPTIONS "$line\n";            
         }
@@ -389,29 +391,17 @@ useTitleForPics=0
         $self->{columns} = $self->{options}->columns;
 
         $self->{options}->toolbar(1) if ! $self->{options}->exists('toolbar');
-        $self->{toolbarOption}->set_history($self->{options}->toolbar);
+        $self->{toolbarOption}->setValue($self->{options}->toolbar);
 
         $self->{options}->toolbarPosition(0) if ! $self->{options}->exists('toolbarPosition');
-        $self->{toolbarPositionOption}->set_history($self->{options}->toolbarPosition);
+        $self->{toolbarPositionOption}->setValue($self->{options}->toolbarPosition);
 
         $self->{options}->view(0) if ! $self->{options}->exists('view');
-        $self->{viewOption}->set_history($self->{options}->view);
+        $self->{viewOption}->setValue($self->{options}->view);
        
-        my @plugins = @{$self->{plugins}};
         $self->{model}->{preferences}->plugin('ask')
             if ! $self->{model}->{preferences}->exists('plugin');
-        my $i = 0;
-        foreach (@plugins)
-        {
-            last if ($self->{model}->{preferences}->plugin eq 'ask')
-                     || ($self->{model}->{preferences}->plugin eq 'multi')
-                     || ($self->{model}->{preferences}->plugin eq 'multiask')
-                     || ($_ eq $self->{model}->{preferences}->plugin);
-            $i++;
-        }
-        $i++ if $self->{model}->{preferences}->plugin eq 'multiask';
-        $i += 2 if $self->{model}->{preferences}->plugin eq 'multi';
-        $self->{pluginOption}->set_history($i);
+        $self->{pluginOption}->setValue($self->{model}->{preferences}->plugin);
 
         $self->{askImport}->set_active($self->{options}->askImport);
         $self->{searchStop}->set_active($self->{options}->searchStop);
@@ -420,23 +410,8 @@ useTitleForPics=0
         $self->{langOption}->setValue($self->{options}->lang);
         $self->{styleOption}->setValue($self->{options}->style);
 
-        my $layoutIdx = 0;
-        foreach (@{$self->{model}->{panelsNames}})
-        {
-            last if $_ eq $self->{model}->{preferences}->layout;
-            $layoutIdx++;
-        }
-        $self->{layoutOption}->set_history($layoutIdx);
-        
-        my @panelStyles= @{$self->{panelStyles}};
-        my $panelStylesCurrent = $self->{options}->panelStyle;
-        $i = 0;
-        foreach (@panelStyles)
-        {
-            last if ($_ eq $panelStylesCurrent);
-            $i++;
-        }
-        $self->{panelStyleOption}->set_history($i);
+        $self->{layoutOption}->setValue($self->{model}->{preferences}->layout);
+        $self->{panelStyleOption}->setValue($self->{options}->panelStyle);
 
         $self->{options}->mailer('Sendmail') if ! $self->{options}->exists('mailer');
         $self->{mailerOption}->setValue($self->{options}->mailer);
@@ -461,8 +436,6 @@ useTitleForPics=0
         $self->{model}->{preferences}->details($self->{model}->{commonFields}->{title})
             if ! $self->{model}->{preferences}->exists('details');
         $self->{details} = $self->{model}->{preferences}->details;
-        #$self->{options}->groupItems(1) if ! $self->{options}->exists('groupItems');
-        #$self->{groupItems} = $self->{options}->groupItems;
         
         $self->{groupBy} = $self->{model}->{preferences}->groupBy;
         $self->{masterType} = $self->{model}->{preferences}->masterType;
@@ -531,19 +504,13 @@ useTitleForPics=0
 	
             $self->{options}->lang($self->{langOption}->getValue);
             $self->{options}->style($self->{styleOption}->getValue);
-            
-            my $layoutIndex = $self->{layoutOption}->get_history;
-            $self->{model}->{preferences}->layout($self->{model}->{panelsNames}->[$layoutIndex]);
-            
-            my $panelStyleIndex = $self->{panelStyleOption}->get_history;
-            $self->{options}->panelStyle($self->{panelStyleOption}->child->get_label);
-
-            $self->{options}->toolbar($self->{toolbarOption}->get_history);
-
-            $self->{options}->toolbarPosition($self->{toolbarPositionOption}->get_history);
+            $self->{model}->{preferences}->layout($self->{layoutOption}->getValue);
+            $self->{options}->panelStyle($self->{panelStyleOption}->getValue);
+            $self->{options}->toolbar($self->{toolbarOption}->getValue);
+            $self->{options}->toolbarPosition($self->{toolbarPositionOption}->getValue);
 
             my $currentView = $self->{options}->view;
-            $self->{options}->view($self->{viewOption}->get_history);
+            $self->{options}->view($self->{viewOption}->getValue);
             
             my $currentColumns = $self->{options}->columns;
             my $currentImgSize = $self->{options}->listImgSize;
@@ -552,7 +519,6 @@ useTitleForPics=0
             my $currentFg = $self->{options}->listFgColor;
             my $currentBgPicture = $self->{options}->listBgPicture;
             my $currentDetails = $self->{model}->{preferences}->details;
-            #my $currentGroupItems = $self->{options}->groupItems;
             my $currentGroupBy = $self->{model}->{preferences}->groupBy;
             my $currentMasterType = $self->{model}->{preferences}->masterType;
             my $currentOrderBy = $self->{model}->{preferences}->orderBy;
@@ -563,7 +529,6 @@ useTitleForPics=0
             $self->{options}->listFgColor($self->{mlfg});
             $self->{options}->listBgPicture($self->{listBgPicture});
             $self->{model}->{preferences}->details($self->{details});
-            #$self->{options}->groupItems($self->{groupItems});
             $self->{model}->{preferences}->groupBy($self->{groupBy});
             $self->{model}->{preferences}->masterType($self->{masterType});
             $self->{model}->{preferences}->orderBy($self->{orderBy});
@@ -609,8 +574,6 @@ useTitleForPics=0
                       ||
                       ($currentDetails ne $self->{model}->{preferences}->details)
                       ||
-                      #($currentGroupItems != $self->{options}->groupItems)
-                      #||
                       ($currentGroupBy ne $self->{model}->{preferences}->groupBy)
                       ||
                       ($currentMasterType ne $self->{model}->{preferences}->masterType)
@@ -623,19 +586,7 @@ useTitleForPics=0
                 $self->{parent}->setItemsList(0);
             }
 
-		    my $selPlugin = $self->{pluginOption}->child->get_label;
-		    my $plugin = 'ask';
-		    foreach (@{$self->{plugins}})
-		    {
-				last if $selPlugin eq $self->{parent}->{lang}->{OptionsAskPlugins};
-                last if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMulti};
-                last if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMultiAsk};
-				$plugin = $_;
-				last if $plugin eq $selPlugin;
-		    }
-		    $plugin = 'multi' if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMulti};
-		    $plugin = 'multiask' if $selPlugin eq $self->{parent}->{lang}->{OptionsPluginsMultiAsk};
-		    $self->{model}->{preferences}->plugin($plugin);
+            $self->{model}->{preferences}->plugin($self->{pluginOption}->getValue);
        
             $self->{options}->askImport(($self->{askImport}->get_active) ? 1 : 0);
             $self->{options}->searchStop(($self->{searchStop}->get_active) ? 1 : 0);
@@ -677,40 +628,20 @@ useTitleForPics=0
         my ($self, $model) = @_;
 
         $self->{model} = $model;
-        if ($self->{plugin})
-        {
-            $self->{pluginOption}->remove_menu;
-            $self->{plugin}->destroy;
-        }
-        $self->{plugin} = new Gtk2::Menu();
-		my @plugins = ($self->{parent}->{lang}->{OptionsAskPlugins},
-                       $self->{parent}->{lang}->{OptionsPluginsMultiAsk},
-                       $self->{parent}->{lang}->{OptionsPluginsMulti},
-                       @{$model->getPluginsNames});
-		foreach (@plugins)
-		{
-		    my $item = Gtk2::MenuItem->new_with_label($_);
-		    $self->{plugin}->append($item) ;
-		}
-		$self->{plugins} = \@plugins;
-		$self->{pluginOption}->set_menu($self->{plugin});
-		$self->{plugin}->show_all;
-		
-		if ($self->{layout})
-		{
-            $self->{layoutOption}->remove_menu;
-            $self->{layout}->destroy;
-		}
-        $self->{layout} = new Gtk2::Menu();
-        foreach (@{$model->{panelsNames}})
-        {
-            my $text = $model->getDisplayedText($model->{panels}->{$_}->{label});
-            my $item = Gtk2::MenuItem->new_with_label($text);
-            $self->{layout}->append($item);
-        }
-        
-        $self->{layoutOption}->set_menu($self->{layout}) ;
-		
+        my @plugins = map {{value => $_,
+                           displayed => $_}}
+                         @{$model->getPluginsNames};
+        unshift @plugins, (
+                            {value => 'ask', displayed => $self->{parent}->{lang}->{OptionsAskPlugins}},
+                            {value => 'multiask', displayed => $self->{parent}->{lang}->{OptionsPluginsMultiAsk}},
+                            {value => 'multi', displayed => $self->{parent}->{lang}->{OptionsPluginsMulti}},
+                          );
+        $self->{pluginOption}->setValues(\@plugins);
+
+        my @panels = map {{value => $_,
+                           displayed => $model->getDisplayedText($model->{panels}->{$_}->{label})}}
+                         @{$model->{panelsNames}};
+        $self->{layoutOption}->setValues(\@panels);
     }
 
     sub initMailerOption
@@ -797,16 +728,14 @@ useTitleForPics=0
         $tableDisplay->attach($labelDisplayInformationGroup, 0, 6, 0, 1, 'fill', 'fill', 0, 0);
 
         my $labelView = new GCLabel($parent->{lang}->{OptionsView});
-        $self->{viewOption} = new Gtk2::OptionMenu();
-		$self->{view} = new Gtk2::Menu();
-		my %views = %{$parent->{lang}->{OptionsViews}};
-		foreach (0..(scalar(keys %views) - 1))
-		{
-		    my $item = Gtk2::MenuItem->new_with_label($views{$_});
-		    $self->{view}->append($item);
-		}
-        $self->{viewOption}->set_menu($self->{view});
-        $self->{viewOption}->set_alignment(0.0,0.0);
+        my %views = %{$parent->{lang}->{OptionsViews}};
+        $self->{viewOption} = new GCMenuList;
+        my @viewsOptions = map {{value => $_, displayed => $views{$_}}}
+                              (sort keys %views);
+        $self->{viewOption}->setValues(\@viewsOptions);
+
+
+
         $tableDisplay->attach($labelView, 2, 3, 1, 2, 'fill', 'fill', 0, 0);
         $tableDisplay->attach($self->{viewOption}, 3, 4, 1, 2, 'fill', 'fill', 0, 0);
 
@@ -826,9 +755,7 @@ useTitleForPics=0
         $self->{hboxDetails}->pack_start($self->{buttonDetails}, 0, 0, 0);
 
         $self->{viewOption}->signal_connect('changed' => sub {
-                my %views = %{$self->{parent}->{lang}->{OptionsViews}};
-                my $i = 0;
-                $i++ while ($views{$i} ne $self->{viewOption}->child->get_label);
+                my $i = $self->{viewOption}->getValue;
                 $self->{hboxImages}->hide;
                 $self->{hboxDetails}->hide;
                 $self->{hboxImages}->show_all if ($i == 1);
@@ -838,10 +765,9 @@ useTitleForPics=0
         $tableDisplay->attach($self->{hboxDetails}, 4, 6, 1, 2, 'fill', 'fill', 0, 0);
 
         my $labelLayout = new GCLabel($parent->{lang}->{OptionsLayout});
-		$self->{layoutOption} = new Gtk2::OptionMenu();
+        $self->{layoutOption} = new GCMenuList;
         $self->{layoutOption}->signal_connect('changed' => sub {
-                my $layoutIndex = $self->{layoutOption}->get_history;
-                my $panelName = $self->{model}->{panelsNames}->[$layoutIndex];
+                my $panelName = $self->{layoutOption}->getValue;
                 my $readonly = ($self->{model}->{panels}->{$panelName}->{editable} eq 'false');
                 if ($readonly)
                 {
@@ -858,42 +784,31 @@ useTitleForPics=0
         $tableDisplay->attach($self->{layoutOption}, 3, 4, 2, 3, 'fill', 'fill', 0, 0);
 
         $self->{labelPanelStyle} = new GCLabel($parent->{lang}->{OptionsStyle});
-        $self->{panelStyleOption} = new Gtk2::OptionMenu();
-        my @panelStyles = sort @GCStyle::readOnlyStyles;
-        $self->{panelStyle} = new Gtk2::Menu();
-        foreach (@panelStyles)
-        {
-            my $item = Gtk2::MenuItem->new_with_label($_);
-            $self->{panelStyle}->append($item);
-        }
-        $self->{panelStyles} = \@panelStyles;
-        $self->{panelStyleOption}->set_menu($self->{panelStyle});
+        $self->{panelStyleOption} = new GCMenuList;
+        my @panelStyles = map {{value => $_, displayed => $_}}
+                              (sort @GCStyle::readOnlyStyles);
+        $self->{panelStyleOption}->setValues(\@panelStyles);
+
         $tableDisplay->attach($self->{labelPanelStyle}, 4, 5, 2, 3, 'fill', 'fill', 0, 0);
         $tableDisplay->attach($self->{panelStyleOption}, 5, 6, 2, 3, ['fill'], 'fill', 30, 0);
 
         my $labelToolbar = new GCLabel($parent->{lang}->{OptionsToolbar});
-        $self->{toolbarOption} = new Gtk2::OptionMenu();
-		$self->{toolbar} = new Gtk2::Menu();
-		my %toolbars = %{$parent->{lang}->{OptionsToolbars}};
-		foreach (0..(scalar(keys %toolbars) - 1))
-		{
-		    my $item = Gtk2::MenuItem->new_with_label($toolbars{$_});
-		    $self->{toolbar}->append($item);
-		}
-        $self->{toolbarOption}->set_menu($self->{toolbar}) ;
+        $self->{toolbarOption} = new GCMenuList;
+        my %toolbars = %{$parent->{lang}->{OptionsToolbars}};
+        my @toolbarValues = map {{value => $_, displayed => $toolbars{$_}}}
+                                (sort keys %toolbars);
+        $self->{toolbarOption}->setValues(\@toolbarValues);
+
         $tableDisplay->attach($labelToolbar, 2, 3, 3, 4, 'fill', 'fill', 0, 0);
         $tableDisplay->attach($self->{toolbarOption}, 3, 4, 3, 4, 'fill', 'fill', 0, 0);
 
         my $labelToolbarPosition = new GCLabel($parent->{lang}->{OptionsToolbarPosition});
-        $self->{toolbarPositionOption} = new Gtk2::OptionMenu();
-		$self->{toolbarPosition} = new Gtk2::Menu();
-		my %toolbarPositions = %{$parent->{lang}->{OptionsToolbarPositions}};
-		foreach (0..(scalar(keys %toolbarPositions) - 1))
-		{
-		    my $item = Gtk2::MenuItem->new_with_label($toolbarPositions{$_});
-		    $self->{toolbarPosition}->append($item);
-		}
-        $self->{toolbarPositionOption}->set_menu($self->{toolbarPosition}) ;
+        $self->{toolbarPositionOption} = new GCMenuList;
+        my %toolbarPositions = %{$parent->{lang}->{OptionsToolbarPositions}};
+        my @positionValues = map {{value => $_, displayed => $toolbarPositions{$_}}}
+                                 (sort keys %toolbarPositions);
+        $self->{toolbarPositionOption}->setValues(\@positionValues);
+
         $tableDisplay->attach($labelToolbarPosition, 4, 5, 3, 4, 'fill', 'fill', 0, 0);
         $tableDisplay->attach($self->{toolbarPositionOption}, 5, 6, 3, 4, ['fill'], 'fill', 30, 0);
 
@@ -983,13 +898,14 @@ useTitleForPics=0
         $tableInternet->attach($self->{dataGroupLabel}, 0, 5, 0, 1, 'fill', 'fill', 0, 0); 
 	    
 		$self->{pluginLabel} = new GCLabel($parent->{lang}->{OptionsPlugins});
-		$self->{pluginOption} = new Gtk2::OptionMenu();
+        $self->{pluginOption} = new GCMenuList;
 		$self->{pluginList} = new Gtk2::Button($parent->{lang}->{OptionsPluginsList});
 		$self->{pluginList}->signal_connect('clicked' => sub {
 		  $parent->selectMultiPluginsList;
 		});
 		$self->{pluginOption}->signal_connect('changed' => sub {
-	       if (($self->{pluginOption}->child->get_label eq $parent->{lang}->{OptionsPluginsMulti}) || ($self->{pluginOption}->child->get_label eq $parent->{lang}->{OptionsPluginsMultiAsk}))
+	       if (($self->{pluginOption}->getValue eq 'multi') 
+	        || ($self->{pluginOption}->getValue eq 'multiask'))
            {
                $self->{pluginList}->show;
            }
@@ -1163,16 +1079,8 @@ useTitleForPics=0
         my $self = shift;
         
         $self->{columns}->set_value($self->{parent}->{columns});
-        
-        $self->{imgSizeOption}->set_history($self->{parent}->{listImgSize});
-        
-        my $idx = 0;
-        foreach (@GCStyle::lists)
-        {
-            last if $_ eq $self->{parent}->{listImgSkin};
-            $idx++;
-        }
-        $self->{optionStyle}->set_history($idx);
+        $self->{imgSizeOption}->setValue($self->{parent}->{listImgSize});
+        $self->{optionStyle}->setValue($self->{parent}->{listImgSkin});
         
         $self->{listBgPicture}->set_active($self->{parent}->{listBgPicture});
         $self->activateColors(! $self->{parent}->{listBgPicture});
@@ -1185,10 +1093,8 @@ useTitleForPics=0
         my $self = shift;
         
         $self->{parent}->{columns} = $self->{columns}->get_value;
-        
-        $self->{parent}->{listImgSize} = $self->{imgSizeOption}->get_history;
-
-        $self->{parent}->{listImgSkin} = $self->{optionStyle}->child->get_label;
+        $self->{parent}->{listImgSize} = $self->{imgSizeOption}->getValue;
+        $self->{parent}->{listImgSkin} = $self->{optionStyle}->getValue;
         $self->{parent}->{mlbg} = $self->{mlbg};
         $self->{parent}->{mlfg} = $self->{mlfg};
         $self->{parent}->{listBgPicture} = (($self->{listBgPicture}->get_active) ? 1 : 0);
@@ -1258,15 +1164,11 @@ useTitleForPics=0
         $self->{columns} = Gtk2::SpinButton->new($adj, 0, 0);
 
         my $imgSizeLabel = new GCLabel($parent->{lang}->{ImagesOptionsSizeLabel});
-        $self->{imgSizeOption} = new Gtk2::OptionMenu;
-		$self->{imgSize} = new Gtk2::Menu();
-		my %imgSizes = %{$parent->{lang}->{ImagesOptionsSizeList}};
-		foreach (0..(scalar(keys %imgSizes) - 1))
-		{
-		    my $item = Gtk2::MenuItem->new_with_label($imgSizes{$_});
-		    $self->{imgSize}->append($item);
-		}
-        $self->{imgSizeOption}->set_menu($self->{imgSize}) ;
+        $self->{imgSizeOption} = new GCMenuList;
+        my %imgSizes = %{$parent->{lang}->{ImagesOptionsSizeList}};
+        my @imgValues = map {{value => $_, displayed => $imgSizes{$_}}}
+                                 (sort keys %imgSizes);
+        $self->{imgSizeOption}->setValues(\@imgValues);
 
         $self->{listBgPicture} = new Gtk2::CheckButton($parent->{lang}->{ImagesOptionsBgPicture});
         $self->{listBgPicture}->signal_connect('clicked' => sub {
@@ -1274,15 +1176,10 @@ useTitleForPics=0
         });
         
         $self->{labelStyle} = new GCLabel($parent->{lang}->{OptionsStyle});
-		$self->{optionStyle} = new Gtk2::OptionMenu();
-		$self->{style} = new Gtk2::Menu();
-		foreach (@GCStyle::lists)
-		{
-		    my $item = Gtk2::MenuItem->new_with_label($_);
-		    $self->{style}->append($item);
-		}
-		$self->{optionStyle}->set_menu($self->{style}) ;
-
+        $self->{optionStyle} = new GCMenuList;
+        my @styleValues = map {{value => $_, displayed => $_}}
+                               @GCStyle::lists;
+        $self->{optionStyle}->setValues(\@styleValues);
        
         $self->{labelBg} = new GCLabel($parent->{lang}->{ImagesOptionsBg});
         $self->{buttonBg} = new Gtk2::Button($parent->{lang}->{ImagesOptionsSelectColor});
@@ -1336,7 +1233,7 @@ useTitleForPics=0
     {
         my $self = shift;
         
-        $self->{imgSizeOption}->set_history($self->{parent}->{listImgSize});
+        $self->{imgSizeOption}->setValue($self->{parent}->{listImgSize});
         $self->{groupByOption}->setValue($self->{parent}->{groupBy});
         if ($self->{parent}->{masterType} eq 'generated')
         {
@@ -1346,14 +1243,6 @@ useTitleForPics=0
         {
             $self->{masterDetermined}->set_active(1);
         }
-
-#        my $i = 0;
-#        foreach (@{$self->{fields}})
-#        {
-#            last if ($_ eq $self->{parent}->{orderBy});
-#            $i++;
-#        }
-#        $self->{orderByOption}->set_history($i);
         $self->{orderByOption}->setValue($self->{parent}->{orderBy});
     }
     
@@ -1361,13 +1250,7 @@ useTitleForPics=0
     {
         my $self = shift;
         
-        $self->{parent}->{listImgSize} = $self->{imgSizeOption}->get_history;
-
-        #$self->{parent}->{groupItems} = (($self->{groupItems}->get_active) ? 1 : 0);
-
-#        my $i = $self->{groupByOption}->get_history;
-#        $self->{parent}->{groupBy} = '';
-#        $self->{parent}->{groupBy} =  $self->{fields}->[$i - 1] if $i;
+        $self->{parent}->{listImgSize} = $self->{imgSizeOption}->getValue;
         $self->{parent}->{groupBy} =  $self->{groupByOption}->getValue;
 
         if ($self->{masterAuto}->get_active())
@@ -1378,8 +1261,6 @@ useTitleForPics=0
         {
             $self->{parent}->{masterType} = 'ordered';
         }
-
-#        $self->{parent}->{orderBy} = $self->{fields}->[$self->{orderByOption}->get_history];
         $self->{parent}->{orderBy} = $self->{orderByOption}->getValue;
     }
     
@@ -1455,15 +1336,11 @@ useTitleForPics=0
         $self->{masterDetermined} = new Gtk2::RadioButton($self->{masterRadioGroup}, $parent->{lang}->{DetailedOptionsMasterOrdered});
         
         my $imgSizeLabel = new GCLabel($parent->{lang}->{DetailedOptionsImageSize});
-        $self->{imgSizeOption} = new Gtk2::OptionMenu();
-		$self->{imgSize} = new Gtk2::Menu();
+        $self->{imgSizeOption} = new GCMenuList;
         my %imgSizes = %{$parent->{lang}->{ImagesOptionsSizeList}};
-        foreach (0..(scalar(keys %imgSizes) - 1))
-        {
-            my $item = Gtk2::MenuItem->new_with_label($imgSizes{$_});
-            $self->{imgSize}->append($item);
-        }
-        $self->{imgSizeOption}->set_menu($self->{imgSize}) ;
+        my @imgValues = map {{value => $_, displayed => $imgSizes{$_}}}
+                                 (sort keys %imgSizes);
+        $self->{imgSizeOption}->setValues(\@imgValues);
 
         my $preferencesLabel = new GCHeaderLabel($parent->{lang}->{OptionsDetailedPreferencesGroup});
         $tableLayout->attach($preferencesLabel, 0, 6, 0, 1, 'fill', 'fill', 0, 0);
