@@ -150,7 +150,6 @@ use strict;
     {
         my ($self, $show, $hasToShow) = @_;
         return if ! $self->initShow($show, $hasToShow);
-        
         my %parentsToHide;
         foreach (keys %{$show})
         {
@@ -456,6 +455,15 @@ use strict;
                 });
                 push @{$self->{dependencies}->{$_->{for}}}, $widget;
             }
+            elsif ($_->{type} eq 'extractor')
+            {
+                $widget = Gtk2::Button->new($self->{parent}->{lang}->{ExtractButton});
+                my $valueWidget = $self->{$_->{for}};
+                $widget->signal_connect('clicked' => sub {
+                    $self->{parent}->extractInfo($valueWidget->getValue, $self);
+                });
+                push @{$self->{dependencies}->{$_->{for}}}, $widget;
+            }
             elsif ($_->{type} eq 'line')
             {
                 $widget = new Gtk2::HBox(0,0);
@@ -825,25 +833,25 @@ use strict;
 
     sub AUTOLOAD
     {
-        my $self = shift;
-        my $name = our $AUTOLOAD;
-        return if $name =~ /::DESTROY$/;
-        $name =~ s/.*?::(.*)/$1/;
-        if (scalar @_)
-        {
+        return if our $AUTOLOAD =~ /::DESTROY$/;
+        (my $name = $AUTOLOAD) =~ s/.*?::(.*)/$1/;
+        return if !$name;
+        no strict 'refs';
+        
+        *{$AUTOLOAD} = sub {
+            my $self = shift;
+            return 0 if !$self->{$name};
+            return $self->{$name.'Value'}
+                if !(scalar @_);
             my $text = shift;
             $self->{$name.'Value'} = $text;
-
             if (my $func = $self->{prepare}->{$name}->{func})
             {
                 $text = $self->$func($text, $self->{prepare}->{$name}->{extra});
             }
             $text = ' ' if ! defined $text;
-            if ($self->{displayedValues}->{$name})
-            {
-                $text = $self->{model}->getDisplayedValue($self->{displayedValues}->{$name}, $text);
-            }
-            
+            $text = $self->{model}->getDisplayedValue($self->{displayedValues}->{$name}, $text)
+                if ($self->{displayedValues}->{$name});
             if ($self->{$name})
             {
                 if ($self->{$name}->acceptMarkup)
@@ -857,11 +865,8 @@ use strict;
                     $self->{$name}->setValue($text);
                 }
             }
-        }
-        else
-        {
-            return $self->{$name.'Value'};
-        }
+        };
+        goto &{$AUTOLOAD};
     }
 }
 
@@ -915,12 +920,6 @@ use strict;
         $self->{mainBox} = new Gtk2::VBox(0, 0);
         $self->{mainBox}->set_border_width($self->{margin});
 
-        #$self->deactivate if ($readonly ||  $parent->{options}->lockPanel);
-        $self->{trailerExtract} = Gtk2::Button->new($parent->{lang}->{ExtractButton});
-        $self->{trailerExtract}->signal_connect('clicked' => sub {
-            $self->{parent}->extractInfo($self->{trailer}->get_text, $self);
-        });
-       
         $self->set_name('GCItemFrame');
 
         my $realMain = new Gtk2::VBox(0,0);
@@ -979,6 +978,7 @@ use strict;
             my $borrowerField = $self->{model}->{commonFields}->{borrower}->{name};
             my $lendDateField = $self->{model}->{commonFields}->{borrower}->{date};
             my $borrowingsField = $self->{model}->{commonFields}->{borrower}->{history};
+            my $coverField = $self->{model}->{commonFields}->{cover};
             my @data = ($self->{$borrowerField}->getDisplayedValue,
                         $self->{$lendDateField}->getValue,
                         $dialog->date);
@@ -986,8 +986,9 @@ use strict;
             my $previous = $self->getAsHash;
             $self->{$borrowerField}->setValue('none');
             $self->{$lendDateField}->clear;
-            my $new = $self->getAsHash;           
-            $self->{parent}->{itemsList}->changeCurrent($previous, $new) if $self->image;
+            my $new = $self->getAsHash;
+            $self->{parent}->{itemsList}->changeCurrent($previous, $new)
+                if $self->$coverField;
         }
         $self->showMe;
     }
@@ -1212,20 +1213,18 @@ use strict;
     
     sub AUTOLOAD
     {
-        my $self = shift;
-        my $name = our $AUTOLOAD;
-        return if $name =~ /::DESTROY$/;
-        $name =~ s/.*?::(.*)/$1/;
+        return if our $AUTOLOAD =~ /::DESTROY$/;
+        (my $name = $AUTOLOAD) =~ s/.*?::(.*)/$1/;
         return if !$name;
-        if (scalar @_)
-        {
-            my $text = shift;
-            $self->{$name}->setValue($text);
-        }
-        else
-        {
-            return $self->{$name}->getValue;
-        }
+        no strict 'refs';
+        *{$AUTOLOAD} = sub {
+            my $self = shift;
+            return 0 if !$self->{$name};
+            return $self->{$name}->getValue
+                if !(scalar @_);
+            ($self->{$name}->setValue(shift), return);
+        };
+        goto &{$AUTOLOAD};
     }
 }
 
