@@ -1,5 +1,5 @@
 {
-	package GCPlugins;
+    package GCPlugins;
     
 ###################################################
 #
@@ -40,7 +40,7 @@ sub loadPlugins
     {
         next if $dir =~ /PluginsBase/;
         my $model = basename($dir);
-        next if $model !~ /^GC/;
+        next if ($model !~ /^GC/) || ($model eq 'GCstar');
         foreach (glob "$dir/*.pm")
         {
             my $plugin = basename($_, '.pm')."\n";
@@ -135,42 +135,42 @@ sub loadPlugins
  
     use Gtk2;
  
-	{
-	    package GCPluginsDialog;
-	    
-	    use base 'GCModalDialog';
-	
-	    sub show
-	    {
-	        my $self = shift;
-	        $self->{useThisSite}->set_active(0);
-	        $self->SUPER::show();
-	        $self->show_all;
-	        $self->{fieldsList}->hide if $self->{hideFieldsList};
-	        my $path = $self->{pluginsList}->get_selection->get_selected_rows;
-		    $self->{pluginsList}->scroll_to_cell($path) if $path;
-	        
-	        my $response = $self->run;
-	        $self->{plugin} = undef;
-	        if ($response eq 'ok')
-	        {
-	            my $pluginName = '';
-	            my $idx = ($self->{pluginsList}->get_selected_indices)[0];
+    {
+        package GCPluginsDialog;
+        
+        use base 'GCModalDialog';
+    
+        sub show
+        {
+            my $self = shift;
+            $self->{useThisSite}->set_active(0);
+            $self->SUPER::show();
+            $self->show_all;
+            $self->{fieldsList}->hide if $self->{hideFieldsList};
+            my $path = $self->{pluginsList}->get_selection->get_selected_rows;
+            $self->{pluginsList}->scroll_to_cell($path) if $path;
+            
+            my $response = $self->run;
+            $self->{plugin} = undef;
+            if ($response eq 'ok')
+            {
+                my $pluginName = '';
+                my $idx = ($self->{pluginsList}->get_selected_indices)[0];
                 $pluginName = $self->{pluginsList}->{data}->[$idx]->[0 + $self->{withPics}];
 
-	            $self->{plugin} = $self->{model}->getPlugin($pluginName);
+                $self->{plugin} = $self->{model}->getPlugin($pluginName);
 
-	            if ($self->{useThisSite}->get_active)
-	            {
-	               $self->{parent}->{model}->{preferences}->plugin($pluginName);
-	               $self->{parent}->checkPlugin;
-	            }
-	        }
-	        $self->hide;
-	    }
-	    
-	    sub new
-	    {
+                if ($self->{useThisSite}->get_active)
+                {
+                   $self->{parent}->{model}->{preferences}->plugin($pluginName);
+                   $self->{parent}->checkPlugin;
+                }
+            }
+            $self->hide;
+        }
+        
+        sub new
+        {
             my ($proto, $parent) = @_;
             my $class = ref($proto) || $proto;
             my $self  = $class->SUPER::new($parent,
@@ -178,7 +178,7 @@ sub loadPlugins
                                            'gtk-jump-to'
                                           );
     
-    	        bless ($self, $class);
+                bless ($self, $class);
     
             $self->{parent} = $parent;
             $self->{withPics} = $parent->{hasPluginsPictures};
@@ -195,8 +195,8 @@ sub loadPlugins
             $queryHbox->pack_start($self->{fieldsList}, 0, 0, $GCUtils::halfMargin);
             $self->{titleGroup}->addWidget($queryHbox);
             $self->vbox->pack_start($self->{titleGroup}, 0, 0, 0);
-    	
-    	
+        
+        
             my $pluginGroup = undef;
             my $pluginsFrame = new GCGroup($parent->{lang}->{PluginsFrame});
              
@@ -205,12 +205,14 @@ sub loadPlugins
                 $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsLogo} => "pixbuf",
                                                             $parent->{lang}->{PluginsName} => "text",
                                                             $parent->{lang}->{PluginsLang} => "text",
+                                                            $parent->{lang}->{PluginsSearchFields} => "text",
                                                             $parent->{lang}->{PluginsAuthor} => "text",);
             }
             else
             {
                 $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsName} => "text",
                                                             $parent->{lang}->{PluginsLang} => "text",
+                                                            $parent->{lang}->{PluginsSearchFields} => "text",
                                                             $parent->{lang}->{PluginsAuthor} => "text",);
             }
             $self->{pluginsList}->set_border_width(5);
@@ -227,7 +229,7 @@ sub loadPlugins
             $self->{currentPluginList} = undef;
 
             #$self->setModel;
-	
+    
             my $scrollPanelList = new Gtk2::ScrolledWindow;
             $scrollPanelList->set_border_width(5);
             $scrollPanelList->set_policy ('never', 'automatic');
@@ -235,20 +237,20 @@ sub loadPlugins
             $scrollPanelList->add($self->{pluginsList});
 
             $self->{useThisSite} = Gtk2::CheckButton->new($parent->{lang}->{PluginsUseSite});
-	        
+            
             my $pluginBox = new Gtk2::VBox(0,0);
             $pluginBox->pack_start($scrollPanelList, 1, 1, 0);
             $pluginBox->pack_start(Gtk2::VBox->new, 0, 0, $GCUtils::halfMargin);
             $pluginBox->pack_start($self->{useThisSite}, 0, 0, 0);
-	        
+            
             $pluginsFrame->addWidget($pluginBox);
             $self->vbox->pack_start($pluginsFrame, 1, 1, 0);
 
             $self->set_default_size(1,550);
-	        
-	        return $self;
-	    }
-	
+            
+            return $self;
+        }
+    
         sub query
         {
             my $self = shift;
@@ -260,7 +262,7 @@ sub loadPlugins
             }
             return ($self->{query}->getValue, $self->{fieldsList}->getValue);
         }
-	
+    
         sub plugin
         {
             my $self = shift;
@@ -310,32 +312,187 @@ sub loadPlugins
             
             if ($model)
             {
-    	        foreach (sort keys %{$model->getAllPlugins})
-    	        {
-    	            my $plugin = $model->getPlugin($_);
+                foreach (sort keys %{$model->getAllPlugins})
+                {
+                    my $plugin = $model->getPlugin($_);
                     if ((!$list) || ($plugin->getName eq $plugins_array[$i]))
                     {
                         if ($self->{withPics})
                         {
                             my $picFile = $self->{parent}->{pluginsPicturesDir}.$plugin->getImageFile;
                             $picFile = $ENV{GCS_SHARE_DIR}.'/icons/gcstar_32x32.png' if ! -f $picFile;
-    	          	 	    my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($picFile);
-        	          	 	push @newData, [$pixbuf, $plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                               my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($picFile);
+                               push @newData, [$pixbuf, $plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
                         }
                         else
                         {
-        	          	 	push @newData, [$plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                               push @newData, [$plugin->getName, "\n".$plugin->getLang."\n",
+                                               $plugin->getSearchFields($model), $plugin->getAuthor];
                         }
-    	          	 	
+                           
                         $i++;
                     }
-    	        }
+                }
             }
             @{$self->{pluginsList}->{data}} = @newData;
             $self->{pluginsList}->select(0);
         }
     }
      
+    {
+        package GCAllPluginsDialog;
+        
+        use base 'GCModalDialog';
+    
+        sub show
+        {
+            my $self = shift;
+            $self->SUPER::show();
+            $self->show_all;
+            ($self->action_area->get_children)[1]->hide_all;
+            my $response = $self->run;
+            $self->hide;
+        }
+        
+        sub new
+        {
+            my ($proto, $parent) = @_;
+            my $class = ref($proto) || $proto;
+            my $self  = $class->SUPER::new($parent,
+                                           $parent->{lang}->{PluginsFrame},
+                                           'gtk-close'
+                                          );
+    
+            bless ($self, $class);
+
+            $self->{parent} = $parent;
+            $self->{factory} = $parent->{modelsFactory};
+
+            my @columnsNames = ('Name', 'Lang', 'SearchFields', 'Author');
+            $self->{pluginsModel} = new Gtk2::TreeStore(map {'Glib::String'} @columnsNames);
+            $self->{pluginsList} = Gtk2::TreeView->new_with_model($self->{pluginsModel});
+
+            my @columns;
+            my $i = 0;
+            for my $col(@columnsNames)
+            {
+                my $column = Gtk2::TreeViewColumn->new_with_attributes($parent->{lang}->{'Plugins'.$col},
+                                                                       Gtk2::CellRendererText->new,
+                                                                       'text' => $i);
+                $column->set_resizable(1);
+                $self->{pluginsList}->append_column($column);
+                $i++;
+            }
+
+            $self->{pluginsList}->set_border_width(5);
+            $self->{pluginsList}->set_rules_hint(1);
+
+            my $scrollPanelList = new Gtk2::ScrolledWindow;
+            $scrollPanelList->set_border_width(5);
+            $scrollPanelList->set_policy ('never', 'automatic');
+            $scrollPanelList->set_shadow_type('etched-in');
+            $scrollPanelList->add($self->{pluginsList});
+
+            $self->{useThisSite} = Gtk2::CheckButton->new($parent->{lang}->{PluginsUseSite});
+
+            my $pluginBox = new Gtk2::VBox(0,0);
+            $pluginBox->pack_start($scrollPanelList, 1, 1, 0);
+
+            for my $modelInfo (@{$self->{factory}->getDefaultModels})
+            {
+                my $modelIter = $self->{pluginsModel}->append(undef);
+                $self->{pluginsModel}->set($modelIter,
+                                           (0 => $modelInfo->{description})
+                                          );
+
+                my $model = $self->{factory}->getModel($modelInfo->{name});
+                for my $pluginName (sort keys %{$model->getAllPlugins})
+                {
+                    my $plugin = $model->getPlugin($pluginName);
+                    my $pluginIter = $self->{pluginsModel}->append($modelIter);
+                    my %data;
+                    $i = 0;
+                    my $method;
+                    ($method = 'get'.$_, $data{$i++} = $plugin->$method($model))
+                        foreach (@columnsNames);
+                    $self->{pluginsModel}->set($pluginIter, %data);
+#                                               (
+#                                                0 => $plugin->getName,
+#                                                1 => $plugin->getLang,
+#                                                2 => $plugin->getSearchFieldsAsString($model),
+#                                                4 => $plugin->getAuthor
+#                                               )
+#                                              );
+                }
+            }
+
+            $self->vbox->pack_start($pluginBox, 1, 1, 0);
+
+            $self->set_default_size(1,550);
+            
+            return $self;
+        }
+    
+        sub setModel
+        {
+            my ($self, $model, $list) = @_;
+            $model ||= $self->{parent}->{model};
+            my @plugins_array = sort split (",", $list) if $list;
+    
+            my @fields = @{$model->getSearchFields};
+            if ($#fields < 1)
+            {
+                $self->{hideFieldsList} = 1;
+            }
+            else
+            {
+                $self->{hideFieldsList} = 0;
+                my @values;
+                foreach (@fields)
+                {
+                    push @values, {value => $_,
+                                   displayed => $model->getDisplayedText($model->{fieldsInfo}->{$_}->{label})};
+                }
+                $self->{fieldsList}->setValues(\@values);
+            }
+
+            return if $list && ($self->{currentPluginList} eq $list);
+            $self->{currentPluginList} = $list;
+
+            my $pluginGroup = undef;
+            my $i = 0;
+            my @newData;
+            
+            $self->{model} = $model;
+            
+            if ($model)
+            {
+                foreach (sort keys %{$model->getAllPlugins})
+                {
+                    my $plugin = $model->getPlugin($_);
+                    if ((!$list) || ($plugin->getName eq $plugins_array[$i]))
+                    {
+                        if ($self->{withPics})
+                        {
+                            my $picFile = $self->{parent}->{pluginsPicturesDir}.$plugin->getImageFile;
+                            $picFile = $ENV{GCS_SHARE_DIR}.'/icons/gcstar_32x32.png' if ! -f $picFile;
+                               my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($picFile);
+                               push @newData, [$pixbuf, $plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                        }
+                        else
+                        {
+                               push @newData, [$plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                        }
+                           
+                        $i++;
+                    }
+                }
+            }
+            @{$self->{pluginsList}->{data}} = @newData;
+            $self->{pluginsList}->select(0);
+        }
+    }
+
     {
         #Class that is used to let user select
         #plugins he wants to use in a multi-site search.
@@ -412,13 +569,13 @@ sub loadPlugins
             $self->{model} = $model;
         }               
 
-	    sub new
-	    {
-	        my ($proto, $parent, $model) = @_;
-	        my $class = ref($proto) || $proto;
-	        my $self  = $class->SUPER::new(
-	                                $parent,
-	                                $parent->{lang}->{MultiSiteTitle}
+        sub new
+        {
+            my ($proto, $parent, $model) = @_;
+            my $class = ref($proto) || $proto;
+            my $self  = $class->SUPER::new(
+                                    $parent,
+                                    $parent->{lang}->{MultiSiteTitle}
                                 );
             bless ($self, $class);
 
@@ -445,8 +602,8 @@ sub loadPlugins
             $self->{vboxUnused}->pack_start($langButton, 0, 0, 0);
             $self->{vboxUsed}->pack_start($clearButton, 0, 0, 0);
             
-	        return $self;
-	    }
+            return $self;
+        }
     }
     
 }
@@ -550,7 +707,7 @@ sub loadPlugins
         $self->{parent} = $parent;
 
         $self->set_modal(1);
-		$self->set_position('center');
+        $self->set_position('center');
 
         $self->{scrollPanelList} = new Gtk2::ScrolledWindow;
         $self->{scrollPanelList}->set_policy ('never', 'automatic');
@@ -730,7 +887,8 @@ sub loadPlugins
                 }
                 $tmp =~ s/\n/ /g;
                 $tmp =~ s/(.{50}).*/$1.../m;
-                $self->{$_}->set_text($tmp);
+                $self->{$_}->set_text($tmp)
+                    if $self->{$_};
             }
         }
         else
@@ -828,20 +986,46 @@ sub loadPlugins
         $self->{parent} = $parent;
  
         $self->set_modal(1);
-		$self->set_position('center');
+        $self->set_position('center');
         $self->set_default_size(1,500);
 
-        my $fieldsInfo = $self->{parent}->{model}->{fieldsInfo};
-        $self->{table} = new Gtk2::Table($#fieldsInfo + 3, 2, 0);
+        $self->{table} = new Gtk2::Table(1, 2, 0);
         $self->{table}->set_row_spacings($GCUtils::halfMargin);
         $self->{table}->set_col_spacings($GCUtils::margin);
         $self->{table}->set_border_width($GCUtils::margin);
+
+        $self->{scrollPanelList} = new Gtk2::ScrolledWindow;
+        $self->{scrollPanelList}->set_policy ('never', 'automatic');
+        $self->{scrollPanelList}->set_shadow_type('none');
+        $self->{scrollPanelList}->add_with_viewport($self->{table});
+
+        $self->vbox->pack_start($self->{scrollPanelList},1,1,$GCUtils::margin);
+
+        $self->setModel($parent->{model});
+
+        return $self;
+    }
+    
+    sub setModel
+    {
+        my ($self, $model) = @_;
         
+        my $parent = $self->{parent};
+        
+        $self->{model} = $model;
+        my $fieldsInfo = $model->{fieldsInfo};
+
+        foreach ($self->{table}->get_children)
+        {
+            $self->{table}->remove($_);
+            $_->destroy;
+        }
+
         my $row = 0;
         
         my @picFields;
         my $field;
-        foreach $field(@{$self->{parent}->{model}->{fieldsNames}})
+        foreach $field(@{$model->{fieldsNames}})
         {
             next if $fieldsInfo->{$field}->{imported} ne 'true';
             next if ($fieldsInfo->{$field}->{type} eq 'url');
@@ -888,14 +1072,6 @@ sub loadPlugins
         $self->{table}->attach($self->{selectNone}, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
 
 
-        my $scrollPanelList = new Gtk2::ScrolledWindow;
-        $scrollPanelList->set_policy ('never', 'automatic');
-        $scrollPanelList->set_shadow_type('none');
-        $scrollPanelList->add_with_viewport($self->{table});
-
-        $self->vbox->pack_start($scrollPanelList,1,1,$GCUtils::margin);
- 
-        return $self;
     }
     
 }
