@@ -24,25 +24,35 @@ package GCPlugins::GCbooks::GCAmazonFR;
 
 use strict;
 
-use GCPlugins::GCbooks::GCbooksCommon;
+use GCPlugins::GCbooks::GCbooksAmazonCommon;
 
 {
     package GCPlugins::GCbooks::GCPluginAmazonFR;
 
-    use base qw(GCPlugins::GCbooks::GCbooksPluginsBase);
+    use base qw(GCPlugins::GCbooks::GCbooksAmazonPluginsBase);
 
     sub start
     {
         my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
-	
         $self->{inside}->{$tagname}++;
 
 	    if ($self->{parsingEnded})
         {
             if ($self->{itemIdx} < 0)
             {
-                $self->{itemIdx} = 0;
-                $self->{itemsList}[0]->{url} = $self->{loadedUrl};
+                if ($self->{loadedUrl} !~ m|^http://s1\.amazon|)
+                {
+                    $self->{itemIdx} = 0;
+                    $self->{itemsList}[0]->{url} = $self->{loadedUrl};
+                }
+                else
+                {
+                    if (($tagname eq 'a') && ($attr->{href} =~ m|exec/obidos/ASIN| ))
+                    {
+                        $self->{itemIdx} = 0;
+                        $self->{itemsList}[0]->{url} = $attr->{href};
+                    }
+                }
             }
             return;
         }
@@ -71,15 +81,9 @@ use GCPlugins::GCbooks::GCbooksCommon;
         }
         else
         {
-            if ($tagname eq "img")
+            if (($tagname eq "img") && (!$self->{curInfo}->{cover}))
             {
-                if (($attr->{src} =~ m%^http://.*?images[.-]amazon\.com/images/P/[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%)
-                 && (!$self->{curInfo}->{cover}))
-                {
-                    $self->{curInfo}->{cover} = $attr->{src};
-                    $self->{curInfo}->{cover} =~ s%(.*?/images/P/[0-9X.]*\.)(.*?)(_SC.ZZZZZZZ_(.*?)\.(jpg|gif))%$1$3%;
-                    $self->{curInfo}->{cover} =~ s/_PE[0-9]{2}_/_/;
-                }
+                $self->{curInfo}->{cover} = $self->extractImage($attr->{src});
             }
         }
     }
@@ -100,7 +104,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
         {
             if (($self->{inside}->{title})
              && ($origtext !~ /Amazon.fr:.*R.*sultats/)
-             && ($origtext !~ /Amazon.fr\s+Livres\s*:/))
+             && ($origtext !~ /Amazon.fr:\s+.*?Livres$/))
             {
                 $self->{parsingEnded} = 1;
             }
@@ -149,7 +153,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
             $origtext =~ s/\s*$//;
             if ($self->{inside}->{title})
             {
-                $origtext =~ m/Amazon.fr\s*:\s*(.*?):\s*Livres( en anglais)?:\s*(.*)\s*$/;
+                $origtext =~ m/Amazon.fr\s*:\s*(.*?):\s*Livres( en anglais)?:?\s*(.*)\s*$/;
 	            $self->{curInfo}->{title} = $1;
 	            $self->{curInfo}->{authors} = $3;
             }
@@ -172,8 +176,9 @@ use GCPlugins::GCbooks::GCbooksCommon;
                 }
                 else
                 {
-                    ($self->{curInfo}->{publication} = $origtext) =~ s/;\s*$//;
+                    ($self->{curInfo}->{publisher} = $origtext) =~ s/;\s*$//;
                 }
+                $self->{insidePublisher} = 0;
             }
             elsif ($self->{insidePublication})
             {
@@ -184,6 +189,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
                     $self->{insidePublication} = 0;
                     $self->{curInfo}->{publication} =~ s|([0-9]*) ([A-Za-z]*) ([0-9]*)|$1.'/'.$self->{monthNumber}->{lc $2}.'/'.$3|e;
                 }
+                $self->{insidePublication} = 0;
             }
             elsif ($self->{insideLanguage})
             {
@@ -197,7 +203,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
             }
             elsif ($self->{insideIsbn})
             {
-                $self->{curInfo}->{isbn} = $origtext;
+                ($self->{curInfo}->{isbn} = $origtext) =~ s/[^0-9X]//g;
                 $self->{insideIsbn} = 0;
             }
             elsif ($self->{insidePages})
@@ -273,6 +279,8 @@ use GCPlugins::GCbooks::GCbooksCommon;
         $self->{curName} = undef;
         $self->{curUrl} = undef;
 
+        $self->{suffix} = 'fr';
+
         return $self;
     }
 
@@ -292,17 +300,19 @@ use GCPlugins::GCbooks::GCbooksCommon;
         }
         else
         {
+            $html =~ s/(<i>|<\/i>)//gim;
+            $html =~ s/<p>/\n/gim;
+            $html =~ s|</p>|\n|gim;
+            $html =~ s/(<ul>|<\/ul>)/\n/gim;
+            $html =~ s/<li>([^<])/- $1/gim;
+            $html =~ s|([^>])</li>|$1\n|gim;
+            $html =~ s|<br ?/?>|\n|gi;
+            $self->{insideDesc} = 0;
             $self->{insidePublisher} = 0;
             $self->{insideLanguage} = 0;
             $self->{insideSerie} = 0;
             $self->{insideDetails} = 0;
             $self->{insideIsbn} = 0;
-            $self->{insideDesc} = 0;
-            $html =~ s/(<i>|<\/i>)//gim;
-            $html =~ s/(<ul>|<\/ul>)/\n/gim;
-            $html =~ s/<li>([^<])/- $1/gim;
-            $html =~ s|([^>])</li>|$1\n|gim;
-            $html =~ s|<br ?/?>|\n|gi;
         }
         
         $self->{alreadyRetrieved} = {};
@@ -310,35 +320,11 @@ use GCPlugins::GCbooks::GCbooksCommon;
         return $html;
     }
     
-    sub getSearchUrl
-    {
-		my ($self, $word) = @_;
-        return "http://www.amazon.fr/gp/search/?redirect=true&search-alias=books&keywords=$word";
-    }
-    
-    sub getItemUrl
-    {
-		my ($self, $url) = @_;
-		
-        return 'http://www.amazon.fr' if !$url;
-        return $url;
-    }
-
     sub getName
     {
         return 'Amazon (FR)';
     }
     
-    sub getImageFile
-    {
-        return "amazon.png";
-    }
-
-    sub getAuthor
-    {
-        return 'Tian';
-    }
-    
     sub getLang
     {
         return 'FR';
