@@ -38,8 +38,15 @@ use GCPlugins::GCPluginsBase;
         my $class = ref($proto) || $proto;
         my $self  = $class->SUPER::new();
         bless ($self, $class);
+        $self->{searchType} = 'books';
         return $self;
     }    
+
+    sub getSearchFieldsArray
+    {
+        return ['title'];
+    }
+
 }
 
 1;
\ No newline at end of file
