@@ -72,12 +72,10 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq "img")
             {
-                if (($attr->{src} =~ m%^http://.*?images[.-]amazon\.com/images/P/[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%)
+                if (($attr->{src} =~ m%^http://.*?images[.-]amazon\.com/images/P/([A-Z0-9]*)(\.[0-9]+\.)?[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%)
                  && (!$self->{curInfo}->{image}))
                 {
-                    $self->{curInfo}->{image} = $attr->{src};
-                    $self->{curInfo}->{image} =~ s%(.*?/images/P/[0-9]*\.)(.*?)(_SC.ZZZZZZZ_(.*?)\.(jpg|gif))%$1$3%;
-                    $self->{curInfo}->{image} =~ s/_PE[0-9]{2}_/_/;
+                    $self->{curInfo}->{image} = 'http://images.amazon.com/images/P/'.$1.$2.'MZZZZZZZ.jpg';
                 }
             }
             elsif ($tagname eq "b")
@@ -105,7 +103,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if (($self->{inside}->{title})
             && ($origtext !~ /Amazon.de.? DVD Search Results/)
-            && ($origtext !~ /Amazon.de\s*DVD:/))
+            && ($origtext !~ /Amazon.de:?\s+.*?DVD$/))
             {
                 $self->{parsingEnded} = 1;
             }
