@@ -68,12 +68,10 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($tagname eq "img")
             {
-                if (($attr->{src} =~ m%^http://.*?images[.-]amazon\.com/images/P/[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%)
+                if (($attr->{src} =~ m%^http://.*?images[.-]amazon\.com/images/P/([A-Z0-9]*)(\.[0-9]+\.)?[-A-Za-z0-9_.,]*?ZZZZZZZ(.*?)\.(jpg|gif)%)
                  && (!$self->{curInfo}->{image}))
                 {
-                    $self->{curInfo}->{image} = $attr->{src};
-                    $self->{curInfo}->{image} =~ s%(.*?/images/P/[0-9]*\.)(.*?)(_SC.ZZZZZZZ_(.*?)\.(jpg|gif))%$1$3%;
-                    $self->{curInfo}->{image} =~ s/_PE[0-9]{2}_/_/;
+                    $self->{curInfo}->{image} = 'http://images.amazon.com/images/P/'.$1.$2.'MZZZZZZZ.jpg';
                 }
             }
             elsif ($tagname eq "b")
@@ -100,7 +98,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if (($self->{inside}->{title})
              && ($origtext !~ /Amazon.fr:.*R.*sultats/)
-             && ($origtext !~ /Amazon.fr\s+DVD\s*:/))
+             && ($origtext !~ /Amazon.fr:?\s+.*?DVD$/))
             {
                 $self->{parsingEnded} = 1;
             }
@@ -206,6 +204,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         else
         {
             $html =~ s/(<i>|<\/i>)//gim;
+            $html =~ s/<p>/\n/gim;
+            $html =~ s|</p>|\n|gim;
             $html =~ s/(<ul>|<\/ul>)/\n/gim;
             $html =~ s/<li>([^<])/- $1/gim;
             $html =~ s|([^>])</li>|$1\n|gim;
