@@ -103,18 +103,18 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif (($self->{couldBeYear}))
             {
-                $self->{itemsList}[$self->{itemIdx}]->{'year'} = $1 if $origtext =~ m/([0-9]{4})/;
+                $self->{itemsList}[$self->{itemIdx}]->{'date'} = $1 if $origtext =~ m/([0-9]{4})/;
                 $self->{couldBeYear} = 0;
             }
         }
         else
         {
             $origtext =~ s/ : //g if !$self->{insideSynopsis};
-            if ($self->{insideType})
+            if ($self->{insideGenre})
             {
                 $origtext =~ s/ - /,/g;
-                $self->{curInfo}->{type} .= $origtext;
-                $self->{insideType} = 0;
+                $self->{curInfo}->{genre} .= $origtext;
+                $self->{insideGenre} = 0;
             }
             elsif ($self->{insideDate})
             {
@@ -161,7 +161,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 $self->{insideDate}=1 if $origtext =~ m/Year/;
                 $self->{insideDirector} = 1 if $origtext =~ m/Director\(s\)/;
-                $self->{insideType} = 1 if $origtext =~ m/Genres/;
+                $self->{insideGenre} = 1 if $origtext =~ m/Genres/;
                 $self->{insideOrig} = 1 if $origtext =~ m/Original title/;
                 $self->{insideTime} = 1 if $origtext =~ m/Duration/;
                 $self->{insideNat} = 1 if $origtext =~ m/Country/;
@@ -196,7 +196,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $html) = @_;
 
-        $html =~ s|<a class="underline" href="http://www\.mediadis\.com/products/search\.asp\?par=[0-9]*" title="Filmography">([^<]*)</a>|$1|g;
+        $html =~ s|<a (class="underline" )?href="http://www\.mediadis\.com/products/search\.asp\?par=[0-9]*" title="Filmography">([^<]*)</a>|$2|g;
         $html =~ s/&nbsp;/ /g;
         
         return $html;
