@@ -44,6 +44,11 @@ use GCPlugins::GCPluginsBase;
         return $self;
     }    
     
+    sub getSearchFieldsArray
+    {
+        return ['name'];
+    }
+
     sub getTipsUrl
     {
         my $self = shift;
