@@ -49,6 +49,27 @@ sub glob
     return glob "$pattern";
 }
 
+sub pathToUnix
+{
+    my $path = shift;
+    $path =~ s|\\|/|g if ($^O =~ /win32/i);
+    return $path;
+}
+
+sub sizeToHuman
+{
+    my ($size, $sizesSymbols) = @_;
+    
+    #my @prefixes = ('', 'K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y');
+    my $i = 0;
+    while ((($size / 1024) > 1) && ($i < scalar @$sizesSymbols))
+    {
+        $size /= 1024;
+        $i++;
+    }
+    return sprintf("%.1f %s%s", $size, $sizesSymbols->[$i]);
+}
+
 sub getSafeFileName
 {
     my $file = shift;
@@ -71,9 +92,21 @@ sub listNameToNumber
     return 1 if $value =~ /single/;
     return 2 if $value =~ /double/;
     return 3 if $value =~ /triple/;
+    return 4 if $value =~ /quadruple/;
     return 0;
 }
 
+sub encodeEntities
+{
+    my $value = shift;
+    $value =~ s/&/&amp;/g;
+    $value =~ s/</&lt;/g;
+    $value =~ s/>/&gt;/g;
+    $value =~ s/"/&quot;/g;
+    #"
+    return $value;
+}
+
 sub listToXml
 {
     my $value = shift;
@@ -148,22 +181,39 @@ sub listToXml
             return $value;
         }
     }
-    
+
+    sub otherList
+    {
+        my $value = shift;
+        if (ref($value) eq 'HASH')
+        {
+            my $string = '';
+            foreach my $line(@{$value->{line}})
+            {
+                $string .= $_.'|' foreach (@{$line->{col}});
+                $string .= ', ';
+            }
+            $string =~ s/, $//;
+            return $string;
+        }
+        else
+        {
+            $value =~ s/,([^ ])/, $1/g;
+            $value =~ s/(, ?)*$//;
+            return $value;
+        }
+    }
+
     sub multipleList
     {
         my ($value, $number) = @_;
 
         $number = GCUtils::listNameToNumber($number) if $number !~ /^[0-9]+$/;
 
-        if ($number == 2)
-        {
-            return doubleList($value);
-        }
-        else
-        {
-            #We only return the first column of each line in a string
-            return singleList($value);
-        }
+        return singleList($value) if $number == 1;
+        return doubleList($value) if $number == 2;
+        #We only return the first column of each line in a string
+        return otherList($value);
     }
     
     sub multipleListToArray
@@ -210,6 +260,7 @@ sub listToXml
         (my $date = shift) =~ s|([0-9]{2})/([0-9]{2})/([0-9]{4})|$3/$2/$1|;
         return $date;
     }
+    
     sub restoreDate
     {
         (my $date = shift) =~ s|([0-9]{4})/([0-9]{2})/([0-9]{2})|$3/$2/$1|;
@@ -225,6 +276,13 @@ sub listToXml
         
         return $year;
     }
+    
+    sub noNullNumber
+    {
+        my $num = shift;
+        return 0 if ($num eq '') || (! defined($num));
+        return $num;
+    }
 }
 
 sub round 
@@ -353,8 +411,8 @@ sub getDisplayedImage
         $displayedImage = $default if ! -f $displayedImage;
     }
     $displayedImage = $default if ! -f $displayedImage;
-    
-    return $displayedImage;
+
+    return GCUtils::pathToUnix($displayedImage);
 }
 
 1;
